@@ -3,7 +3,7 @@
         'name' => 'nextcloud/3rdparty',
         'pretty_version' => 'dev-stable28',
         'version' => 'dev-stable28',
-        'reference' => NULL,
+        'reference' => null,
         'type' => 'library',
         'install_path' => __DIR__ . '/../',
         'aliases' => array(),
@@ -11,18 +11,18 @@
     ),
     'versions' => array(
         'aws/aws-crt-php' => array(
-            'pretty_version' => 'v1.0.2',
-            'version' => '1.0.2.0',
-            'reference' => '3942776a8c99209908ee0b287746263725685732',
+            'pretty_version' => 'v1.2.6',
+            'version' => '1.2.6.0',
+            'reference' => 'a63485b65b6b3367039306496d49737cf1995408',
             'type' => 'library',
             'install_path' => __DIR__ . '/../aws/aws-crt-php',
             'aliases' => array(),
             'dev_requirement' => false,
         ),
         'aws/aws-sdk-php' => array(
-            'pretty_version' => '3.240.8',
-            'version' => '3.240.8.0',
-            'reference' => '72a4381a59f42720b033865d265aa64c3190cc13',
+            'pretty_version' => '3.322.4',
+            'version' => '3.322.4.0',
+            'reference' => 'f6d2c64cb87d9e70ad99aeaffcd879a412d2ccb5',
             'type' => 'library',
             'install_path' => __DIR__ . '/../aws/aws-sdk-php',
             'aliases' => array(),
@@ -310,7 +310,7 @@
         'nextcloud/3rdparty' => array(
             'pretty_version' => 'dev-stable28',
             'version' => 'dev-stable28',
-            'reference' => NULL,
+            'reference' => null,
             'type' => 'library',
             'install_path' => __DIR__ . '/../',
             'aliases' => array(),
