@@ -40,27 +40,15 @@ use Psr\Log\LoggerInterface;
  * @brief Class for managing the data in the activities
  */
 class Data {
-	/** @var IManager */
-	protected $activityManager;
 
-	/** @var IDBConnection */
-	protected $connection;
+	/** @var  */
+	protected ?IQueryBuilder $insertActivity = null;
+	protected ?IQueryBuilder $insertMail = null;
 
-	/** @var ?IQueryBuilder */
-	protected $insertActivity;
-
-	/** @var ?IQueryBuilder */
-	protected $insertMail;
-	private LoggerInterface $logger;
-
-	/**
-	 * @param IManager $activityManager
-	 * @param IDBConnection $connection
-	 */
-	public function __construct(IManager $activityManager, IDBConnection $connection, LoggerInterface $logger) {
-		$this->activityManager = $activityManager;
-		$this->connection = $connection;
-		$this->logger = $logger;
+	public function __construct(
+		protected IManager $activityManager,
+		protected IDBConnection $connection,
+		protected LoggerInterface $logger) {
 	}
 
 	/**
@@ -375,7 +363,7 @@ class Data {
 	 */
 	public function deleteActivities($conditions): void {
 		$platform = $this->connection->getDatabasePlatform();
-		if ($platform instanceof MySQLPlatform) {
+		if($platform instanceof MySQLPlatform) {
 			$this->logger->debug('Choosing chunked activity delete for MySQL/MariaDB', ['app' => 'activity']);
 			$this->deleteActivitiesForMySQL($conditions);
 			return;
@@ -494,7 +482,7 @@ class Data {
 		$query->setMaxResults(50000);
 		$result = $query->executeQuery();
 		$count = $result->rowCount();
-		if ($count === 0) {
+		if($count === 0) {
 			return;
 		}
 		$ids = array_map(static function (array $id) {
@@ -506,11 +494,11 @@ class Data {
 		$deleteQuery = $this->connection->getQueryBuilder();
 		$deleteQuery->delete('activity');
 		$deleteQuery->where($deleteQuery->expr()->in('activity_id', $deleteQuery->createParameter('ids'), IQueryBuilder::PARAM_INT_ARRAY));
-		foreach (array_chunk($ids, 1000) as $chunk) {
+		foreach(array_chunk($ids, 1000) as $chunk) {
 			$deleteQuery->setParameter('ids', $chunk, IQueryBuilder::PARAM_INT_ARRAY);
 			$queryResult += $deleteQuery->executeStatement();
 		}
-		if ($queryResult === 50000) {
+		if($queryResult === 50000) {
 			$this->deleteActivitiesForMySQL($conditions);
 		}
 	}
