@@ -16,7 +16,7 @@ OC.L10N.register(
     "Could not find share" : "共有が見つかりませんでした",
     "Federated sharing" : "連携共有",
     "You received {share} as a remote share from {user} (on behalf of {behalf})" : "{user} からリモート共有として {share} を受け取りました。({behalf} の代理として)",
-    "You received {share} as a remote share from {user}" : "{user} から {file} のリモート共有が届いています",
+    "You received {share} as a remote share from {user}" : "{user} から {share} のリモート共有が届いています",
     "Accept" : "承諾",
     "Decline" : "拒否",
     "Federated Cloud Sharing" : "統合されたクラウド共有",
@@ -36,8 +36,8 @@ OC.L10N.register(
     "Your Federated Cloud ID:" : "あなたのクラウド共有ID：",
     "Share it so your friends can share files with you:" : "友達があなたとファイルを共有できるよう、シェアしましょう:",
     "Facebook" : "Facebook",
-    "Twitter" : "Twitter",
-    "Diaspora" : "Diaspora",
+    "X (formerly Twitter)" : "X (旧 Twitter)",
+    "Mastodon" : "Mastodon",
     "Add to your website" : "ウェブサイトに追加",
     "Share with me via Nextcloud" : "Nextcloud 経由で共有",
     "HTML Code:" : "HTMLコード:",
@@ -45,8 +45,6 @@ OC.L10N.register(
     "Share with me through my #Nextcloud Federated Cloud ID" : "#Nextcloud の「クラウド共有ID」で私と共有できます。",
     "Cloud ID copied to the clipboard" : "クリップボードにクラウドIDをコピーしました",
     "Copy to clipboard" : "クリップボードにコピー",
-    "Clipboard is not available" : "クリップボードは利用できません",
-    "Copied!" : "コピーしました！",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "{owner}@{remote} からのリモート共有 {name} を追加してもよろしいですか？",
     "Remote share" : "リモート共有",
     "Remote share password" : "リモート共有のパスワード",
@@ -60,6 +58,10 @@ OC.L10N.register(
     "Allow users on this server to send shares to groups on other servers" : "ユーザーがこのサーバーから他のサーバー上のグループに共有することを許可する",
     "Allow users on this server to receive group shares from other servers" : "ユーザーが他のサーバーからこのサーバーにグループ共有することを許可する",
     "Search global and public address book for users" : "グローバルまたはユーザーの公開アドレス帳を検索する",
-    "Allow users to publish their data to a global and public address book" : "公開アドレス帳をグローバルに公開することをユーザーに許可する"
+    "Allow users to publish their data to a global and public address book" : "公開アドレス帳をグローバルに公開することをユーザーに許可する",
+    "Twitter" : "Twitter",
+    "Diaspora" : "Diaspora",
+    "Clipboard is not available" : "クリップボードは利用できません",
+    "Copied!" : "コピーしました！"
 },
 "nplurals=1; plural=0;");
