@@ -20,13 +20,11 @@ OC.L10N.register(
     "Federated Cloud" : "Nuvem Federada",
     "Your Federated Cloud ID:" : "A sua id. da Nuvem Federada:",
     "Share it so your friends can share files with you:" : "Partilhe para que os seus amigos possam partilhar ficheiros consigo:",
-    "Twitter" : "Twitter",
     "Add to your website" : "Adicione ao seu site da Web",
     "Share with me via Nextcloud" : "Partilhe comigo via Nextcloud",
     "HTML Code:" : "Código HTML:",
     "Share with me through my #Nextcloud Federated Cloud ID" : "Partilhe comigo através da minha Id. da Nuvem Federada #Nextcloud",
     "Copy to clipboard" : "Copiar para área de transferência",
-    "Copied!" : "Copiado!",
     "Do you want to add the remote share {name} from {owner}@{remote}?" : "Pretende adicionar a partilha remota {nome} de {proprietório}@{remoto}?",
     "Remote share" : "Partilha remota",
     "Remote share password" : "Palavra-passe da partilha remota",
@@ -35,6 +33,8 @@ OC.L10N.register(
     "Not allowed to create a federated share with the same user" : "Não é possível criar uma partilha federada com o mesmo utilizador",
     "Allow users on this server to receive shares from other servers" : "Permitir que os utilizadores neste servidor recebam as partilhas de outros servidores",
     "Search global and public address book for users" : "Pesquisar lista global e pública de contactos de utilizadores  ",
-    "Allow users to publish their data to a global and public address book" : "Permitir que  os utilizadores publiquem os seus dados para uma lista de contactos global e pública"
+    "Allow users to publish their data to a global and public address book" : "Permitir que  os utilizadores publiquem os seus dados para uma lista de contactos global e pública",
+    "Twitter" : "Twitter",
+    "Copied!" : "Copiado!"
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
