@@ -1,120 +1,6 @@
 OC.L10N.register(
     "files",
     {
-    "File could not be found" : "找不到檔案",
-    "Move or copy" : "移動或複製",
-    "Download" : "下載",
-    "Delete" : "刪除",
-    "Tags" : "標籤",
-    "Show list view" : "顯示清單檢視",
-    "Show grid view" : "顯示網格檢視",
-    "Home" : "家目錄",
-    "Close" : "關閉",
-    "Could not create folder \"{dir}\"" : "無法建立資料夾「{dir}」",
-    "This will stop your current uploads." : "這會終止目前任何的上傳。",
-    "Upload cancelled." : "上傳已取消。",
-    "Processing files …" : "正在處理檔案……",
-    "…" : "……",
-    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
-    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
-    "Target folder \"{dir}\" does not exist any more" : "目標資料夾「{dir}」不存在",
-    "Not enough free space" : "空間不足",
-    "An unknown error has occurred" : "發生未知的錯誤",
-    "File could not be uploaded" : "檔案無法上傳",
-    "Uploading …" : "正在上傳……",
-    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
-    "Uploading … ({currentNumber}/{total})" : "正在上傳…… ({currentNumber}/{total})",
-    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize} ({bitrate})",
-    "Uploading that item is not supported" : "不支援上傳該項目",
-    "Target folder does not exist any more" : "目標資料夾已經不存在了",
-    "Operation is blocked by access control" : "操作已被存取控制封鎖",
-    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
-    "Actions" : "動作",
-    "Rename" : "重新命名",
-    "Move" : "移動",
-    "Copy" : "複製",
-    "Choose target folder" : "選擇目標資料夾",
-    "Set reminder" : "設定提醒",
-    "Edit locally" : "本機編輯",
-    "Open" : "開啟",
-    "Delete file" : "刪除檔案",
-    "Delete folder" : "刪除資料夾",
-    "Disconnect storage" : "解除連結儲存空間",
-    "Leave this share" : "離開此分享",
-    "Could not load info for file \"{file}\"" : "無法讀取「{file}」的詳細資料",
-    "Files" : "檔案",
-    "Details" : "詳細資料",
-    "Please select tag(s) to add to the selection" : "請選取要新增到選定項目的標籤",
-    "Apply tag(s) to selection" : "將標籤套用至選定項目",
-    "Select directory \"{dirName}\"" : "選取目錄「{dirName}」",
-    "Select file \"{fileName}\"" : "選取檔案「{fileName}」",
-    "Pending" : "等候中",
-    "Unable to determine date" : "無法確定日期",
-    "This operation is forbidden" : "此動作被禁止",
-    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
-    "Storage is temporarily not available" : "儲存空間暫時無法使用",
-    "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
-    "Could not move \"{file}\"" : "無法移動「{file}」",
-    "copy" : "複製",
-    "Could not copy \"{file}\", target exists" : "無法複製「{file}」，目標已存在",
-    "Could not copy \"{file}\"" : "無法複製「{file}」",
-    "Copied {origin} inside {destination}" : "已複製 {origin} 至 {destination}",
-    "Copied {origin} and {nbfiles} other files inside {destination}" : "已複製 {origin} 和其他 {nbfiles} 個檔案至 {destination}",
-    "Failed to redirect to client" : "重新導向到客戶端失敗",
-    "{newName} already exists" : "{newName} 已經存在",
-    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案「{fileName}」，因為此檔案已經不存在",
-    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱「{targetName}」在這資料夾「{dir}」已經被使用。請選擇其他名稱。",
-    "Could not rename \"{fileName}\"" : "無法重新命名「{fileName}」",
-    "Could not create file \"{file}\"" : "無法建立檔案「{file}」",
-    "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已存在",
-    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾「{dir}」，因為此資料夾已存在",
-    "Could not fetch file details \"{file}\"" : "無法擷取檔案詳細資訊「{file}」",
-    "Error deleting file \"{fileName}\"." : "刪除「{fileName}」時發生錯誤。",
-    "No search results in other folders for {tag}{filter}{endtag}" : "在其他資料夾中沒有找到 {tag}{filter}{endtag}",
-    "Enter more than two characters to search in other folders" : "輸入兩個字元以上以便在其他資料夾搜尋",
-    "Name" : "名稱",
-    "Size" : "大小",
-    "Modified" : "修改時間",
-    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
-    "_%n file_::_%n files_" : ["%n 個檔案"],
-    "{dirs} and {files}" : "{dirs} 和 {files}",
-    "_including %n hidden_::_including %n hidden_" : ["包含 %n 個隱藏檔"],
-    "You do not have permission to upload or create files here" : "您無權在此上傳或建立檔案",
-    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
-    "New" : "新增",
-    "New file/folder menu" : "新檔案/資料夾選單",
-    "Select file range" : "選取多個檔案",
-    "{used}%" : "{used}%",
-    "{used} of {quota} used" : "已使用 {quota} 當中的 {used}",
-    "{used} used" : "已使用 {used}",
-    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名。",
-    "File name cannot be empty." : "檔名不能為空。",
-    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"。",
-    "\"{name}\" is not an allowed filetype" : "「{name}」是不允許的檔案類型",
-    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
-    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群組資料夾「{mountPoint}」已滿，已無法再更新或同步檔案！",
-    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部儲存空間「{mountPoint}」已滿，已無法再更新或同步檔案！",
-    "Your storage is full, files cannot be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
-    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的儲存空間將近已滿 ({usedSpacePercent}%)。",
-    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "群組資料夾「{mountPoint}」將近已滿 ({usedSpacePercent}%)。",
-    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部儲存空間「{mountPoint}」將近已滿 ({usedSpacePercent}%)。",
-    "Your storage is almost full ({usedSpacePercent}%)." : "您的儲存空間將近已滿 ({usedSpacePercent}%)。",
-    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["符合「{filter}」"],
-    "View in folder" : "在資料夾中檢視",
-    "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
-    "Path" : "路徑",
-    "_%n byte_::_%n bytes_" : ["%n 位元組"],
-    "Favorited" : "已加入最愛",
-    "Favorite" : "我的最愛",
-    "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
-    "New folder" : "新資料夾",
-    "Create new folder" : "新增資料夾",
-    "Upload file" : "上傳檔案",
-    "Recent" : "近期",
-    "Not favorited" : "未加入至最愛",
-    "Remove from favorites" : "從最愛中移除",
-    "Add to favorites" : "新增至最愛",
-    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
     "Added to favorites" : "已新增至最愛",
     "Removed from favorites" : "已從最愛中移除",
     "You added {file} to your favorites" : "您已新增 {file} 至您的最愛",
@@ -154,9 +40,17 @@ OC.L10N.register(
     "You moved {oldfile} to {newfile}" : "您將 {oldfile} 移動到了 {newfile}",
     "{user} moved {oldfile} to {newfile}" : "{user} 將 {oldfile} 移動到了 {newfile}",
     "A file has been added to or removed from your <strong>favorites</strong>" : "檔案已從您的<strong>最愛</strong>新增或移除",
+    "Files" : "檔案",
     "A file or folder has been <strong>changed</strong>" : "檔案或資料夾已被<strong>變更</strong>",
     "A favorite file or folder has been <strong>changed</strong>" : "一個最愛的檔案或資料夾已<strong>變更</strong>",
+    "Failed to authorize" : "授權失敗",
+    "Invalid folder path" : "無效的資料夾路徑",
+    "Folder not found" : "找不到資料夾",
     "Upload (max. %s)" : "上傳（最多 %s）",
+    "Files compatibility" : "檔案相容性",
+    "Allow to restrict filenames to ensure files can be synced with all clients. By default all filenames valid on POSIX (e.g. Linux or macOS) are allowed." : "允許限制檔案名稱以確保檔案可以與所有客戶端同步。預設情況下，允許 POSIX（例如 Linux 或 macOS）上所有有效的檔案名稱。",
+    "Enforce Windows compatibility" : "強制 Windows 相容性",
+    "This will block filenames not valid on Windows systems, like using reserved names or special characters. But this will not enforce compatibility of case sensitivity." : "這會封鎖在 Windows 系統上無效的檔案名稱，例如使用保留名稱或特殊字元。但這不會強制區分大小寫的相容性。",
     "Accept" : "接受",
     "Reject" : "拒絕",
     "Incoming ownership transfer from {user}" : "來自 {user} 的所有權轉移",
@@ -173,32 +67,42 @@ OC.L10N.register(
     "Transferred from %1$s on %2$s" : "於 %2$s 從 %1$s 轉移",
     "File Management" : "檔案管理",
     "Current directory path" : "目前目錄路徑",
+    "Home" : "家目錄",
+    "Target folder does not exist any more" : "目標資料夾已經不存在了",
     "Reload current directory" : "重新載入目前的目錄",
     "Go to the \"{dir}\" directory" : "到「{dir}」目錄",
     "Drag and drop files here to upload" : "將檔案拖曳到此處以上傳",
     "Your have used your space quota and cannot upload files anymore" : "您已用完您的空間配額，無法再上傳檔案",
     "You don’t have permission to upload or create files here" : "您沒有權限在這裡上傳或建立檔案",
+    "Favorite" : "我的最愛",
     "\"{displayName}\" action executed successfully" : "「{displayName}」動作執行成功",
     "\"{displayName}\" action failed" : "「{displayName}」操作失敗",
     "Toggle selection for file \"{displayName}\"" : "切換檔案「{displayName}」的選取",
     "Toggle selection for folder \"{displayName}\"" : "切換資料夾「{displayName}」的選取",
+    "File is loading" : "正在載入檔案",
+    "Folder is loading" : "正在載入資料夾",
     "Rename file" : "重新命名檔案",
-    "File name" : "檔案名稱",
+    "Filename" : "檔案名稱",
     "Folder name" : "資料夾名稱",
     "This node is unavailable" : "此節點不可用",
-    "Download file {name}" : "下載檔案 {name}",
-    "Invalid file name" : "無效的檔案名稱",
-    "\"{name}\" is not an allowed filetype." : "「{name}」是不允許的檔案類型。",
-    "{newName} already exists." : "{newName} 已經存在。",
-    "\"{char}\" is not allowed inside a file name." : "不允許檔名中出現「{char}」。",
-    "Name cannot be empty" : "名稱不能空白",
-    "Another entry with the same name already exists" : "已存在另一個同名條目",
+    "Another entry with the same name already exists." : "已存在另一個同名條目。",
+    "Invalid filename." : "無效的檔案名稱。",
     "Renamed \"{oldName}\" to \"{newName}\"" : "已將「{oldName}」重新命名為「{newName}」",
     "Could not rename \"{oldName}\", it does not exist any more" : "無法命名檔案「{oldName}」，因為此檔案已經不存在",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱「{newName}」在資料夾「{dir}」中已被使用。請選擇其他名稱。",
     "Could not rename \"{oldName}\"" : "無法重新命名「{oldName}」",
+    "Pending" : "等候中",
+    "Clear filter" : "清除過濾條件",
+    "Modified" : "修改時間",
+    "Type" : "類型",
+    "Active filters" : "作用中的過濾條件",
+    "Remove filter" : "移除過濾條件",
     "Total rows summary" : "總列摘要",
+    "Name" : "名稱",
+    "Size" : "大小",
     "Toggle selection for all files and folders" : "切換所有檔案和資料夾的選取",
+    "Actions" : "動作",
+    "(selected)" : "（已選取）",
     "\"{displayName}\" failed on some elements " : "「{displayName}」在某些元素上失敗",
     "\"{displayName}\" batch action executed successfully" : "「{displayName}」批次動作執行成功",
     "{count} selected" : "已選取 {count} 個",
@@ -206,13 +110,20 @@ OC.L10N.register(
     "Column headers with buttons are sortable." : "帶有按鈕的欄位標題是可排序的。",
     "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "出於效能考量，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
     "File not found" : "找不到檔案",
-    "Storage informations" : "儲存空間資訊",
+    "Storage information" : "儲存空間資訊",
+    "Storage quota" : "儲存空間配額",
     "{usedQuotaByte} used" : "已使用 {usedQuotaByte}",
+    "{used} of {quota} used" : "已使用 {quota} 當中的 {used}",
     "{relative}% used" : "已使用 {relative}%",
     "Could not refresh storage stats" : "無法重新整理儲存空間統計資料",
     "Your storage is full, files can not be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
     "Create" : "建立",
-    "A file or folder with that name already exists." : "已存在同名的檔案或資料夾。",
+    "New folder" : "新資料夾",
+    "Create new folder" : "新增資料夾",
+    "This name is already in use." : "此名稱已使用。",
+    "Fill template fields" : "檔案範本欄位",
+    "Submitting fields…" : "正在遞交欄位……",
+    "Submit" : "遞交",
     "Transfer ownership of a file or folder" : "轉移檔案或是資料夾的所有權",
     "Choose file or folder to transfer" : "選擇要轉移的檔案或資料夾",
     "Change" : "更改",
@@ -225,8 +136,8 @@ OC.L10N.register(
     "Ownership transfer request sent" : "已送出所有權轉移的請求",
     "Cannot transfer ownership of a file or folder you do not own" : "無法轉移您未擁有的檔案或資料夾的所有權",
     "Select file or folder to link to" : "選取要連結的檔案或資料夾",
-    "Choose file" : "選擇檔案",
     "Choose {file}" : "選擇 {file}",
+    "New" : "新增",
     "Loading current folder" : "正在載入目前資料夾",
     "No files in here" : "沒有任何檔案",
     "Upload some content or sync with your devices!" : "在您的裝置同步或上傳一些內容！",
@@ -238,10 +149,13 @@ OC.L10N.register(
     "Switch to list view" : "切換至列表檢視",
     "Switch to grid view" : "切換到網格檢視",
     "Upload was cancelled by user" : "使用者已取消上傳",
+    "Not enough free space" : "空間不足",
+    "Operation is blocked by access control" : "操作已被存取控制封鎖",
     "Error during upload: {message}" : "上傳時發生錯誤：{message}",
     "Error during upload, status code {status}" : "上傳時發生錯誤，狀態碼 {status}",
     "Unknown error during upload" : "上傳時發生未知的錯誤",
-    "Open the files app settings" : "開啟檔案應用程式設定",
+    "Filter filenames…" : "篩選檔案名稱……",
+    "Views" : "顯示",
     "Files settings" : "檔案設定",
     "File cannot be accessed" : "無法存取檔案",
     "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "找不到該檔案，或是您沒有檢視該檔案的權限。請寄件者分享。",
@@ -252,6 +166,7 @@ OC.L10N.register(
     "Show hidden files" : "顯示隱藏檔",
     "Crop image previews" : "圖片裁剪預覽",
     "Enable the grid view" : "啟用網格檢視",
+    "Enable folder tree" : "啟用資料夾樹",
     "Additional settings" : "其他設定",
     "WebDAV" : "WebDAV",
     "WebDAV URL" : "WebDAV URL",
@@ -260,6 +175,12 @@ OC.L10N.register(
     "If you have enabled 2FA, you must create and use a new app password by clicking here." : "若您啟用了 2FA，您必須點擊此處建立並使用新的應用程式密碼。",
     "Clipboard is not available" : "剪貼簿無法使用",
     "WebDAV URL copied to clipboard" : "WebDAV URL 已複製到剪貼簿",
+    "Owner" : "擁有者",
+    "Remove from favorites" : "從最愛中移除",
+    "Add to favorites" : "新增至最愛",
+    "Tags" : "標籤",
+    "You" : "您",
+    "Shared multiple times with different people" : "與不同的人多次分享",
     "Unable to change the favourite state of the file" : "無法更改檔案的最愛狀態",
     "Error while loading the file data" : "載入檔案資料時發生錯誤",
     "Pick a template for {name}" : "為 {name} 挑選範本",
@@ -267,18 +188,30 @@ OC.L10N.register(
     "Creating file" : "正在建立檔案",
     "Blank" : "空白",
     "Unable to create new file from template" : "無法從範本建立新檔案",
+    "Deletion cancelled" : "刪除已取消",
     "Delete permanently" : "永久刪除",
     "Delete and unshare" : "刪除並取消分享",
+    "Leave this share" : "離開此分享",
     "Leave these shares" : "離開這些分享",
+    "Disconnect storage" : "解除連結儲存空間",
     "Disconnect storages" : "解除連結儲存空間",
+    "Delete file" : "刪除檔案",
     "Delete files" : "刪除檔案",
+    "Delete folder" : "刪除資料夾",
     "Delete folders" : "刪除資料夾",
-    "You are about to delete {count} items." : "您將要移除 {count} 個項目。",
+    "Delete" : "刪除",
+    "_You are about to permanently delete {count} item_::_You are about to permanently delete {count} items_" : ["您將要永久刪除 {count} 個項目"],
+    "_You are about to delete {count} item_::_You are about to delete {count} items_" : ["您將要刪除 {count} 個項目"],
     "Confirm deletion" : "確認刪除",
     "Cancel" : "取消",
-    "Deletion cancelled" : "刪除已取消",
-    "Destination is not a folder" : "目的地不是資料夾",
-    "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
+    "Edit file locally" : "本機編輯檔案",
+    "The file should now open locally. If you don't see this happening, make sure that the desktop client is installed on your system." : "檔案現在應該在本機開啟。若您並未看到檔案在本機開啟，請確保您的系統上已安裝桌面客戶端。",
+    "Retry local edit" : "重試本機編輯",
+    "Edit online" : "線上編輯",
+    "Failed to redirect to client" : "重新導向到客戶端失敗",
+    "Edit locally" : "本機編輯",
+    "Moving \"{source}\" to \"{destination}\" …" : "正在移動「{source}」至「{destination}」……",
+    "Copying \"{source}\" to \"{destination}\" …" : "正在複製「{source}」至「{destination}」……",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "您無法將檔案/資料夾移動到其自身或子資料夾中",
     "(copy)" : "（副本）",
     "(copy %n)" : "（副本 %n）",
@@ -288,16 +221,35 @@ OC.L10N.register(
     "The file does not exist anymore" : "檔案已不存在",
     "Choose destination" : "選擇目的地",
     "Copy to {target}" : "複製到 {target}",
+    "Copy" : "複製",
     "Move to {target}" : "移動至 {target}",
-    "Cancelled move or copy operation" : "已取消移動或複製操作",
+    "Move" : "移動",
     "Move or copy operation failed" : "移動或複製操作失敗",
+    "Move or copy" : "移動或複製",
+    "Cancelled move or copy of \"{filename}\"." : "已取消移動或複製「{filename}」。",
+    "Cancelled move or copy operation" : "已取消移動或複製操作",
     "Open folder {displayName}" : "開啟資料夾 {displayName}",
     "Open in Files" : "在「檔案」應用程式中開啟",
+    "Rename" : "重新命名",
     "Open details" : "開啟細節",
+    "View in folder" : "在資料夾中檢視",
+    "Today" : "今日",
+    "Last 7 days" : "過去7天",
+    "Last 30 days" : "過去30天",
+    "This year ({year})" : "今年 ({year})",
+    "Last year ({year})" : "去年 ({year})",
+    "Documents" : "文件",
+    "Spreadsheets" : "試算表",
+    "Presentations" : "簡報",
+    "PDFs" : "PDF",
+    "Folders" : "資料夾",
+    "Audio" : "音訊",
+    "Photos and images" : "照片與影像",
+    "Videos" : "影片",
+    "New folder creation cancelled" : "已取消建立新資料夾",
     "Created new folder \"{name}\"" : "已建立新資料夾「{name}」",
-    "Filename" : "檔案名稱",
     "Unable to initialize the templates directory" : "無法初始化範本目錄",
-    "Create new templates folder" : "建立新的範本資料夾",
+    "Create templates folder" : "建立範本資料夾",
     "Templates" : "範本",
     "New template folder" : "新範本資料夾",
     "In folder" : "在資料夾中",
@@ -320,49 +272,136 @@ OC.L10N.register(
     "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 個檔案與 {folderCount} 個資料夾"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} 個檔案與 1 個資料夾"],
     "{fileCount} files and {folderCount} folders" : "{fileCount} 個檔案與 {folderCount} 個資料夾",
-    "List of favorites files and folders." : "最愛檔案與資料夾的清單。",
+    "Filename must not be empty." : "檔案名稱不能為空。",
+    "\"{char}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{char}」",
+    "\"{segment}\" is a reserved name and not allowed for filenames." : "「{segment}」是保留名稱，不允許用在檔案名稱。",
+    "\"{extension}\" is not an allowed filetype." : "「{extension}」是不允許的檔案類型。",
+    "Filenames must not end with \"{extension}\"." : "檔案名稱不能以「{extension}」結尾。",
+    "List of favorite files and folders." : "最愛檔案與資料夾清單。",
     "No favorites yet" : "尚無最愛",
     "Files and folders you mark as favorite will show up here" : "您標記為最愛的檔案與資料夾將會顯示在這裡",
     "All files" : "所有檔案",
     "List of your files and folders." : "您的檔案與資料夾清單。",
+    "All folders" : "所有資料夾",
     "Personal Files" : "個人檔案",
     "List of your files and folders that are not shared." : "未分享的檔案與資料夾清單。",
     "No personal files found" : "找不到個人檔案",
     "Files that are not shared will show up here." : "尚未分享的檔案將會顯示在此處。",
+    "Recent" : "近期",
     "List of recently modified files and folders." : "最近修改的檔案與資料夾的清單。",
     "No recently modified files" : "近期無修改檔案",
     "Files and folders you recently modified will show up here." : "您最近修改的檔案與資料夾將會顯示在此處。",
+    "You do not have permission to upload or create files here" : "您無權在此上傳或建立檔案",
     "No entries found in this folder" : "在此資料夾中沒有任何項目",
     "Select all" : "全選",
     "Upload too large" : "上傳過大",
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "您試圖上傳的檔案大小超過伺服器的限制",
+    "File could not be found" : "找不到檔案",
+    "Download" : "下載",
+    "Show list view" : "顯示清單檢視",
+    "Show grid view" : "顯示網格檢視",
+    "Close" : "關閉",
+    "Could not create folder \"{dir}\"" : "無法建立資料夾「{dir}」",
+    "This will stop your current uploads." : "這會終止目前任何的上傳。",
+    "Upload cancelled." : "上傳已取消。",
+    "Processing files …" : "正在處理檔案……",
+    "…" : "……",
+    "Unable to upload {filename} as it is a directory or has 0 bytes" : "因為 {filename} 是個目錄或是大小為零，所以無法上傳",
+    "Not enough free space, you are uploading {size1} but only {size2} is left" : "可用空間不足，你正要上傳 {size1} 可是只剩下 {size2}",
+    "Target folder \"{dir}\" does not exist any more" : "目標資料夾「{dir}」不存在",
+    "An unknown error has occurred" : "發生未知的錯誤",
+    "File could not be uploaded" : "檔案無法上傳",
+    "Uploading …" : "正在上傳……",
+    "{remainingTime} ({currentNumber}/{total})" : "{remainingTime} ({currentNumber}/{total})",
+    "Uploading … ({currentNumber}/{total})" : "正在上傳…… ({currentNumber}/{total})",
+    "{loadedSize} of {totalSize} ({bitrate})" : "{totalSize} 中的 {loadedSize} ({bitrate})",
+    "Uploading that item is not supported" : "不支援上傳該項目",
+    "Error when assembling chunks, status code {status}" : "重組檔案片段時出錯，狀態代碼 {status}",
+    "Choose target folder" : "選擇目標資料夾",
+    "Set reminder" : "設定提醒",
+    "Open" : "開啟",
+    "Could not load info for file \"{file}\"" : "無法讀取「{file}」的詳細資料",
+    "Details" : "詳細資料",
+    "Please select tag(s) to add to the selection" : "請選取要新增到選定項目的標籤",
+    "Apply tag(s) to selection" : "將標籤套用至選定項目",
+    "Select directory \"{dirName}\"" : "選取目錄「{dirName}」",
+    "Select file \"{fileName}\"" : "選取檔案「{fileName}」",
+    "Unable to determine date" : "無法確定日期",
+    "This operation is forbidden" : "此動作被禁止",
+    "This directory is unavailable, please check the logs or contact the administrator" : "這個目錄無法存取，請檢查伺服器記錄檔或聯絡管理員",
+    "Storage is temporarily not available" : "儲存空間暫時無法使用",
+    "Could not move \"{file}\", target exists" : "無法移動「{file}」，目標已經存在",
+    "Could not move \"{file}\"" : "無法移動「{file}」",
+    "copy" : "複製",
+    "Could not copy \"{file}\", target exists" : "無法複製「{file}」，目標已存在",
+    "Could not copy \"{file}\"" : "無法複製「{file}」",
+    "Copied {origin} inside {destination}" : "已複製 {origin} 至 {destination}",
+    "Copied {origin} and {nbfiles} other files inside {destination}" : "已複製 {origin} 和其他 {nbfiles} 個檔案至 {destination}",
+    "{newName} already exists" : "{newName} 已經存在",
+    "Could not rename \"{fileName}\", it does not exist any more" : "無法命名檔案「{fileName}」，因為此檔案已經不存在",
+    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "此名稱「{targetName}」在這資料夾「{dir}」已經被使用。請選擇其他名稱。",
+    "Could not rename \"{fileName}\"" : "無法重新命名「{fileName}」",
+    "Could not create file \"{file}\"" : "無法建立檔案「{file}」",
+    "Could not create file \"{file}\" because it already exists" : "無法建立檔案「{file}」，因為此檔案已存在",
+    "Could not create folder \"{dir}\" because it already exists" : "無法建立資料夾「{dir}」，因為此資料夾已存在",
+    "Could not fetch file details \"{file}\"" : "無法擷取檔案詳細資訊「{file}」",
+    "Error deleting file \"{fileName}\"." : "刪除「{fileName}」時發生錯誤。",
+    "No search results in other folders for {tag}{filter}{endtag}" : "在其他資料夾中沒有找到 {tag}{filter}{endtag}",
+    "Enter more than two characters to search in other folders" : "輸入兩個字元以上以便在其他資料夾搜尋",
+    "_%n folder_::_%n folders_" : ["%n 個資料夾"],
+    "_%n file_::_%n files_" : ["%n 個檔案"],
+    "{dirs} and {files}" : "{dirs} 和 {files}",
+    "_including %n hidden_::_including %n hidden_" : ["包含 %n 個隱藏檔"],
+    "_Uploading %n file_::_Uploading %n files_" : ["正在上傳 %n 個檔案"],
+    "New file/folder menu" : "新檔案/資料夾選單",
+    "Select file range" : "選取多個檔案",
+    "{used}%" : "{used}%",
+    "{used} used" : "已使用 {used}",
+    "\"{name}\" is an invalid file name." : "{name} 是無效的檔名。",
+    "File name cannot be empty." : "檔名不能為空。",
+    "\"/\" is not allowed inside a file name." : "不允許檔名中出現 \"/\"。",
+    "\"{name}\" is not an allowed filetype" : "「{name}」是不允許的檔案類型",
+    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "{owner} 的儲存空間已滿，沒有辦法再更新或是同步檔案！",
+    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "群組資料夾「{mountPoint}」已滿，已無法再更新或同步檔案！",
+    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "外部儲存空間「{mountPoint}」已滿，已無法再更新或同步檔案！",
+    "Your storage is full, files cannot be updated or synced anymore!" : "您的儲存空間已滿，沒有辦法再更新或是同步檔案！",
+    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "{owner} 的儲存空間將近已滿 ({usedSpacePercent}%)。",
+    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "群組資料夾「{mountPoint}」將近已滿 ({usedSpacePercent}%)。",
+    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "外部儲存空間「{mountPoint}」將近已滿 ({usedSpacePercent}%)。",
+    "Your storage is almost full ({usedSpacePercent}%)." : "您的儲存空間將近已滿 ({usedSpacePercent}%)。",
+    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["符合「{filter}」"],
+    "Direct link was copied (only works for users who have access to this file/folder)" : "已複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
+    "Path" : "路徑",
+    "_%n byte_::_%n bytes_" : ["%n 位元組"],
+    "Favorited" : "已加入最愛",
+    "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
+    "Upload file" : "上傳檔案",
+    "Not favorited" : "未加入至最愛",
+    "An error occurred while trying to update the tags" : "更新標籤時發生錯誤",
+    "\"remote user\"" : "「遠端使用者」",
+    "{newName} already exists." : "{newName} 已經存在。",
+    "\"{segment}\" is not allowed inside a filename." : "檔案名稱中不允許出現「{segment}」",
+    "\"{segment}\" is a forbidden file or folder name." : "「{segment}」是禁止的檔案或資料夾名稱。",
+    "\"{segment}\" is not an allowed filetype." : "「{segment}」是不允許的檔案類型。",
+    "Filenames must not end with \"{segment}\"." : "檔案名稱不能以「{segment}」結尾。",
+    "Name cannot be empty" : "名稱不能空白",
+    "Another entry with the same name already exists" : "已存在另一個同名條目",
+    "Storage informations" : "儲存空間資訊",
+    "Choose file" : "選擇檔案",
+    "Open the files app settings" : "開啟檔案應用程式設定",
+    "You might not have have permissions to view it, ask the sender to share it" : "您可能沒有權限檢視它，請要求寄件者分享它",
+    "Destination is not a folder" : "目的地不是資料夾",
+    "This file/folder is already in that directory" : "此檔案/資料夾已在該目錄中",
+    "The files is locked" : "檔案已鎖定",
+    "Create new templates folder" : "建立新的範本資料夾",
+    "List of favorites files and folders." : "最愛檔案與資料夾的清單。",
+    "Toggle %1$s sublist" : "切換 %1$s 子列表",
     "Text file" : "文字檔案",
     "New text file.txt" : "新文字檔案.txt",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "已複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
-    "Copy direct link (only works for users who have access to this file/folder)" : "複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
-    "You can only favorite a single file or folder at a time" : "您一次只能將一個檔案或資料夾加入最愛",
-    "This file has the tag {tag}" : "此檔案有標籤 {tag}",
-    "This file has the tags {firstTags} and {lastTag}" : "此檔案有標籤 {firstTags} 與 {lastTag}",
-    "\"remote user\"" : "「遠端使用者」",
-    "Select the row for {displayName}" : "選取 {displayName} 的列",
-    "Open folder {name}" : "開啟資料夾 {name}",
-    "Unselect all" : "取消全選",
-    "ascending" : "遞增",
-    "descending" : "遞減",
-    "Sort list by {column} ({direction})" : "按 {column}（{direction}）排序清單",
-    "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "出於效能考量，此清單未完全呈現。檔案將在您瀏覽清單時呈現。",
-    "Search for an account" : "搜尋帳號",
-    "Choose" : "選擇",
-    "No files or folders have been deleted yet" : "尚未刪除任何檔案或資料夾",
-    "You might not have have permissions to view it, ask the sender to share it" : "您可能沒有權限檢視它，請要求寄件者分享它",
-    "Set up templates folder" : "設定範本資料夾",
-    "Toggle %1$s sublist" : "切換 %1$s 子列表",
-    "Toggle grid view" : "切換網格檢視",
-    "Shares" : "分享",
-    "Shared with others" : "與其他人分享",
-    "Shared with you" : "與您分享",
-    "Deleted shares" : "已刪除的分享",
-    "Pending shares" : "等待分享",
-    "The files is locked" : "檔案已鎖定"
+    "Direct link was copied (only works for people who have access to this file/folder)" : "已複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
+    "Copy direct link (only works for people who have access to this file/folder)" : "複製直接連結（僅對有權存取此檔案或資料夾的使用者有用）",
+    "Favored" : "已加入最愛",
+    "Favor" : "加入最愛",
+    "Not favored" : "未加入最愛"
 },
 "nplurals=1; plural=0;");
