@@ -18,6 +18,7 @@ OC.L10N.register(
     "Disconnect" : "კავშირის გაწყვეტა",
     "Admin defined" : "განსაზღვრულია ადმინისტრატორის მიერ",
     "Delete storage?" : "გავაუქმოთ საცავი?",
+    "Click to recheck the configuration" : "დააწკაპუნეთ კონფიგურაციის ხელახალი შემოწმებისთვის",
     "Saved" : "შენახულია",
     "Save" : "შენახვა",
     "Storage with ID \"%d\" not found" : "საცავი ID-ით \"%d\" ვერ იქნა ნაპოვნი",
@@ -86,6 +87,7 @@ OC.L10N.register(
     "The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "FTP-ს მხარდაჭერა PHP-ში არაა მოქმედი ან დაყენებული. %s-ის მონტაჟი ვერ ხერხდება. გთხოვთ სთხოვოთ თქვენი სისტემის ადმინისტრატორს მისი დაყენება.",
     "External storage" : "ექსტერნალური საცავი",
     "External storage support" : "გარე საცავის მხარდაჭერა",
+    "Submit" : "გაგზავნა",
     "External mount error" : "გარე მონტაჟის შეცდომა",
     "Storage type" : "საცავის სახეობა",
     "Unknown" : "უცნობია",
@@ -98,26 +100,13 @@ OC.L10N.register(
     "Authentication" : "აუტენტიფიკაცია",
     "Configuration" : "კონფიგურაცია",
     "Available for" : "ხელმისაწვდომია რომ",
-    "Click to recheck the configuration" : "დააწკაპუნეთ კონფიგურაციის ხელახალი შემოწმებისთვის",
     "Add storage" : "საცავის დამატება",
     "Advanced settings" : "დამატებითი პარამეტრები",
-    "Empty response from the server" : "სერვერმა დააბრუნა ცარიელი პასუხი",
-    "Couldn't access. Please log out and in again to activate this mount point" : "წვდომა ვერ მოხერხდა. ამ მონტაჟის წერტილის გასააქტიურებლად გთხოვთ გახვიდეთ და ახლიდან გაიაროთ ავტორიზაცია.",
-    "Couldn't get the information from the remote server: {code} {type}" : "დისტანციური სერვერიდან ინფორმაციის მოპოვება ვერ მოხერხდა: {code} {type}",
-    "Couldn't get the list of external mount points: {type}" : "გარე მონტაჟის წერტილების სიის მოპოვება ვერ მოხერხდა: {type}",
-    "There was an error with message: " : "წარმოიშვა შეცდომა წერილით:",
-    "external-storage" : "გარე-საცავი",
-    "Couldn't fetch list of Windows network drive mount points: Empty response from server" : "Windows-ის ქსელის დრაივის მონტაჯის წერტილების სიის მოპოვება ვერ მოხერხდა: ცარიელი პასუხი სერვერიდან",
-    "Please enter the credentials for the {mount} mount" : "გთხოვთ {mount} მონტაჟისთვის შეიყვანოთ მონაცემები",
-    "Username" : "მომხმარებლის სახელი",
-    "Credentials saved" : "მონაცემები შენახულია",
-    "Credentials saving failed" : "მონაცემების შენახვა ვერ მოხერხდა",
-    "Credentials required" : "მონაცემები საჭიროა",
     "Storage with ID \"%d\" is not user editable" : "საცავი ID-ით \"%d\" არაა მომხმარებლისთვის შეცვლადი",
+    "Username" : "მომხმარებლის სახელი",
     "Username and password" : "მომხმარებელი და პაროლი",
     "User entered, store in database" : "შეყვანილი მომხმარებელი, შენახვა მონაცემთა ბაზაში",
     "Username as share" : "მომხმარებლის სახელი გაზიარებად",
-    "Name" : "სახელი",
     "Allow users to mount external storage" : "მივცეთ მომხმარებლებს გარე საცავის მონტაჟის უფლება"
 },
 "nplurals=2; plural=(n!=1);");
