@@ -1,20 +1,6 @@
 OC.L10N.register(
     "files_sharing",
     {
-    "Waiting…" : "Venter …",
-    "error" : "fejl",
-    "finished" : "Færdiggjort",
-    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
-    "Move or copy" : "Flyt eller kopier",
-    "Download" : "Download",
-    "Delete" : "Slet",
-    "You can upload into this folder" : "Du kan overføre til denne mappe",
-    "Terms of service" : "Servicebetingelser",
-    "Show list view" : "Vis som liste",
-    "Show grid view" : "Vis som gitter",
-    "No compatible server found at {remote}" : "Ingen kompatible servere fundet på {remote}",
-    "Invalid server URL" : "Ugyldig server adresse",
-    "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
     "File shares" : "Fildelinger",
     "Downloaded via public link" : "Downloaded via et offentligt link",
     "Downloaded by {email}" : "Downloaded af {email}",
@@ -70,7 +56,7 @@ OC.L10N.register(
     "Share for file {file} expired" : "Deling af {file} udløbet",
     "A file or folder shared by mail or by public link was <strong>downloaded</strong>" : "En fil eller mapper delt vie mail eller offentligt link blev <strong>downloaded</strong>",
     "A file or folder was shared from <strong>another server</strong>" : "En fil eller mappe blev delt fra <strong>en anden server</strong>",
-    "Files" : "Filer",
+    "Sharing" : "Deling",
     "A file or folder has been <strong>shared</strong>" : "En fil eller mappe er blevet <strong>delt</strong>",
     "Shared link" : "Delt link",
     "Wrong share ID, share does not exist" : "Forkert DelingsID, deling findes ikke",
@@ -90,8 +76,6 @@ OC.L10N.register(
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Deling af %1$s mislykkedes fordi backenden ikke tillader delinger fra typen %2$s",
     "Please specify a valid federated account ID" : "Venligst angiv et gyldigt fødereret konto-ID",
     "Please specify a valid federated group ID" : "Venligst angiv en gyldig fødereret gruppe-ID",
-    "You cannot share to a Circle if the app is not enabled" : "Du kan ikke dele en CIrkel hvis appen ikke er aktiveret",
-    "Please specify a valid circle" : "Venligst angiv en gyldig cirkel",
     "Sharing %s failed because the back end does not support room shares" : "Deling af %s mislykkedes fordi backenden ikke tillader delinger af rumdeling",
     "Sharing %s failed because the back end does not support ScienceMesh shares" : "Kunne ikke dele %s fordi backenden ikke understøtter deling af ScienceMesh",
     "Unknown share type" : "Ukendt deletype",
@@ -101,11 +85,13 @@ OC.L10N.register(
     "Wrong or no update parameter given" : "Forkert eller manglende opdateringsparameter",
     "Wrong password" : "Forkert adgangskode",
     "shared by %s" : "delt af %s",
+    "Download" : "Download",
     "Direct link" : "Direkte link",
     "Share API is disabled" : "Delings-API er slået fra",
     "File sharing" : "Fildeling",
     "Accept" : "Accepter",
     "Decline" : "Afvis",
+    "People" : "Personer",
     "Expiration date" : "Udløbsdato",
     "Set a password" : "Indstil en adgangskode",
     "Password" : "Kodeord",
@@ -115,10 +101,9 @@ OC.L10N.register(
     "Link copied to clipboard" : "Link kopieret til udklipsholder",
     "Select" : "Vælg",
     "Cancel" : "Annullér",
-    "Continue" : "Videre",
     "Close" : "Luk",
+    "Continue" : "Videre",
     "Error creating the share" : "Fejl ved skabelse af delt drev",
-    "Sharing" : "Deling",
     "Reset" : "Nulstil",
     "Invalid path selected" : "Ugyldig sti valgt.",
     "Unknown error" : "Ukendt fejl",
@@ -133,7 +118,6 @@ OC.L10N.register(
     "Link copied" : "Link kopieret",
     "Password protection" : "Adgangskodebeskyttelse",
     "Enter a password" : "Indtast en adgangskode",
-    "Enter a date" : "Indtast en dato",
     "Add another link" : "Tilføj et link mere",
     "Create a new share link" : "Opret et nyt delingslink",
     "View only" : "Kun visning",
@@ -146,6 +130,8 @@ OC.L10N.register(
     "Guest" : "Gæst",
     "Group" : "Gruppe",
     "Email" : "E-mail",
+    "File drop" : "Fil drop",
+    "Terms of service" : "Servicebetingelser",
     "Allow upload and editing" : "Tillad upload og redigering",
     "Allow editing" : "Tillad redigering",
     "Advanced settings" : "Avancerede indstillinger",
@@ -157,23 +143,19 @@ OC.L10N.register(
     "Create" : "Opret",
     "Edit" : "Rediger",
     "Share" : "Del",
+    "Delete" : "Slet",
     "Others with access" : "Andre med adgang",
     "Toggle list of others with access to this directory" : "Vis/skjul liste over andre med adgang til denne mappe",
     "Toggle list of others with access to this file" : "Vis/skjul liste over andre med adgang til denne fil",
+    "Shares" : "Delinger",
     "Shared with you by {owner}" : "Delt med dig {owner}",
     "Open in Files" : "Vis i filer",
     "Shared" : "Delt",
-    "Shared by" : "Delt af",
-    "Shared with" : "Delt med",
-    "Shared with you and the group {group} by {owner}" : "Delt med dig og grupp {group} af {owner}",
-    "Shared with you and {circle} by {owner}" : "Delt med dig og {circle} af {owner}",
-    "Shared with you and the conversation {conversation} by {owner}" : "Delt med dig og konversationen {conversation} af {owner}",
-    "Shared with you in a conversation by {owner}" : "Delt med dig og konversationen af {owner}",
-    "Shares" : "Delinger",
+    "Shared with others" : "Delt med andre",
+    "No file" : "Ingen fil",
     "No shares" : "Ingen delinger",
     "Shared with you" : "Delt med dig",
     "Nothing shared with you yet" : "Der deles ikke noget med dig endnu",
-    "Shared with others" : "Delt med andre",
     "Nothing shared yet" : "Der deles endnu ikke noget",
     "Shared by link" : "Delt via link",
     "No shared links" : "Ingen delte link",
@@ -181,33 +163,43 @@ OC.L10N.register(
     "No deleted shares" : "Ingen slettede delinger",
     "Pending shares" : "Afventende delinger",
     "No pending shares" : "Ingen afventende delinger",
+    "Shared by" : "Delt af",
+    "Shared with" : "Delt med",
+    "Shared with you and the group {group} by {owner}" : "Delt med dig og grupp {group} af {owner}",
+    "Shared with you and {circle} by {owner}" : "Delt med dig og {circle} af {owner}",
+    "Shared with you and the conversation {conversation} by {owner}" : "Delt med dig og konversationen {conversation} af {owner}",
+    "Shared with you in a conversation by {owner}" : "Delt med dig og konversationen af {owner}",
     "Share note" : "Del note",
+    "Show list view" : "Vis som liste",
+    "Show grid view" : "Vis som gitter",
     "Upload files to %s" : "Upload filer til %s",
     "Note" : "Note",
     "Select or drop files" : "Vælg eller slip filer",
     "Uploading files" : "Uploader filer",
     "Uploaded files:" : "Uploadede filer:",
+    "Share not found" : "Delt fil ikke fundet",
+    "Back to %s" : "Tilbage til %s",
     "Add to your Nextcloud" : "Tilføj til din Nextcloud",
-    "Files and folders others share with you will show up here" : "Filer og mapper som andre deler med dig, vil blive vist her",
-    "Files and folders you share will show up here" : "Filer og mapper som du deler, vil blive vist her",
-    "Files and folders you share by link will show up here" : "Filer og mapper som du deler gennem link, vil blive vist her",
-    "Shares you deleted will show up here" : "Delinger du har slettet vil dukke op her",
-    "Shares you have received but not confirmed will show up here" : "Delinger du har modtaget men ikke accepteret vil dukke op her",
-    "Shares will show up here" : "Delinger vil dukke op her",
-    "Restore" : "Gendan",
-    "Something happened. Unable to restore the share." : "Der skete et eller andet. Ude af stand til at genskabe delingen.",
-    "Something happened. Unable to accept the share." : "Der skete et eller andet. Ude af stand til at acceptere delingen.",
-    "Something happened. Unable to reject the share." : "Der skete et eller andet. Ude af stand til at afvise delingen.",
-    "No expiration date set" : "Ingen udløbsdato sat",
+    "Waiting…" : "Venter …",
+    "error" : "fejl",
+    "finished" : "Færdiggjort",
+    "This will stop your current uploads." : "Dette vil stoppe din nuværende uploads.",
+    "Move or copy" : "Flyt eller kopier",
+    "You can upload into this folder" : "Du kan overføre til denne mappe",
+    "No compatible server found at {remote}" : "Ingen kompatible servere fundet på {remote}",
+    "Invalid server URL" : "Ugyldig server adresse",
+    "Failed to add the public link to your Nextcloud" : "Fejl ved tilføjelse af offentligt link til din Nextcloud",
+    "Files" : "Filer",
     "Please specify a valid user" : "Angiv en gyldig bruger",
+    "You cannot share to a Circle if the app is not enabled" : "Du kan ikke dele en CIrkel hvis appen ikke er aktiveret",
+    "Please specify a valid circle" : "Venligst angiv en gyldig cirkel",
     "Read only" : "Skrivebeskyttet",
     "File drop (upload only)" : "Fil drop (kun upload)",
     "Upload" : "Send",
     "Only works for users with access to this folder" : "Virker kun for brugere med adgang til denne folder",
     "Only works for users with access to this file" : "Virker kun for brugere med adgang til denne fil",
-    "File drop" : "Fil drop",
+    "Enter a date" : "Indtast en dato",
     "Circle" : "Cirkel",
-    "Update" : "Opdatér",
     "No other users with access found" : "Ingen andre brugere med adgang fundet",
     "No entries found in this folder" : "Der blev ikke fundet poster i denne mappe",
     "Name" : "Navn",
