@@ -6,8 +6,6 @@ OC.L10N.register(
     "Read more" : "Leggi altro",
     "Disable announcements" : "Disabilita annunci",
     "(These announcements are only shown to administrators)" : "(Questi annunci sono mostrati solo agli amministratori)",
-    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Gli annunci di Nextcloud portano le ultime notizie di Nextcloud nelle tue notifiche",
-    "Shows the latest news of Nextcloud in your notifications." : "Mostra le ultime novità di Nextcloud nelle tue notifiche.",
-    "These groups will be notified about the announcements." : "Questi gruppi riceveranno notifiche relative agli annunci."
+    "Nextcloud announcements brings the latest news of Nextcloud into your notifications" : "Gli annunci di Nextcloud portano le ultime notizie di Nextcloud nelle tue notifiche"
 },
 "nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
