@@ -4,19 +4,38 @@ OC.L10N.register(
     "Privacy" : "Ochrana osobných údajov",
     "-" : "–",
     "The privacy center shows you where your data is stored and who can access it, either because you shared with them or because they are administrators." : "Centrum ochrany osobných údajov vám ukáže, kde sú vaše údaje uložené a kto k nim má prístup, buď preto, že ste ich niekomu sprístupnili vy alebo boli sprístupnené správcami.",
+    "Administrators" : "Administrátori",
     "Add external admin" : "Pridať externého správcu",
+    "Cancel" : "Zrušiť",
+    "Add" : "Pridať",
     "Name of external admin" : "Meno externého správcu",
+    "Encryption" : "Šifrovanie",
+    "Edit" : "Úprava",
     "This server is using full-disk-encryption." : "Tento server používa šifrovanie celého úložiska.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key based on their configuration." : "Vaše súbory na externých úložiskách môžu byť šifrované pomocou {linkopen} šifrovania na strane servera ↗ {linkclose} s hlavným kľúčom na základe ich konfigurácie.",
     "Your files on external storages may be encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual key based on their configuration." : "Vaše súbory vo externých úložiskách môžu byť šifrované pomocou {linkopen} šifrovania na strane servera ↗ {linkclose} s individuálnym kľúčom na základe ich konfigurácie.",
     "Additionally, this server is protected with full-disk-encryption." : "Naviac, tento server je chránený šifrovaním celého úložiska.",
     "This server is protected with full-disk-encryption." : "Tento server je chránený šifrovaním celého úložiska.",
     "Your files are not protected by encryption." : "Vaše súbory nie sú chránené šifrovaním.",
+    "Privacy policy" : "Zásady ochrany osobných údajov",
+    "Who has access to your data?" : "Kto má prístup v vašim dátam?",
+    "Where is your data?" : "Kde sa nachádzajú vaše dáta?",
     "Your data is located in:" : "Vaše dáta sa nachádzajú v krajine:",
-    "The admin has not selected the location of the server yet." : "Správca zatiaľ nezadal umiestnenie servera.",
     "Change data location" : "Zmena umiestnenia údajov",
+    "Region" : "Región",
     "Please select a region" : "Vyberte oblasť",
-    "You don't have any shares with individual users." : "Nesprístupňujete žiadne súbory iným používateľom.",
+    "User Data Manifesto 2.0" : "Manifest o používateľských údajoch, verzia 2.0",
+    "Control" : "Kontrola",
+    "over user data access" : "nad prístupom k údajom používateľa",
+    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Údaje výslovne a dobrovoľne odovzdané používateľom by mali byť pod konečnou kontrolou používateľa. Používatelia by mali mať možnosť rozhodnúť sa, komu udelia priamy prístup k svojim údajom a s ktorými povoleniami a licenciami by sa mal takýto prístup udelovať.",
+    "Knowledge" : "Znalosť",
+    "of how the data is stored" : "ako sú údaje uchovávané",
+    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Keď sa údaje nahrávajú ku konkrétnemu poskytovateľovi služieb, používatelia by mali byť informovaní o tom, kde tento poskytovateľ služieb ukladá tieto údaje, ako dlho, v akej jurisdikcii konkrétny poskytovateľ služieb pôsobí a aké právne predpisy sa voči týmto údajom uplatňujú.",
+    "Freedom" : "Sloboda",
+    "to choose a platform" : "zvoliť si platformu",
+    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Používatelia by mali mať vždy možnosť extrahovať svoje údaje zo služby kedykoľvek, bez toho, aby pri tom narazili na nepostrádateľnosť od výrobcu resp. poskytovateľa. Na zabezpečenie tohto sú potrebné otvorené normy pre formáty a protokoly.",
+    "Learn more ↗" : "Viac informácií ↗",
+    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vaše údaje predstavujú kto ste a môžu byť ľahko zneužité. My v spoločnosti Nextcloud veríme, že máte právo rozhodnúť sa, ako sa bude s nimi nakladať. Nextcloud chráni vaše práva definované v Manifeste o používateľských údajoch.",
     "Somaliland" : "Soomaalilandská republika",
     "Andorra" : "Andorra",
     "United Arab Emirates" : "Spojené Arabské Emiráty",
@@ -111,9 +130,9 @@ OC.L10N.register(
     "Guam" : "Guam",
     "Guinea-Bissau" : "Guinea-Bissau",
     "Guyana" : "Guyana",
-    "Honduras" : "Honduras",
     "Hong Kong" : "Hong Kong",
     "Heard Island and McDonald Islands" : "Heardove a McDonaldove ostrovy",
+    "Honduras" : "Honduras",
     "Croatia" : "Chorvátsko",
     "Haiti" : "Haiti",
     "Hungary" : "Maďarsko",
@@ -263,29 +282,6 @@ OC.L10N.register(
     "Mayotte" : "Mayotte",
     "South Africa" : "Juhoafrická republika",
     "Zambia" : "Zambia",
-    "Zimbabwe" : "Zimbabwe",
-    "Your %s account" : "Váš účet %s",
-    "Your data represents who you are and can easily be abused. We at Nextcloud believe that you have a right to decide what happens with your data. Nextcloud protects your rights as defined in the User Data Manifesto!" : "Vaše údaje predstavujú kto ste a môžu byť ľahko zneužité. My v spoločnosti Nextcloud veríme, že máte právo rozhodnúť sa, ako sa bude s nimi nakladať. Nextcloud chráni vaše práva definované v Manifeste o používateľských údajoch.",
-    "User Data Manifesto 2.0" : "Manifest o používateľských údajoch, verzia 2.0",
-    "Defining basic rights for people to control their own data in the internet age" : "Definovanie základných práv ľudí na kontrolu vlastných údajov vo veku internetu",
-    "Control" : "Kontrola",
-    "over user data access" : "nad prístupom k údajom používateľa",
-    "Data explicitly and willingly uploaded by a user should be under the ultimate control of the user. Users should be able to decide whom to grant direct access to their data and with which permissions and licenses such access should be granted." : "Údaje výslovne a dobrovoľne odovzdané používateľom by mali byť pod konečnou kontrolou používateľa. Používatelia by mali mať možnosť rozhodnúť sa, komu udelia priamy prístup k svojim údajom a s ktorými povoleniami a licenciami by sa mal takýto prístup udelovať.",
-    "Knowledge" : "Znalosť",
-    "of how the data is stored" : "ako sú údaje uchovávané",
-    "When the data is uploaded to a specific service provider, users should be informed about where that specific service provider stores the data, how long, in which jurisdiction the specific service provider operates, and which laws apply." : "Keď sa údaje nahrávajú ku konkrétnemu poskytovateľovi služieb, používatelia by mali byť informovaní o tom, kde tento poskytovateľ služieb ukladá tieto údaje, ako dlho, v akej jurisdikcii konkrétny poskytovateľ služieb pôsobí a aké právne predpisy sa voči týmto údajom uplatňujú.",
-    "Freedom" : "Sloboda",
-    "to choose a platform" : "zvoliť si platformu",
-    "Users should always be able to extract their data from the service at any time without experiencing any vendor lock-in. Open standards for formats and protocols are necessary to guarantee this." : "Používatelia by mali mať vždy možnosť extrahovať svoje údaje zo služby kedykoľvek, bez toho, aby pri tom narazili na nepostrádateľnosť od výrobcu resp. poskytovateľa. Na zabezpečenie tohto sú potrebné otvorené normy pre formáty a protokoly.",
-    "Learn more ↗" : "Viac informácií ↗",
-    "Where is your data?" : "Kde sa nachádzajú vaše dáta?",
-    "Who has access to your data?" : "Kto má prístup v vašim dátam?",
-    "Administrators" : "Administrátori",
-    "People you shared with" : "Ľudia s ktorými ste zdieľali",
-    "Privacy policy" : "Zásady ochrany osobných údajov",
-    "Read the privacy policy." : "Prečítať si zásady ochrany osobných údajov",
-    "Encryption" : "Šifrovanie",
-    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with a master key." : "Vaše domáce úložisko je šifrované pomocou {linkopen}server-side-encryption ↗{linkclose} s hlavným kľúčom.",
-    "Your home storage is encrypted using {linkopen}server-side-encryption ↗{linkclose} with an individual user key." : "Vaše domáce úložisko je šifrované pomocou šifrovania {linkopen} na strane servera ↗ {linkclose} pomocou individuálneho používateľského kľúča."
+    "Zimbabwe" : "Zimbabwe"
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
