@@ -1,14 +1,9 @@
 OC.L10N.register(
     "settings",
     {
-    "Migration in progress. Please wait until the migration is finished" : "La migración está en curso. Por favor espera hasta que termine la migración",
-    "Migration started …" : "La migración ha comenzado ...",
-    "Saved" : "Guardado",
-    "Not saved" : "No guardado",
-    "Sending…" : "Enviando...",
-    "Email sent" : "Correo electrónico enviado",
     "Private" : "Privado",
     "Local" : "Local",
+    "Federated" : "Federado",
     "Verify" : "Verificar",
     "Verifying …" : "Verificando ...",
     "Unable to change password" : "No fue posible cambiar la contraseña",
@@ -17,7 +12,6 @@ OC.L10N.register(
     "So-so password" : "Contraseña aceptable",
     "Good password" : "Buena contraseña",
     "Strong password" : "Contraseña fuerte",
-    "Select a profile picture" : "Selecciona una imagen de perfil",
     "Groups" : "Grupos",
     "{actor} changed your password" : "{actor} ha cambiado tu contraseña",
     "You changed your password" : "Cambiaste tu contraseña",
@@ -29,22 +23,20 @@ OC.L10N.register(
     "You successfully logged in using two-factor authentication (%1$s)" : "Has iniciado sesión exitosamente usando autenticación de dos-factores (%1$s)",
     "A login attempt using two-factor authentication failed (%1$s)" : "Un intento de autenticación usando autenticación de dos-factores ha fallado (%1$s)",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Tu <strong>contraseña</strong> o <strong>correo electrónico</strong> ha sido modificado",
-    "Couldn't remove app." : "No fue posible eliminar la aplicación. ",
-    "Couldn't update app." : "No fue posible actualizar la aplicación.",
+    "Settings" : "Configuraciones ",
     "Wrong password" : "Contraseña incorrecta",
-    "No user supplied" : "No se proporcionó usuario alguno",
+    "Saved" : "Guardado",
     "Authentication error" : "Error de autenticación",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
     "Wrong admin recovery password. Please check the password and try again." : "Contraseña de recuperación de administrador incorrecta. Por favor verificala e inténtalo de nuevo.",
-    "Backend doesn't support password change, but the user's encryption key was updated." : "El backend no soporta el cambio de contraseñas, pero la llave de encripción del usuario fue actualizada.",
-    "Federated Cloud Sharing" : "Compartir en la Nube Federada",
+    "Administrator documentation" : "Documentación del adminsitrador",
+    "User documentation" : "Documentación del usuario",
     "Invalid SMTP password." : "Constraseña SMTP inválida. ",
     "Email setting test" : "Prueba de ajustes de correo",
     "Well done, %s!" : "¡Bien hecho, %s!",
     "If you received this email, the email configuration seems to be correct." : "Si has recibido este correo electrónico, la configuración del correo electrónico parece estar correcta. ",
     "Email could not be sent. Check your mail server log" : "No fue posible enviar el correo electrónico. Por favor verfica la bitácora de tu servidor de correo",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Se presentó un problema al enviar el correo electrónico. Por favor revisa tus configuraciones (Error: %s)",
-    "You need to set your user email before being able to send test emails." : "Requieres establecer tu correo electrónico antes de poder enviar correos electrónicos de prueba. ",
+    "Invalid account" : "Cuenta inválida",
     "Invalid mail address" : "Dirección de correo inválida",
     "Settings saved" : "Se han guardado las configuraciones ",
     "Unable to change full name" : "No fue posible cambiar el nombre completo",
@@ -66,197 +58,174 @@ OC.L10N.register(
     "Welcome aboard" : "Bienvenido a bordo",
     "Welcome aboard %s" : "Bienvenido a bordo %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Bienvenido a tu cuenta %s, puedes agregar, proteger y compartir tus datos.",
-    "Your username is: %s" : "Tu Usuario es: %s",
     "Set your password" : "Establece tu contraseña",
     "Go to %s" : "Ir a %s",
     "Install Client" : "Instalar el cliente",
     "Apps" : "Aplicaciones",
-    "Settings" : "Configuraciones ",
     "Personal" : "Personal",
     "Administration" : "Administración",
+    "Users" : "Usuarios",
     "Additional settings" : "Configuraciones adicionales",
     "Basic settings" : "Configuraciones  básicas",
     "Sharing" : "Compartiendo",
+    "Calendar" : "Calendario",
     "Personal info" : "Información Personal",
-    "Create" : "Crear",
-    "Change" : "Cambiar",
-    "Delete" : "Borrar",
+    "Email server" : "Servidor de correo electrónico",
+    "Security & setup warnings" : "Advertencias de seguridad y configuración",
+    "Background jobs" : "Trabajos en segundo plano",
     "Unlimited" : "Ilimitado",
     "Verifying" : "Verificando",
+    "Disabled" : "Deshabilitado",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
+    "None" : "Ninguno",
+    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
+    "Allow resharing" : "Permitir volver a compartir",
+    "Allow sharing with groups" : "Permitir compartir con grupos",
+    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
+    "Allow public uploads" : "Permitir cargas públicas",
+    "Always ask for a password" : "Siempre pedir una contraseña",
+    "Enforce password protection" : "Forzar protección de contraseñas",
+    "Enforce expiration date" : "Forzar fecha de expiración",
+    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de la liga pública cuando la lista de archivos esté oculta. ",
     "Limit to groups" : "Limitar a grupos",
     "Save changes" : "Guardar cambios",
+    "Remove" : "Eliminar",
+    "Disable" : "Deshabilitar",
+    "Featured" : "Destacado",
+    "Icon" : "Ícono",
+    "Name" : "Nombre",
+    "Version" : "Versión",
+    "Level" : "Nivel",
+    "Actions" : "Acciones",
+    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
+    "Loading" : "Cargando",
+    "Description" : "Descripción",
+    "Details" : "Detalles",
     "All" : "Todos",
     "No results" : "No hay resultados",
     "Update to {version}" : "Actualizar a {version}",
-    "Remove" : "Eliminar",
-    "Disable" : "Deshabilitar",
     "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión mínima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Esta aplicación no cuenta con una versión máxima de Nextcloud asignada. Esto será un error en el futuro.",
     "This app cannot be installed because the following dependencies are not fulfilled:" : "Esta aplicación no puede ser instalada porque las siguientes dependencias no están satisfechas:",
+    "Categories" : "Categorías",
+    "Resources" : "Recursos",
+    "Documentation" : "Documentación",
+    "Report a bug" : "Reporta un detalle",
+    "Request feature" : "Solicitar una funcionalidad",
+    "Ask questions or discuss" : "Hacer una pregunta o comentario",
+    "Rate" : "Calificar",
     "View in store" : "Ver en la tienda",
     "Visit website" : "Visita el sitio web",
-    "Report a bug" : "Reporta un detalle",
-    "User documentation" : "Documentación del usuario",
     "Admin documentation" : "Documentación del administrador",
     "Developer documentation" : "Documentación del desarrollador",
-    "Featured" : "Destacado",
-    "No apps found for your version" : "No se encontraron aplicaciones para tu versión",
-    "Enable all" : "Habilitar todo",
+    "Changelog" : "Bitácora de cambios",
     "Allow filesystem access" : "Permitir acceso al sistema de archivos",
     "Rename" : "Renombrar",
     "Revoke" : "Revocar",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
     "Google Chrome for Android" : "Google Chrome para Android",
-    "Sync client - {os}" : "Sync client - {os}",
     "This session" : "Esta sesión",
     "Device" : "Dispositivo",
     "Last activity" : "Última actividad",
     "Web, desktop and mobile clients currently logged in to your account." : "Clientes web, de escritorio y móviles han iniciado sesión en tu cuenta. ",
-    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
-    "Error while deleting the token" : "Se presentó un error al borrar la ficha",
     "App name" : "Nombre de la aplicación",
     "Create new app password" : "Crear una nueva contraseña de aplicación",
-    "Use the credentials below to configure your app or device." : "Usa las siguientes credenciales para configurar tu aplicación o dispositivo. ",
-    "For security reasons this password will only be shown once." : "Por razones de seguridad esta contraseña sólo se mostrará una vez. ",
-    "Username" : "Usuario",
-    "Password" : "Contraseña",
-    "Done" : "Terminado",
-    "Copied!" : "¡Copiado!",
-    "Copy" : "Copiar",
-    "Add" : "Agregar",
-    "Your email address" : "Tu dirección de correo electrónico",
-    "No email address set" : "No se ha establecido la dirección de correo electrónico",
-    "Email" : "Correo electrónico",
-    "Cancel" : "Cancelar",
-    "{size} used" : "{size} usado",
-    "Display name" : "Nombre a desplegar",
-    "Group admin for" : "Administrador del grupo para",
-    "Quota" : "Cuota",
-    "Language" : "Idioma",
-    "User backend" : "Backend del usuario",
-    "Storage location" : "Úbicación del almacenamiento",
-    "Last login" : "Último inicio de sesión",
-    "Default quota" : "Cuota predeterminada",
-    "All languages" : "Todos los idiomas",
-    "Unnamed device" : "Dispositivo sin nombre",
-    "Your apps" : "Tus aplicaciones",
-    "Disabled apps" : "Aplicaciones deshabilitadas",
-    "Updates" : "Actualizaciones",
-    "App bundles" : "Paquetes de aplicación",
-    "Details" : "Detalles",
-    "Changelog" : "Bitácora de cambios",
-    "Add group" : "Agregar grupo",
-    "Admins" : "Administradores",
-    "Show last login" : "Mostrar último inicio de sesión",
-    "Show user backend" : "Mostrar backend del usuario",
-    "Send email to new user" : "Enviar un correo electrónico al usuario nuevo",
-    "Enable" : "Habilitar",
-    "Never" : "Nunca",
-    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
-    "App update" : "Actualización de la aplicación",
-    "Administrator documentation" : "Documentación del adminsitrador",
-    "Documentation" : "Documentación",
-    "Forum" : "Foro",
-    "None" : "Ninguno",
+    "Error while creating device token" : "Se presentó un error al crear la ficha en el dispositivo",
     "Login" : "Iniciar sesión",
-    "Plain" : "Plano",
-    "NT LAN Manager" : "Administrador de LAN NT",
-    "SSL/TLS" : "SSL/TLS",
-    "STARTTLS" : "STARTTLS",
-    "Email server" : "Servidor de correo electrónico",
-    "Open documentation" : "Abrir documentación",
-    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
-    "Send mode" : "Modo de envío",
-    "Encryption" : "Encripción",
-    "From address" : "De la dirección",
-    "Authentication method" : "Método de autenticación",
-    "Authentication required" : "Autenticación requerida",
-    "Server address" : "Dirección del servidor",
-    "Port" : "Puerto",
-    "Credentials" : "Credenciales",
-    "SMTP Username" : "Usuario SMTP",
-    "SMTP Password" : "Contraseña SMTP",
-    "Save" : "Guardar",
-    "Test email settings" : "Probar las configuraciones de correo electrónico",
-    "Send email" : "Enviar correo electrónico",
-    "Security & setup warnings" : "Advertencias de seguridad y configuración",
-    "All checks passed." : "Pasaron todas las verificaciones. ",
-    "Version" : "Versión",
+    "Password" : "Contraseña",
+    "Enable" : "Habilitar",
     "Server-side encryption" : "Encripción del lado del servidor",
     "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "La encripción del lado del servidor hace posible encriptar archivos que serán cargados a este servidor. Esto trae consigo algunas limitaciónes como penalizaciones en el desemeño, asi que habilítalo sólo si es necesario. ",
     "Enable server-side encryption" : "Habilitar encripción del lado del servidor",
-    "Please read carefully before activating server-side encryption: " : "Por favor lee detenidamente antes de activar la encripción del lado de servidor:",
     "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Una vez que la encripción se encuentre habilitada, todos lo archivos cargados al servidor desde ese momento en tiempo, se encriptarán en el servidor. Sólo será posible deshabilitar la encripción en una fecha posterior si el modulo de encripción activo soporta esa funcionalidad y si todas las preciondiciones están satisfechas (ejem. establecer una llave de recuperación).",
     "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "La encripción por sí sola no garantiza la seguridad del sistema. Por favor consulta la documentación para mayores informes de cómo funciona la aplicación de encripción y de los casos de uso soportados. ",
     "Be aware that encryption always increases the file size." : "Por favor considera que la encripción siempre aumenta el tamaño de los archivos. ",
     "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Siempre es una buena idea generar respaldos de tus datos, en caso de tener encripción asegúrate de respaldar las llaves de encripción junto con tus datos. ",
     "This is the final warning: Do you really want to enable encryption?" : "Esta es la advertencia final: ¿Realmente deseas habilitar la encripción?",
-    "Enable encryption" : "Habilitar encripción",
     "No encryption module loaded, please enable an encryption module in the app menu." : "No se ha cargado un módulo de encripción, por favor habilita un módulo de encripción en el menú de la aplicación. ",
     "Select default encryption module:" : "Selecciona el modulo de encripción predeterminado:",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one. Please enable the \"Default encryption module\" and run 'occ encryption:migrate'" : "Necesitas migrar tus llaves de encripción de la encripción anterior (ownCloud <= 8.0) a la actual. Por favor habilita el \"Módulo de encripción predeterminado\" y ejecuta el comando 'occ encryption:migrate'",
-    "You need to migrate your encryption keys from the old encryption (ownCloud <= 8.0) to the new one." : "Necesitas migar tus llaves de encripción de la encripción anterior (ownCloud <=8.0) a la actual. ",
-    "Start migration" : "Iniciar migración",
-    "Background jobs" : "Trabajos en segundo plano",
-    "Last job execution ran %s. Something seems wrong." : "La última ejecución del trabajo corrió %s. Algo parece estar mal. ",
-    "Last job ran %s." : "El último trabajo corrió %s.",
-    "Background job didn’t run yet!" : "¡El trabajo de segundo plano aún no ha corrido!",
-    "For optimal performance it's important to configure background jobs correctly. For bigger instances 'Cron' is the recommended setting. Please see the documentation for more information." : "Para un desempeño ideal, es importante configurar los trabajos de fondo correctamente. Para instancias más grandes 'Cron' es la configuración recomendada. Por favor consulta la documentación para más información. ",
-    "The cron.php needs to be executed by the system user \"%s\"." : "El cron.php necesita ser ejecutado por el usuario de sistema \"%s\".",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "Para correr esto necesitas la extensión POSIX de PHP. Por favor ve la {linkstart}documentación de PHP{linkend} para más detalles. ",
-    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
-    "Allow apps to use the Share API" : "Permitir que las aplicaciones usen el API para Compartir",
-    "Enforce expiration date" : "Forzar fecha de expiración",
-    "Allow public uploads" : "Permitir cargas públicas",
-    "Always ask for a password" : "Siempre pedir una contraseña",
-    "Enforce password protection" : "Forzar protección de contraseñas",
-    "Allow resharing" : "Permitir volver a compartir",
-    "Allow sharing with groups" : "Permitir compartir con grupos",
-    "Restrict users to only share with users in their groups" : "Limitar a los usuarios a sólo compartir con otros usuarios en sus grupos",
-    "Exclude groups from sharing" : "Evitar que los grupos compartan",
-    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
-    "This text will be shown on the public link upload page when the file list is hidden." : "Este texto se mostrará en la página de carga de la liga pública cuando la lista de archivos esté oculta. ",
-    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
-    "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
-    "Follow us on Twitter" : "Síguenos en Twitter",
-    "Check out our blog" : "Visita nuestro blog",
-    "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
-    "Profile picture" : "Foto de perfil",
-    "Upload new" : "Cargar nuevo",
-    "Select from Files" : "Seleccionar desde Archivos",
-    "Remove image" : "Eliminar imagen",
-    "png or jpg, max. 20 MB" : "png o jpg max. 20 MB",
-    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
-    "Choose as profile picture" : "Seleccionar como foto del perfil",
-    "Full name" : "Nombre completo",
-    "No display name set" : "No se ha establecido el nombre a desplegar",
-    "Phone number" : "Número de teléfono",
-    "Your phone number" : "Su número telefónico",
-    "Address" : "Dirección",
-    "Your postal address" : "Tu dirección postal",
-    "Website" : "Sitio web",
-    "It can take up to 24 hours before the account is displayed as verified." : "Puede tomar hasta 24 horas antes de que la cuenta se muestre como verificada. ",
-    "Link https://…" : "Liga https:// ...",
-    "Twitter" : "Twitter",
-    "Twitter handle @…" : "Cuenta de twitter @...",
-    "Help translate" : "Ayuda a traducir",
+    "Cancel" : "Cancelar",
+    "Confirm" : "Confirmar",
+    "Submit" : "Enviar",
     "Current password" : "Contraseña actual",
     "New password" : "Nueva contraseña",
     "Change password" : "Cambiar contraseña",
-    "Public" : "Público",
-    "installing and updating apps via the app store or Federated Cloud Sharing" : "Instalando y actualizando aplicaciones por la tienda de aplicaciones o Compartido la Nube Federada",
-    "Close" : "Cerrar",
-    "Everyone" : "Todos",
-    "The app will be downloaded from the app store" : "La aplicación será descargada de la tienda de aplicaciones <app store>",
-    "Error: This app can not be enabled because it makes the server unstable" : "Error: Esta aplicación no puede ser habilitada porque genera inestabilidad en el servidor",
-    "mail" : "correo",
-    "Expire after " : "Expirar después de",
-    "days" : "días",
-    "Allow users to share via link" : "Permitir a los usuarios compartir mediante ligas",
-    "For password reset and notifications" : "Para restablecer contraseña y notificaciones"
+    "Picture provided by original account" : "Imagen proporcionada por la cuenta original ",
+    "No email address set" : "No se ha establecido la dirección de correo electrónico",
+    "Help translate" : "Ayuda a traducir",
+    "Your phone number" : "Su número telefónico",
+    "Your website" : "Tu sitio web",
+    "Add" : "Agregar",
+    "Create" : "Crear",
+    "Change" : "Cambiar",
+    "Delete" : "Borrar",
+    "Display name" : "Nombre a desplegar",
+    "Email" : "Correo electrónico",
+    "Quota" : "Cuota",
+    "Language" : "Idioma",
+    "Avatar" : "Avatar",
+    "Group admin for" : "Administrador del grupo para",
+    "Storage location" : "Úbicación del almacenamiento",
+    "Last login" : "Último inicio de sesión",
+    "Account actions" : "Acciones de la cuenta",
+    "{size} used" : "{size} usado",
+    "Delete account" : "Borrar cuenta",
+    "Done" : "Terminado",
+    "Edit" : "Editar",
+    "Show last login" : "Mostrar último inicio de sesión",
+    "Send email" : "Enviar correo electrónico",
+    "Default quota" : "Cuota predeterminada",
+    "Unnamed device" : "Dispositivo sin nombre",
+    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Como administrador, puedes hacer ajustes finos al comportamiento de compartir. Por favor consulta la documentación para más información. ",
+    "Admins" : "Administradores",
+    "Group name" : "Nombre del grupo",
+    "Sending…" : "Enviando...",
+    "Email sent" : "Correo electrónico enviado",
+    "Location" : "Ubicación",
+    "Profile picture" : "Foto de perfil",
+    "About" : "Acerca",
+    "Full name" : "Nombre completo",
+    "Phone number" : "Número de teléfono",
+    "Website" : "Sitio web",
+    "Your apps" : "Tus aplicaciones",
+    "Disabled apps" : "Aplicaciones deshabilitadas",
+    "Updates" : "Actualizaciones",
+    "App bundles" : "Paquetes de aplicación",
+    "Hide" : "Ocultar",
+    "Never" : "Nunca",
+    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "La aplicación está habilitada pero necesita ser actualizada. Serás redireccionado a la página de actualización en 5 segundos. ",
+    "Error" : "Error",
+    "Forum" : "Foro",
+    "SSL" : "SSL",
+    "Open documentation" : "Abrir documentación",
+    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Es importante preparar este servidor para poder enviar correos electrónicos, como para restablecer contraseñas y notificaciones. ",
+    "Send mode" : "Modo de envío",
+    "Encryption" : "Encripción",
+    "From address" : "De la dirección",
+    "Server address" : "Dirección del servidor",
+    "Port" : "Puerto",
+    "Authentication" : "Autenticación",
+    "Authentication required" : "Autenticación requerida",
+    "Credentials" : "Credenciales",
+    "SMTP Password" : "Contraseña SMTP",
+    "Save" : "Guardar",
+    "All checks passed." : "Pasaron todas las verificaciones. ",
+    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Desarrollado por la  {communityopen}comunidad Nextcloud {linkclose}, el {githubopen}código fuente {linkclose} está licenciado bajo  {licenseopen}AGPL{linkclose}.",
+    "Like our Facebook page" : "Da un Like a nuestra página de Facebook",
+    "Check out our blog" : "Visita nuestro blog",
+    "Subscribe to our newsletter" : "Suscribete a nuestro boletín",
+    "No user supplied" : "No se proporcionó usuario alguno",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "Por favor proporciona una contraseña de recuperación de administrador; de lo contrario toda la información del usuario se perderá. ",
+    "Invalid user" : "Usuario inválido",
+    "Your username is: %s" : "Tu Usuario es: %s",
+    "Exclude groups from sharing" : "Evitar que los grupos compartan",
+    "These groups will still be able to receive shares, but not to initiate them." : "Estos grupos aún podrán recibir elementos compartidos, pero no los podrán iniciar.",
+    "Username" : "Usuario",
+    "User backend" : "Backend del usuario",
+    "Show user backend" : "Mostrar backend del usuario",
+    "Active users" : "Usuarios activos",
+    "SMTP Username" : "Usuario SMTP",
+    "Follow us on Twitter" : "Síguenos en Twitter"
 },
-"nplurals=2; plural=(n != 1);");
+"nplurals=3; plural=n == 1 ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
