@@ -323,7 +323,6 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "סיבות להשתמש ב־Nextcloud בארגון שלך",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "בפיתוח על ידי {communityopen}קהילת Nextcloud{linkclose}, {githubopen}קוד המקור{linkclose} זמין ברישיון {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "לייק לעמוד הפייסבוק שלנו",
-    "Follow us on Twitter" : "לעקוב אחרינו בטוויטר",
     "Follow us on Mastodon" : "למעקב אחרינו ב־Mastodon",
     "Check out our blog" : "לעיין בבלוג שלנו",
     "Subscribe to our newsletter" : "הרשמה לרשימת הדיוור שלנו",
@@ -331,70 +330,35 @@ OC.L10N.register(
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "אם משמשים אותך יישומי צד־שלישי להתחברות אל Nextcloud, נא לוודא יצירת והגדרת ססמה ליישומון לכל אחד מהם בטרם הפעלת אימות דו־שלבי.",
     "No user supplied" : "לא סופק שם משתמש",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "נא לספק ססמת שחזור של מנהלים, אחרת, כל נתוני המשתמשים ילכו לאיבוד.",
-    "Federated Cloud Sharing" : "ענן שיתוף מאוגד",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL משתמש בגרסה של %1$s שתוקפה פג (%2$s). נא לעדכן את מערכת ההפעלה או שתכונות כמו %3$s לא תפעלנה בצורה אמינה.",
     "Invalid user" : "משתמש שגוי",
     "Your username is: %s" : "שם המשתמש שלך הוא: %s",
     "Logged in user must be a subadmin" : "המשתמש שנכנס חייב להיות תת־מנהל",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "משימת רקע שבודקת את אישורי ה־SSL בייבוא המשתמש ממתינה. נא לדגום את הדף הזה שוב בהמשך.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "יש כמה אישורי SSL מיובאים קיימים שאינם בשימוש עוד ב־Nextcloud 21. אפשר לייבא אותם בשורת הפקודה עם הפקודה „occ security:certificates:import”. הנתיבים שלהם בתור תיקיית הנתונים מופיעים להלן.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה.",
+    "Exclude groups from sharing" : "מניעת קבוצות משיתוף",
+    "These groups will still be able to receive shares, but not to initiate them." : "קבוצות אלו עדיין יוכלו לקבל שיתופים, אך לא לשתף בעצמם.",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "ניתן לאכוף אימות דו־שלבי על כל המשתמשים ועל קבוצות מסוימות. אם אין להם ספק אימות דו־שלבי מוגדר, לא תהיה להם אפשרות להיכנס למערכת.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "כאשר קבוצות נבחרות/מוחרגות, הן משתמשות בלוגיקה הבאה כדי להחליט האם נאכף על המשתמש אימות דו־שלבי: אם לא נבחרו קבוצות, אימות דו־שלבי פעיל עבור כולם למעט החברים בקבוצות שהוחרגו. אם נבחרו קבוצות, אימות דו־שלבי מופעל לכל החברים של הקבוצות האלו. אם משתמש נמצא גם בקבוצה נבחרת וגם בקבוצה מוחרגת, הנבחרת מקבלת עדיפות ואימות דו־שלבי נאכף.",
-    "Enable all" : "הפעלת הכול",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "לקוח סנכרון - {os}",
-    "Error while deleting the token" : "שגיאה בזמן מחיקת המחרוזת",
-    "Use the credentials below to configure your app or device." : "יש להשתמש בפרטי הזיהוי שלהלן כדי להגדיר את היישומון או ההתקן שלך.",
-    "For security reasons this password will only be shown once." : "מטעמי אבטחה הססמה תופיע פעם אחת בלבד.",
+    "{license}-licensed" : "ברישיון {license}",
     "Username" : "שם משתמש",
-    "Copied!" : "הועתק!",
-    "Copy" : "העתקה",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "כדי להריץ זאת יש צורך בהרחבת POSIX ל־PHP. נא לעיין ב{linkstart}תיעוד של PHP{linkend} לפרטים נוספים.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "פעולה זו תסיר את הקבוצה {group}. המשתמשים ﬥﬡ יימחקו.",
-    "Please confirm the group removal " : "נא לאשר את הסרת הקבוצה",
-    "Your email address" : "כתובת הדואר האלקטרוני שלך",
+    "New user" : "משתמש חדש",
+    "User backend" : "מנגנון משתמש",
     "You do not have permissions to see the details of this user" : "אין לך הרשאות לצפות בפירוט על המשתמש",
-    "Add new password" : "הוספת ססמה חדשה",
-    "Add new email address" : "הוספת כתובת דוא״ל חדשה",
     "Set user as admin for" : "הגדרת משתמש כהנהלה של",
     "Select user quota" : "בחירת מכסת משתמש",
-    "Toggle user actions menu" : "החלפת מצב תפריט פעולות משתמש",
     "Delete user" : "מחיקת משתמש",
     "Wipe all devices" : "השמדת נתוני כל המכשירים",
     "Disable user" : "השבתת משתמש",
     "Enable user" : "הפעלת משתמש",
-    "Edit User" : "עריכת משתמש",
-    "New user" : "משתמש חדש",
-    "Will be autogenerated" : "ייווצר אוטומטית",
-    "Add a new user" : "הוספת משתמש חדש",
-    "User backend" : "מנגנון משתמש",
-    "No users in here" : "אין כאן משתמשים",
+    "Toggle user actions menu" : "החלפת מצב תפריט פעולות משתמש",
+    "Show user backend" : "הצגת צד אחורי למשתמש",
     "Name your device" : "מתן שם להתקן שלך",
     "Server error while trying to add WebAuthn device" : "אירעה שגיאת שרת בעת הניסיון להוספת התקן WebAuthn",
-    "{license}-licensed" : "ברישיון {license}",
     "by {author}\n{license}" : "מאת {author}\n{license}",
-    "Enter group name" : "נא להקליד שם קבוצה",
-    "Add group" : "הוספת קבוצה",
     "Active users" : "משתמשים פעילים",
     "Disabled users" : "משתמשים מושבתים",
-    "Default quota:" : "מכסת בררת מחדל:",
-    "Show Languages" : "הצגת שפות",
-    "Show user backend" : "הצגת צד אחורי למשתמש",
-    "Send email to new user" : "שליחת דואר אלקטרוני למשתמש חדש",
-    "Not saved" : "לא נשמר",
-    "Twitter" : "טוויטר",
-    "Enable untested app" : "לאפשר יישומון שלא נבדק",
     "SMTP Username" : "שם משתמש SMTP ",
-    "day(s)" : "ימים",
-    "Set default expiration date" : "הגדרת תאריך תפוגה ברירת מחדל",
-    "Exclude groups from sharing" : "מניעת קבוצות משיתוף",
-    "These groups will still be able to receive shares, but not to initiate them." : "קבוצות אלו עדיין יוכלו לקבל שיתופים, אך לא לשתף בעצמם.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "למסד הנתונים חסרים אינדקסים. כיוון שהוספת אינדקסים על טבלאות גדולות היא פעולה שגוזלת זמן רב הם לא נוספים אוטומטית. על ידי הרצת הפקודה „occ db:add-missing-indices” האינדקסים החסרים נוספים ידנית ללא עצירת פעולת העותק. לאחר הוספת האינדקסים השאילתות על הטבלאות האלה מהירות בהרבה."
+    "Follow us on Twitter" : "לעקוב אחרינו בטוויטר"
 },
 "nplurals=3; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: 2;");
