@@ -38,6 +38,8 @@ OC.L10N.register(
     "{actor} changed your email address" : "{actor} wijzigde je e-mailadres",
     "You changed your email address" : "Je wijzigde je e-mailadres",
     "Your email address was changed by an administrator" : "Je e-mailadres is gewijzigd door een beheerder",
+    "You created an app password for a session named \"{token}\"" : "Je creëerde een app wachtwoord voor een sessie genaamd \"{token}\"",
+    "An administrator created an app password for a session named \"{token}\"" : "Een beheerder maakte een app wachtwoord voor een sessie met de naam \"{token}\"",
     "You deleted app password \"{token}\"" : "Je verwijderde appwachtwoord \"{token}\"",
     "You renamed app password \"{token}\" to \"{newToken}\"" : "Je hernoemde appwachtwoord \"{token}\" naar \"{newToken}\"",
     "You granted filesystem access to app password \"{token}\"" : "Je hebt toegang tot het bestandssysteem verleend aan appwachtwoord \"{token}\"",
@@ -49,20 +51,29 @@ OC.L10N.register(
     "Remote wipe has finished on %1$s" : "Wissen op afstand voltooid op %1$s",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "Je <strong>wachtwoord</strong> of <strong>e-mailadres</strong> is gewijzigd",
     "Settings" : "Instellingen",
+    "Could not remove app." : "Kon app niet verwijderen",
+    "Could not update app." : "Kon app niet updaten",
     "Wrong password" : "Onjuist wachtwoord",
     "Unable to change personal password" : "Kan persoonlijk wachtwoord niet wijzigen",
     "Saved" : "Opgeslagen",
+    "No Login supplied" : "Geen login opgegeven",
     "Unable to change password. Password too long." : "Kan wachtwoord niet wijzigen. Wachtwoord te lang.",
     "Authentication error" : "Authenticatiefout",
+    "Please provide an admin recovery password; otherwise, all account data will be lost." : "Voer een beheerdersherstelwachtwoord in, anders zullen alle account gegevens verloren gaan.",
     "Wrong admin recovery password. Please check the password and try again." : "Onjuist beheerdersherstelwachtwoord. Controleer het wachtwoord en probeer het opnieuw.",
+    "Backend does not support password change, but the encryption of the account key was updated." : "Backend ondersteunt geen wachtwoordwijzigingen, maar de versleuteling van de accountsleutel is bijgewerkt.",
     "Administrator documentation" : "Beheerdersdocumentatie",
     "User documentation" : "Gebruikersdocumentatie",
+    "Nextcloud help overview" : "Nextcloud hulpoverzicht",
     "Invalid SMTP password." : "Ongeldig SMTP wachtwoord",
     "Email setting test" : "E-mailinstellingen test",
     "Well done, %s!" : "Goed gedaan, %s!",
     "If you received this email, the email configuration seems to be correct." : "Als je deze e-mail hebt ontvangen, dan lijken de e-mailinstellingen correct.",
     "Email could not be sent. Check your mail server log" : "Er kon geen e-mail verstuurd worden. Controleer je server log files",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Er ontstond een probleem bij het versturen van de e-mail. Controleer je instellingen.  (Fout: %s)",
+    "You need to set your account email before being able to send test emails. Go to %s for that." : "Je moet je e-mail voor je account instellen voordat je e-mail kan versturen. Ga hiervoor naar %s.",
+    "Recently active" : "Recent actief",
+    "Disabled accounts" : "Uitgeschakelde accounts",
     "Invalid account" : "Ongeldig account",
     "Invalid mail address" : "Ongeldig e-mailadres",
     "Settings saved" : "Instellingen opgeslagen",
@@ -89,14 +100,17 @@ OC.L10N.register(
     "Welcome aboard" : "Welkom aan boord",
     "Welcome aboard %s" : "Welkom aan boord %s",
     "Welcome to your %s account, you can add, protect, and share your data." : "Welkom bij je %s account; je kunt nu je bestanden toevoegen en veilig delen.",
+    "Your Login is: %s" : "Je login is: %s",
     "Set your password" : "Stel je wachtwoord in",
     "Go to %s" : "Ga naar %s",
     "Install Client" : "Installeer Client",
+    "Logged in account must be a subadmin" : "Aangemeld account moet een subadmin zijn",
     "Apps" : "Apps",
     "Personal" : "Persoonlijk",
     "Administration" : "Beheer",
     "Users" : "Gebruikers",
     "Additional settings" : "Aanvullende instellingen",
+    "Artificial Intelligence" : "Artificiële Intelligentie",
     "Administration privileges" : "Beheerdersprivileges",
     "Groupware" : "Groupware",
     "Overview" : "Overzicht",
@@ -111,8 +125,20 @@ OC.L10N.register(
     "Background jobs" : "Achtergrondtaken",
     "Unlimited" : "Ongelimiteerd",
     "Verifying" : "Controleer",
+    "Allowed admin IP ranges" : "Toegestane beheerder IP-reeksen",
+    "Admin IP filtering isn’t applied." : "Beheerder IP-filtering is niet toegepast.",
+    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "Configuratiesleutel \"%1$s\" verwacht een array (%2$s gevonden). Validatie van beheerder IP-bereik wordt niet toegepast.",
+    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "Configuratiesleutel \"%1$s\" bevat ongeldig(e) IP-bereik(en): \"%2$s\"",
+    "Admin IP filtering is correctly configured." : "Beheerder IP-filtering is juist geconfigureerd.",
+    "App directories owner" : "Eigenaar app mappen",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "Sommige app mappen zijn eigendom van een andere gebruiker dan op de webserver . Dat kan het geval zijn als apps handmatig zijn geïnstalleerd. Controleer de machtigingen van de volgende app mappen:\n%s",
+    "App directories have the correct owner \"%s\"" : "App mappen hebben de juiste eigenaar \"%s\"",
+    "Brute-force Throttle" : "Bruteforce begrenzing",
+    "Your remote address could not be determined." : "Je remote adres kon niet bepaald worden",
+    "Your remote address was identified as \"%s\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly." : "Je remote adres is geregistreerd als \"%s\" en wordt op dit moment afgeremd ter bescherming van bruteforce aanvallen. Dit verlaagt de performantie van verschillende aanvragen. Als het remote adres niet uw adres is kan dit wijzen op een verkeerd ingestelde proxy. ",
+    "Your remote address \"%s\" is not brute-force throttled." : "Je remote adres %s is niet bruteforce begrensd.",
+    "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Je datamap en je bestanden zijn waarschijnlijk vanaf het internet bereikbaar.  Het .htaccess-bestand werkt niet. We raden ten zeerste aan aan om je webserver zodanig te configureren, dat de datadirectory niet bereikbaar is vanaf het internet of om je datadirectory te verplaatsen naar een locatie buiten de document-root van de webserver.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "De database mist een paar optionele kolommen. Omdat het toevoegen van kolommen op grote tabellen veel tijd kan kosten, zijn ze niet automatisch gecreëerd, omdat dat optioneel kan. Door het draaien van \"occ db:add-missing-columns\" kunnen deze kolommen handmatig worden toegevoegd terwijl de server blijft draaien.  Als de kolommen zijn toegevoegd, zullen bepaalde functionaliteiten veel sneller of gemakkelijker plaatsvinden.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "De database mist een paar indexen. Omdat het toevoegen van indexen op grote tabellen veel tijd kan kosten, zijn ze niet automatisch gecreëerd. Door het draaien van \"occ db:add-missing-indices\" kunnen deze indexen handmatig worden toegevoegd terwijl de server blijft draaien.  Als de indexen zijn toegevoegd, zullen opvragingen op die tabellen veel sneller plaatsvinden.",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "De database mist enkele primaire sleutels. Omdat het toevoegen van primaire sleutels aan grote tabellen enige tijd kan duren, werden ze niet automatisch toegevoegd. Door \"occ db:add-missing-primary-keys\" uit te voeren, kunnen die ontbrekende primaire sleutels handmatig worden toegevoegd terwijl de server blijft draaien.",
     "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Deze instantie draait in debug modus. Gelieve deze modus enkel te gebruiken voor lokale ontwikkeling, en niet in productie omgevingen.",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Deze server heeft geen werkende internetverbinding: meerdere endpoints kunnen niet worden bereikt. Dat betekent dat sommige functies, zoals het gebruik van externe opslag, notificaties over updates of installatie van apps van derde partijen niet werken. Ook het benaderen van bestanden vanaf een remote locatie en het versturen van notificatie emails kan mislukken. We adviseren om de internetverbinding voor deze server in te schakelen als je alle functies wilt gebruiken.",
@@ -122,12 +148,17 @@ OC.L10N.register(
     "Supported" : "Ondersteund",
     "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Je PHP heeft geen FreeType ondersteuning. Dit zal leiden tot verminkte profielafbeeldingen en instellingeninterface.",
     "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP lijkt niet goed te zijn ingesteld voor opvragen systeemomgevingsvariabelen. De test met getenv(\"PATH\") gaf een leeg resultaat.",
+    "PHP modules" : "PHP modules",
     "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "De PHP OPcache is niet geladen.  Voor betere prestaties adviseren we die te laden in je php.ini instellingen.",
+    "PHP version" : "PHP versie",
+    "Secure" : "Beveiligd",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "De alleen-lezen config is ingeschakeld. Dit voorkomt het via de webinterface wijzigen van verschillende instellingen. Bovendien moet het bestand voor elke aanpassing handmatig op beschrijfbaar worden ingesteld.",
     "Architecture" : "Architectuur",
+    "64-bit" : "64-bit",
     "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Je database draait niet met \"READ COMMITTED\" transactie-isolatie niveau. Dit kan problemen opleveren als er meerdere acties tegelijkertijd worden uitgevoerd.",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "Profielfoto, volledige naam, e-mailadres, telefoonnummer, adres, website, Twitter, organisatie, rol, kop, biografie en of je profiel is ingeschakeld",
     "Nextcloud settings" : "Nextcloud instellingen",
+    "Task:" : "Taak:",
     "Here you can decide which group can access certain sections of the administration settings." : "Hier kun je beslissen welke groep toegang heeft tot bepaalde onderdelen van de beheerders instellingen.",
     "None" : "Geen",
     "Unable to modify setting" : "Kan instelling niet aanpassen",
@@ -139,13 +170,10 @@ OC.L10N.register(
     "Allow public uploads" : "Sta publieke uploads toe",
     "Always ask for a password" : "Vraag altijd naar een wachtwoord",
     "Enforce password protection" : "Dwing wachtwoordbeveiliging af",
-    "Exclude groups from sharing" : "Sta bepaalde groepen niet toe om te delen",
-    "These groups will still be able to receive shares, but not to initiate them." : "Deze groepen kunnen gedeelde mappen en bestanden ontvangen, maar kunnen zelf niks delen.",
     "Set default expiration date for shares" : "Instellen standaard vervaldatum voor deellinks",
     "Enforce expiration date" : "Het kiezen van een vervaldatum verplichten",
     "Set default expiration date for shares to other servers" : "Instellen standaard vervaldatum voor deellink naar andere servers",
     "If autocompletion \"same group\" and \"phone number integration\" are enabled a match in either is enough to show the user." : "Als automatisch aanvullen \"dezelfde groep\" en \"telefoonnummer integratie\" zijn ingeschakeld, is een overeenkomst in een van beide voldoende om de gebruiker te tonen.",
-    "Allow username autocompletion to users based on phone number integration" : "Toestaan automatisch aanvullen van gebruikersnamen gebaseerd op telefoonnummer integratie",
     "Allow autocompletion when entering the full name or email address (ignoring missing phonebook match and being in the same group)" : "Automatisch aanvullen toestaan bij het invoeren van de volledige naam of het e-mailadres (ontbrekende overeenkomst in het telefoonboek negeren en deel uitmaken van dezelfde groep)",
     "Show disclaimer text on the public link upload page (only shown when the file list is hidden)" : "Toon disclaimer tekst op de publieke link upload pagina (alleen getoond wanneer de bestandslijst verborgen is)",
     "This text will be shown on the public link upload page when the file list is hidden." : "Deze tekst wordt getoond op de openbare link uploadpagina als het bestandsoverzicht is verborgen.",
@@ -159,24 +187,12 @@ OC.L10N.register(
     "Two-factor authentication is not enforced for members of the following groups." : "Tweetrapsauthenticatie wordt niet geforceerd voor leden van de volgende groepen.",
     "Excluded groups" : "Uitgesloten groepen",
     "Save changes" : "Wijzigingen bewaren",
-    "All" : "Alle",
-    "Limit app usage to groups" : "Beperk appgebruik tot groepen",
-    "No results" : "Geen resultaten",
-    "Update to {version}" : "Update naar {version}",
+    "Update to {update}" : "Update naar {update}",
     "Remove" : "Verwijderen",
     "Disable" : "Uitschakelen",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Deze app heeft geen minimum Nextcloud versie toegewezen gekregen. In de toekomst wordt dit wordt een fout.",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Deze app heeft geen maximum Nextcloud versie toegewezen gekregen. In de toekomst wordt dit wordt een fout.",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "Deze app kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld:",
-    "View in store" : "Bekijken in store",
-    "Visit website" : "Bezoek website",
-    "Report a bug" : "Rapporteer een fout",
-    "Admin documentation" : "Beheerdocumentatie",
-    "Developer documentation" : "Ontwikkelaarsdocumentatie",
+    "Featured" : "Aanbevolen",
     "This app is supported via your current Nextcloud subscription." : "Deze app wordt ondersteund via je huidige Nextcloud abonnement.",
     "Featured apps are developed by and within the community. They offer central functionality and are ready for production use." : "Aanbevolen apps worden ontwikkeld door en binnen de community. Ze bieden centrale functionaliteit en zijn klaar voor productie.",
-    "Featured" : "Aanbevolen",
-    "Update to {update}" : "Update naar {update}",
     "All apps are up-to-date." : "Alle apps zijn up-to-date.",
     "Icon" : "Pictogram",
     "Name" : "Naam",
@@ -187,6 +203,29 @@ OC.L10N.register(
     "No apps found for your version" : "Geen apps gevonden voor jouw versie",
     "Disable all" : "Alles uitschakelen",
     "_%n app has an update available_::_%n apps have an update available_" : ["Voor %n app is een update beschikbaar","Voor %n apps is een update beschikbaar"],
+    "Loading" : "Laden",
+    "Description" : "Omschrijving",
+    "Details" : "Details",
+    "All" : "Alle",
+    "Limit app usage to groups" : "Beperk appgebruik tot groepen",
+    "No results" : "Geen resultaten",
+    "Update to {version}" : "Update naar {version}",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Deze app heeft geen minimum Nextcloud versie toegewezen gekregen. In de toekomst wordt dit wordt een fout.",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Deze app heeft geen maximum Nextcloud versie toegewezen gekregen. In de toekomst wordt dit wordt een fout.",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "Deze app kan niet worden geïnstalleerd, omdat de volgende afhankelijkheden niet zijn ingevuld:",
+    "Author" : "Auteur",
+    "Categories" : "Categorieën",
+    "Resources" : "Bronnen",
+    "Documentation" : "Documentatie",
+    "Report a bug" : "Rapporteer een fout",
+    "Request feature" : "Vraag functionaliteit aan",
+    "Ask questions or discuss" : "Stel vragen of discussieer",
+    "Rate" : "Beoordelen",
+    "View in store" : "Bekijken in store",
+    "Visit website" : "Bezoek website",
+    "Admin documentation" : "Beheerdocumentatie",
+    "Developer documentation" : "Ontwikkelaarsdocumentatie",
+    "Changelog" : "Lijst van veranderingen",
     "Marked for remote wipe" : "Aangemerkt voor wissen op afstand",
     "Device settings" : "Apparaatinstellingen",
     "Allow filesystem access" : "Toestaan toegang bestandssysteem",
@@ -238,14 +277,13 @@ OC.L10N.register(
     "Change password" : "Wijzig wachtwoord",
     "Picture provided by original account" : "Afbeelding is verstrekt door originele account.",
     "Your biography" : "Jouw biografie",
-    "Details" : "Details",
     "You are a member of the following groups:" : "Je bent lid van de volgende groepen:",
     "Your full name" : "Je volledige naam",
-    "This address is not confirmed" : "Dit adres is niet bevestigd",
     "Primary email for password reset and notifications" : "Primair e-mailadres voor wachtwoordherstel en meldingen",
     "Email options" : "E-mail-opties",
     "Remove primary email" : "Verwijder primair e-mailadres",
     "Delete email" : "Verwijder e-mailadres",
+    "This address is not confirmed" : "Dit adres is niet bevestigd",
     "Unset as primary email" : "Verwijder instelling als primaire e-mail",
     "Set as primary email" : "Instellen als primair e-mailadres",
     "Additional email address {index}" : "Extra e-mailadres {index}",
@@ -255,7 +293,6 @@ OC.L10N.register(
     "Unable to update additional email address" : "Kan extra e-mailadres niet updaten",
     "Unable to delete additional email address" : "Kan extra e-mailadres niet verwijderen",
     "No email address set" : "Geen e-mailadres opgegeven",
-    "Additional emails" : "Extra e-mailadressen",
     "Your headline" : "Jouw hoofdlijn",
     "Languages" : "Talen",
     "Help translate" : "Help met vertalen",
@@ -281,21 +318,18 @@ OC.L10N.register(
     "Common languages" : "Gebruikelijke talen",
     "Other languages" : "Andere talen",
     "Password change is disabled because the master key is disabled" : "Wachtwoordwijziging is uitgeschakeld omdat de hoofdsleutel is uitgeschakeld",
-    "New user" : "Nieuwe gebruiker",
+    "New account" : "Nieuw account",
     "Display name" : "Weergavenaam",
     "Email" : "E-mailadres",
     "Quota" : "Limieten",
     "Language" : "Taal",
     "Avatar" : "Avatar",
-    "Username" : "Gebruikersnaam",
     "Group admin for" : "Groepsbeheerder voor",
-    "User backend" : "Backend gebruiker",
     "Storage location" : "Opslag locatie",
     "Last login" : "Laatste login",
-    "Add user to group" : "Toevoegen gebruiker aan groep",
+    "Account actions" : "Accountacties",
     "{size} used" : "{size} gebruikt",
     "Delete account" : "Account verwijderen",
-    "Wipe all devices" : "Wis alle toestellen",
     "Resend welcome email" : "Verstuur welkomst-e-mail opnieuw",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "In het geval van een verloren apparaat of het verlaten van de organisatie, kan dit op afstand de Nextcloud-gegevens wissen van alle apparaten die zijn gekoppeld aan {userid}. Werkt alleen als de apparaten zijn verbonden met het internet.",
     "Remote wipe of devices" : "Op afstand leegmaken toestellen",
@@ -309,6 +343,7 @@ OC.L10N.register(
     "Visibility" : "Zichtbaarheid",
     "Show storage path" : "Tonen opslagpad",
     "Show last login" : "Toon laatste inlog",
+    "Sorting" : "Sorteren",
     "Send email" : "Verstuur e-mail",
     "Defaults" : "Standaard",
     "Default quota" : "Standaard quota",
@@ -316,9 +351,7 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "Inloggen zonder wachtwoord vereist een beveiligde verbinding.",
     "Add WebAuthn device" : "WebAuthn-apparaat toevoegen",
     "Please authorize your WebAuthn device." : "Autoriseer je WebAuthn toestel.",
-    "Name your device" : "Geef je apparaat een naam",
     "Adding your device …" : "Je apparaat toevoegen...",
-    "Server error while trying to add WebAuthn device" : "Serverfout tijdens het toevoegen van WebAuthn apparaat",
     "Server error while trying to complete WebAuthn device registration" : "Serverfout tijdens registratie van het WebAuthn apparaat",
     "Unnamed device" : "Naamloos apparaat",
     "Passwordless Authentication" : "Inloggen zonder wachtwoord",
@@ -328,12 +361,7 @@ OC.L10N.register(
     "Your browser does not support WebAuthn." : "Je browser ondersteunt WebAuthn niet.",
     "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Als beheerder kun je gedetailleerde regels voor delen instellen. Bekijk de documentatie voor meer informatie.",
     "You need to enable the File sharing App." : "Je dient de File sharing App in te schakelen",
-    "{license}-licensed" : "{license}-gelicenseerd",
-    "Changelog" : "Lijst van veranderingen",
-    "by {author}\n{license}" : "door {author}\n{license}",
-    "New account" : "Nieuw account",
     "Admins" : "Beheerders",
-    "Disabled users" : "Uitgeschakelde gebruikers",
     "Group name" : "Groepsnaam",
     "Sending…" : "Versturen...",
     "Email sent" : "E-mail verzonden",
@@ -362,7 +390,6 @@ OC.L10N.register(
     "The app will be downloaded from the App Store" : "De app zal worden gedownload van de App Store",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "Deze is niet aangeduid als compatibel met jouw versie van Nextcloud. Als je verdergaat, zal je de app kunnen installeren. Let op dat de app misschien niet werkt zoals verwacht.",
     "Never" : "Nooit",
-    "Active users" : "Actieve gebruikers",
     "An error occurred during the request. Unable to proceed." : "Er is een fout opgetreden tijdens het verzoek. Kan niet doorgaan.",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "De app is ingeschakeld maar moet worden geüpdate. Je wordt over 5 seconden doorgeleid naar de updatepagina.",
     "Error: This app cannot be enabled because it makes the server unstable" : "Fout: Deze app kan niet ingeschakeld worden, omdat die de server onstabiel maakt",
@@ -372,8 +399,10 @@ OC.L10N.register(
     "Error while updating device token name" : "Fout tijdens bijwerken device tokennaam",
     "Error while updating device token scope" : "Fout tijdens bijwerken device tokenscope",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Er waren te veel aanvragen afkomstig uit uw netwerk. Probeer later opnieuw of contacteer de beheerder als dat niet correct is.",
-    "Documentation" : "Documentatie",
+    "Error" : "Fout",
     "Forum" : "Forum",
+    "Legal notice" : "Juridische bepalingen",
+    "Privacy policy" : "Privacybeleid",
     "SSL" : "SSL",
     "Open documentation" : "Open documentatie",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Het is belangrijk deze server zo in te stellen dat er ook e-mails verstuurd kunnen worden om wachtwoord resets en meldingen bijvoorbeeld te versturen.",
@@ -399,7 +428,6 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "Redenen om Nextcloud te gebruiken in jouw organisatie",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Ontwikkeld door de {communityopen}Nextcloud community{linkclose}, de {githubopen}broncode{linkclose} is gelicenseerd onder de {licenseopen}AGPL{linkclose}.",
     "Like our Facebook page" : "Vind onze Facebook pagina leuk",
-    "Follow us on Twitter" : "Volg ons op Twitter",
     "Follow us on Mastodon" : "Volg ons op Mastodon",
     "Check out our blog" : "Lees ons blog",
     "Subscribe to our newsletter" : "Abonneer jezelf op onze nieuwsbrief",
@@ -408,77 +436,42 @@ OC.L10N.register(
     "If you use third party applications to connect to Nextcloud, please make sure to create and configure an app password for each before enabling second factor authentication." : "Als u toepassingen van derden gebruikt om met Nextcloud te verbinden, zorg er dan voor om voor elke app een wachtwoord te maken en te configureren voordat \"tweede factor authenticatie\" wordt geactiveerd.",
     "No user supplied" : "Geen gebruiker opgegeven",
     "Please provide an admin recovery password; otherwise, all user data will be lost." : "Voer een beheerdersherstelwachtwoord in, anders zullen alle gebruikersgegevens verloren gaan",
-    "installing and updating apps via the App Store or Federated Cloud Sharing" : "installeren en bijwerken van applicaties via de App Store of gefedereerd delen",
-    "Federated Cloud Sharing" : "Gefedereerd delen via de cloud",
-    "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cUrl gebruikt een verouderde %1$s versie (%2$s). Werk het besturingssysteem bij, want anders zullen functies als %3$s niet betrouwbaar werken.",
-    "OPcache is disabled. For better performance, it is recommended to apply <code>opcache.enable=1</code> to your PHP configuration." : "OPcache is uitgeschakeld. Voor betere prestaties wordt aanbevolen om <code>opcache.enable=1</code> toe te passen in je PHP-configuratie.",
-    "OPcache is configured to remove code comments. With OPcache enabled, <code>opcache.save_comments=1</code> must be set for Nextcloud to function." : "OPcache is geconfigureerd om codeopmerkingen te verwijderen. Als OPcache is ingeschakeld, moet <code>opcache.save_comments=1</code> worden ingesteld om Nextcloud te laten functioneren.",
-    "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud mag de OPcache API niet gebruiken. Met OPcache ingeschakeld, wordt het ten zeerste aanbevolen om alle Nextcloud-mappen op te nemen met <code>opcache.restrict_api</code> of deze instelling uit te schakelen om OPcache API-beperkingen uit te schakelen, om fouten tijdens Nextcloud-kern- of app-upgrades te voorkomen.",
-    "Nextcloud is not allowed to use the OPcache API. It is highly recommended to include all Nextcloud directories with <code>opcache.restrict_api</code> or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud mag de OPcache API niet gebruiken. Het wordt ten zeerste aanbevolen om alle Nextcloud-mappen op te nemen met <code>opcache.restrict_api</code> of deze instelling uit te schakelen om OPcache API-beperkingen uit te schakelen, om fouten tijdens Nextcloud-kern- of app-upgrades te voorkomen.",
-    "The OPcache buffer is nearly full. To assure that all scripts can be hold in cache, it is recommended to apply <code>opcache.memory_consumption</code> to your PHP configuration with a value higher than <code>%s</code>." : "De OPcache-buffer is bijna vol. Om ervoor te zorgen dat alle scripts in de cache kunnen worden bewaard, wordt aanbevolen om <code>opcache.memory_consumption</code> toe te passen in je PHP-configuratie met een waarde hoger dan <code>%s</code>.",
-    "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply <code>opcache.interned_strings_buffer</code> to your PHP configuration with a value higher than <code>%s</code>." : "De OPcache geïnterneerde strings buffer is bijna vol. Om ervoor te zorgen dat herhalende strings effectief in de cache kunnen worden opgeslagen, wordt aanbevolen om <code>opcache.interned_strings_buffer</code> toe te passen in je PHP-configuratie met een waarde hoger dan <code>%s</code>.",
     "Invalid user" : "Ongeldige gebruiker",
     "Your username is: %s" : "Je gebruikersnaam is: %s",
     "Logged in user must be a subadmin" : "Ingelogde gebruiker moet een subbeheerder zijn",
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "Er is een achtergrondtaak in bezig die controleert op door de gebruiker geïmporteerde SSL-certificaten. Kom later terug.",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "Er zijn enkele door gebruikers geïmporteerde SSL-certificaten aanwezig, die niet meer worden gebruikt met Nextcloud 21. Ze kunnen op de opdrachtregel worden geïmporteerd via het commando \"occ security:certificates:import\". De paden binnen de gegevensdirectory worden hieronder weergegeven.",
-    "Invalid UUIDs of LDAP users or groups have been found. Please review your \"Override UUID detection\" settings in the Expert part of the LDAP configuration and use \"occ ldap:update-uuid\" to update them." : "Er zijn ongeldige UUID's van LDAP-gebruikers of -groepen gevonden. Controleer de instellingen voor \"UUID-detectie overschrijven\" in het Expert-gedeelte van de LDAP-configuratie en gebruik \"occ ldap:update-uuid\" om ze bij te werken.",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "De database mist een paar indexen. Omdat het toevoegen van indexen op grote tabellen veel tijd kan kosten, zijn ze niet automatisch gecreëerd. Door het draaien van \"occ db:add-missing-indices\" kunnen deze indexen handmatig worden toegevoegd terwijl de server blijft draaien.  Als de indexen zijn toegevoegd, zullen opvragingen op die tabellen veel sneller plaatsvinden.",
+    "Exclude groups from sharing" : "Sta bepaalde groepen niet toe om te delen",
+    "These groups will still be able to receive shares, but not to initiate them." : "Deze groepen kunnen gedeelde mappen en bestanden ontvangen, maar kunnen zelf niks delen.",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "Tweetrapsauthenticatie kan worden afgedwongen voor alle gebruikers en specifieke groepen. Als ze geen tweetrapsprovider hebben ingesteld, dan kunnen ze niet inloggen in het systeem.",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "Wanneer groepen worden geselecteerd/uitgezonderd, geldt de volgende logica om te bepalen of voor een gebruiker 2FA wordt afgedwongen: Als geen groepen zijn geselecteerd, is 2FA voor iedereen ingeschakeld, behalve voor leden van de uitgezonderde groepen. Als groepen zijn geselecteerd is 2FA is ingeschakeld voor alle leden ervan. Als een gebruiker lid is van zowel een geselecteerde als uitgezonderde groep, krijgt de geselecteerde voorrang en wordt 2FA afgedwongen.",
-    "Enable all" : "Alles activeren",
-    "Internet Explorer" : "Internet Explorer",
-    "Edge" : "Edge",
-    "Firefox" : "Firefox",
-    "Google Chrome" : "Google Chrome",
-    "Safari" : "Safari",
-    "iPhone" : "iPhone",
-    "iPad" : "iPad",
-    "Sync client - {os}" : "Sync client - {os}",
-    "Error while deleting the token" : "Fout bij verwijderen token",
-    "Use the credentials below to configure your app or device." : "Gebruik onderstaande inloggegevens om je app of apparaat te configureren.",
-    "For security reasons this password will only be shown once." : "Vanwege beveiligingsredenen wordt dit wachtwoord maar één keer getoond.",
-    "Copied!" : "Gekopieerd!",
-    "Copy" : "Kopiëren",
+    "{license}-licensed" : "{license}-gelicenseerd",
+    "Username" : "Gebruikersnaam",
     "Execute one task with each page loaded. Use case: Single user instance." : "Een taak uitvoeren bij het laden van iedere pagina. Use case: voor een enkele gebruiker.",
-    "To run this you need the PHP POSIX extension. See {linkstart}PHP documentation{linkend} for more details." : "PHP POSIX extensie is vereist om dit te draaien. Bekijk {linkstart}PHP documentatie{linkend} voor meer informatie.",
     "Enable or disable profile by default for new users." : "Profiel standaard in- of uitschakelen voor nieuwe gebruikers.",
-    "You are about to remove the group {group}. The users will NOT be deleted." : "Je gaat groep {group} verwijderen. De gebruikers worden NIET verwijderd.",
-    "Please confirm the group removal " : "Bevestig verwijderen groep",
-    "png or jpg, max. 20 MB" : "png of jpg, max. 20 MB",
-    "Your email address" : "Je e-mailadres",
-    "Your location" : "Je locatie",
+    "Additional emails" : "Extra e-mailadressen",
     "Enable Profile" : "Schakel Profiel in",
-    "Your Twitter handle" : "Je Twitter naam",
+    "New user" : "Nieuwe gebruiker",
+    "User backend" : "Backend gebruiker",
     "You do not have permissions to see the details of this user" : "Je hebt niet de machtigingen om de details van deze gebruiekr te zien",
-    "Add new password" : "Nieuw wachtwoord toevoegen",
-    "Add new email address" : "Toevoegen nieuw e-mailadres",
+    "Add user to group" : "Toevoegen gebruiker aan groep",
     "Set user as admin for" : "Maak gebruiker beheerder voor",
     "Select user quota" : "Selecteer gebruikersquotum",
-    "Toggle user actions menu" : "Omschakelen gebruikersactiemenu",
     "Delete user" : "Verwijder gebruiker",
+    "Wipe all devices" : "Wis alle toestellen",
     "Disable user" : "Gebruiker uitschakelen",
     "Enable user" : "Inschakelen gebruiker",
-    "Edit User" : "Bewerk gebruiker",
-    "Will be autogenerated" : "Wordt automatisch gegenereerd",
-    "Add a new user" : "Nieuwe gebruiker toevoegen",
-    "No users in here" : "Hier zijn geen gebruikers",
-    "Enter group name" : "Geef een groepsnaam op",
-    "Add group" : "Groep toevoegen",
-    "Default quota:" : "Standaardquota:",
-    "Show Languages" : "Toon talen",
+    "Toggle user actions menu" : "Omschakelen gebruikersactiemenu",
     "Show user backend" : "Toon backend gebruiker",
-    "Send email to new user" : "Verstuur e-mail aan nieuwe gebruiker",
-    "Not saved" : "Niet opgeslagen",
-    "Twitter" : "Twitter",
+    "Name your device" : "Geef je apparaat een naam",
+    "Server error while trying to add WebAuthn device" : "Serverfout tijdens het toevoegen van WebAuthn apparaat",
+    "by {author}\n{license}" : "door {author}\n{license}",
+    "Active users" : "Actieve gebruikers",
+    "Disabled users" : "Uitgeschakelde gebruikers",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "Niet beschikbaar omdat het publiceren van gebruikersdata aan de lookup server niet toegestaan is, neem contact op met je beheerder als je vragen hebt",
     "Show to logged in users only" : "Laat alleen zien aan ingelogde gebruikers",
-    "Enable untested app" : "Inschakelen niet-geteste apps",
     "SMTP Username" : "SMTP gebruikersnaam",
-    "Expire after" : "Vervallen na",
-    "day(s)" : "dag(en)",
-    "Set default expiration date" : "Stel standaard vervaldatum in",
-    "Exclude groups from creating link shares:" : "Sta deze groepen niet toe om deellinks te maken:",
-    "Allow username autocompletion in share dialog" : "Automatisch aanvullen gebruikersnamen binnen deeldialoog toegestaan",
-    "Allow username autocompletion to users within the same groups" : "Automatisch aanvullen van gebruikersnamen voor de gebruikers binnen dezelfde groepen toegestaan"
+    "Follow us on Twitter" : "Volg ons op Twitter"
 },
 "nplurals=2; plural=(n != 1);");
