@@ -72,6 +72,7 @@ OC.L10N.register(
     "Email could not be sent. Check your mail server log" : "邮件无法发送。检查您的邮件服务器日志",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "在发送电子邮件时出现问题。请修正您的设置。（错误：%s）",
     "You need to set your account email before being able to send test emails. Go to %s for that." : "您需要先设置您的帐户电子邮件，然后才能发送测试电子邮件。去 %s 看看吧。",
+    "Recently active" : "最近活跃",
     "Disabled accounts" : "禁用账号",
     "Invalid account" : "无效的账户。",
     "Invalid mail address" : "无效的电子邮件地址",
@@ -124,6 +125,11 @@ OC.L10N.register(
     "Background jobs" : "后台任务",
     "Unlimited" : "无限",
     "Verifying" : "正在验证",
+    "Allowed admin IP ranges" : "允许的管理员 IP 范围",
+    "Admin IP filtering isn’t applied." : "不应用管理员 IP 过滤。",
+    "Configuration key \"%1$s\" expects an array (%2$s found). Admin IP range validation will not be applied." : "配置键 \"%1$s\"需要一个数组（找到 %2$s）。不会应用管理员 IP 范围验证。",
+    "Configuration key \"%1$s\" contains invalid IP range(s): \"%2$s\"" : "配置 key \"%1$s\" 包含无效的ip范围: \"%2$s\"",
+    "Admin IP filtering is correctly configured." : "管理员 IP 过滤已正确配置。",
     "App directories owner" : "应用程序目录所有者",
     "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:\n%s" : "某些应用程序目录由与 Web 服务器不同的用户拥有。 如果手动安装应用程序，可能会出现这种情况。 检查以下应用程序目录的权限:\n%s",
     "App directories have the correct owner \"%s\"" : "应用程序目录具有正确的所有者 \"%s\"",
@@ -148,10 +154,13 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "您的数据目录和文件似乎可以从互联网访问。这是因为 .htaccess 文件无效。强烈建议您配置您的 web 服务器，使数据目录不再可访问，或将数据目录移到 web 服务器文档根目录之外。",
     "Could not check that the data directory is protected. Please check manually that your server does not allow access to the data directory." : "无法检查数据目录是否受到保护。 请手动检查您的服务器是否不允许访问数据目录。",
     "Database missing columns" : "数据库缺失列",
+    "Missing optional column \"%s\" in table \"%s\"." : "缺少可选列 \"%s\" ，在表 \"%s\"中.",
     "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "数据库缺少一些可选列。 由于在大表上添加列可能会花费一些时间，因此在可以选择时不会自动添加列。 通过运行“occ db:add-missing-columns”，可以在实例继续运行时手动添加那些缺少的列。 添加列后，某些功能可能会提高响应速度或可用性。",
     "Database missing indices" : "数据库缺失索引",
     "Missing indices:" : "缺少引索：",
+    "Detected some missing optional indices. Occasionally new indices are added (by Nextcloud or installed applications) to improve database performance. Adding indices can sometimes take awhile and temporarily hurt performance so this is not done automatically during upgrades. Once the indices are added, queries to those tables should be faster. Use the command `occ db:add-missing-indices` to add them. " : "检测到一些缺失的可选索引。偶尔会添加新索引（由 Nextcloud 或已安装的应用程序添加）以提高数据库性能。添加索引有时可能需要一段时间并会暂时损害性能，因此在升级期间不会自动完成此操作。添加索引后，对这些表的查询应该会更快。使用命令 `occ db:add-missing-indices` 添加它们。",
     "Database missing primary keys" : "数据库缺少主键",
+    "Missing primary key on table \"%s\"." : "表 \"%s\" 缺少主键。",
     "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "数据库缺少一些主键。由于在大型数据表上添加主键可能需要一些时间，因此程序没有自动添加。通过运行“occ db:add-missing-primary-keys”，这些缺失的主键可以在实例持续运行时手动添加。",
     "Database pending bigint migrations" : "数据库待处理的 bigint 迁移",
     "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline." : "数据库中的某些列缺少到大整型的转换。 由于更改大表上的列类型可能需要一些时间，因此它们不会自动更改。 通过运行 \"occ db:convert-filecache-bigint\"，可以手动应用这些挂起的更改。 该操作需要在实例离线时进行。",
@@ -163,8 +172,6 @@ OC.L10N.register(
     "Email test" : "电子邮件测试",
     "Email test was successfully sent" : "测试电子邮件成功发出",
     "You have not set or verified your email server configuration, yet. Please head over to the \"Basic settings\" in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "您尚未配置电子邮件服务器或尚未验证配置。请在“基本设置”中进行配置。配置完毕后，请点击表单下方的“发送电子邮件”按钮来验证您的设置。",
-    "File locking" : "文件锁定",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "事务性文件锁定已禁用，可能会引发争用问题。请在 config.php 中启用 filelocking.enabled 以避免这类问题的发生。",
     "The database is used for transactional file locking. To enhance performance, please configure memcache, if available." : "当前正在使用数据库处理事务性文件锁定。若有内存缓存可用，请进行配置以提升性能。",
     "Forwarded for headers" : "转发标头",
     "Your \"trusted_proxies\" setting is not correctly set, it should be an array." : "您的 trusted_proxy 设置存在错误，应为一个列表。",
@@ -172,13 +179,17 @@ OC.L10N.register(
     "The reverse proxy header configuration is incorrect. This is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "反向代理标头设置不正确。这会允许攻击者对 Nextcloud 假冒其IP地址并引发安全问题。",
     "Your IP address was resolved as %s" : "您的IP地址为%s",
     "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud." : "反向代理标头设置不正确，或您正在通过受信任的代理访问 Nextcloud。若您并未使用受信任的代理，这表示存在安全问题，攻击者可以对 Nextcloud 假冒其IP地址。",
+    "HTTPS access and URLs" : "HTTPS 访问和 URL",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "通过 HTTP 不安全地访问网站。 强烈建议您将服务器设置为需要 HTTPS。 如果没有它，一些重要的网络功能（例如 \"复制到剪贴板\" 或 \"服务人员\" ）将无法工作！",
     "Accessing site insecurely via HTTP." : "通过 HTTP 不安全地访问网站。",
+    "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "您正在通过安全连接访问您的实例，但您的实例正在生成不安全的 URL。这可能意味着您的实例位于反向代理后面，并且 Nextcloud `overwrite*` 配置值设置不正确。",
+    "Your instance is generating insecure URLs. If you access your instance over HTTPS, this likely means that your instance is behind a reverse proxy and the Nextcloud `overwrite*` config values are not set correctly." : "您的实例正在生成不安全的 URL。如果您通过 HTTPS 访问您的实例，这可能意味着您的实例位于反向代理后面，并且 Nextcloud `overwrite*` 配置值设置不正确。",
     "You are accessing your instance over a secure connection, and your instance is generating secure URLs." : "您正在通过安全连接访问您的实例，并且您的实例正在生成安全 URL。",
     "Internet connectivity" : "网络连接",
     "Internet connectivity is disabled in configuration file." : "配置文件中网络连接已禁用。",
     "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "此服务器没有工作的互联网连接：无法访问多个端点。这意味着一些功能，如挂载外部存储、更新或安装第三方应用程序的通知将无法工作。远程访问文件和发送通知邮件也可能无法工作。建立从这个服务器到互联网的连接，以享受所有功能。",
     "JavaScript modules support" : "JavaScript 模块支持",
+    "Unable to run check for JavaScript support. Please remedy or confirm manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "无法运行 JavaScript 支持检查。请修复或手动确认您的 Web 服务器是否使用 JavaScript MIME 类型提供 `.mjs` 文件。",
     "Your webserver does not serve `.mjs` files using the JavaScript MIME type. This will break some apps by preventing browsers from executing the JavaScript files. You should configure your webserver to serve `.mjs` files with either the `text/javascript` or `application/javascript` MIME type." : "您的网络服务器不使用 JavaScript MIME 类型提供 \".mjs\" 文件。 这会阻止浏览器执行 JavaScript 文件，从而破坏某些应用程序。 您应该配置您的网络服务器以使用 \"text/javascript\" 或 \"application/javascript\" MIME 类型提供 \".mjs\" 文件。",
     "JavaScript source map support" : "JavaScript 源映射支持",
     "Your webserver is not set up to serve `.js.map` files. Without these files, JavaScript Source Maps won't function properly, making it more challenging to troubleshoot and debug any issues that may arise." : "您的网络服务器未设置为提供 \".js.map\" 文件。 如果没有这些文件，JavaScript Source Maps 将无法正常运行，从而使排除和调试可能出现的任何问题变得更加困难。",
@@ -189,13 +200,25 @@ OC.L10N.register(
     "Server has no maintenance window start time configured. This means resource intensive daily background jobs will also be executed during your main usage time. We recommend to set it to a time of low usage, so users are less impacted by the load caused from these heavy tasks." : "服务器没有配置维护时段开始时间。 这意味着资源密集型日常后台作业也将在您的主要使用时间执行。 我们建议将其设置为低使用率的时间，这样用户就不会受到这些繁重任务造成的负载的影响。",
     "Maintenance window to execute heavy background jobs is between {start}:00 UTC and {end}:00 UTC" : "执行繁重后台作业的维护窗口位于 {start}:00 UTC 和 {end}:00 UTC 之间",
     "Memcache" : "内存缓存",
+    "Memcached is configured as distributed cache, but the wrong PHP module (\"memcache\") is installed. Please install the PHP module \"memcached\"." : "Memcached 已配置为分布式缓存，但安装了错误的 PHP 模块（\"memcache\"）。请安装 PHP 模块 \"memcached\"。",
+    "Memcached is configured as distributed cache, but the PHP module \"memcached\" is not installed. Please install the PHP module \"memcached\"." : "Memcached 配置为分布式缓存，但未安装 PHP 模块 \"memcached\" 。请安装 PHP 模块 \"memcached\" 。",
     "No memory cache has been configured. To enhance performance, please configure a memcache, if available." : "未配置内存缓存。若有内存缓存可用，请进行配置以提升性能。",
     "Configured" : "已配置",
+    "Mimetype migrations available" : "可用的 Mimetype 迁移",
+    "One or more mimetype migrations are available. Occasionally new mimetypes are added to better handle certain file types. Migrating the mimetypes take a long time on larger instances so this is not done automatically during upgrades. Use the command `occ maintenance:repair --include-expensive` to perform the migrations." : "有一个或多个 mimetype 迁移可用。有时会添加新的 mimetype 以更好地处理某些文件类型。在较大的实例上迁移 mimetype 需要很长时间，因此升级期间不会自动完成此操作。使用命令 \"occ Maintenance:repair --include-expensive\" 执行迁移。",
     "MySQL Unicode support" : "MySQL Unicode 支持",
     "You are not using MySQL" : "您没有使用MySQL",
     "MySQL is used as database and does support 4-byte characters" : "MySQL用作数据库并且支持4字节字符",
+    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL." : "MySQL 用作数据库，但不支持 4 字节字符。为了能够处理 4 字节字符（如表情符号），而不会在文件名或注释中出现问题，建议在 MySQL 中启用 4 字节支持。",
     "OCS provider resolving" : "OCS提供商解析",
     "Could not check if your web server properly resolves the OCM and OCS provider URLs." : "无法检查您的 Web 服务器是否正确解析 OCM 和 OCS 提供商 URL。",
+    "Your web server is not properly set up to resolve %1$s.\nThis is most likely related to a web server configuration that was not updated to deliver this folder directly.\nPlease compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx.\nOn Nginx those are typically the lines starting with \"location ~\" that need an update." : "您的 Web 服务器未正确设置以解析 %1$s。\n这很可能与未更新以直接提供此文件夹的 Web 服务器配置有关。\n请将您的配置与 Apache 的 \".htaccess\" 中提供的重写规则或 Nginx 文档中提供的重写规则进行比较。\n在 Nginx 上，通常以 \"location ~\" 开头的行需要更新。",
+    "The \"overwrite.cli.url\" option in your config.php is correctly set to \"%s\"." : "您的 config.php 中的 \"overwrite.cli.url\" 选项正确设置为 \"%s\" 。",
+    "The \"overwrite.cli.url\" option in your config.php is set to \"%s\" which is a correct URL. Suggested URL is \"%s\"." : "您的 config.php 中的 \"overwrite.cli.url\" 选项设置为 \"%s\"，这是正确的 URL。建议的 URL 是 \"%s\"。",
+    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"%s\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "请确保将 config.php 文件中的 \"overwrite.cli.url\" 选项设置为用户主要用来访问此 Nextcloud 的 URL。建议：\"%s\"。否则，通过 cron 生成 URL 可能会出现问题。（不过，建议的 URL 可能不是用户主要用来访问此 Nextcloud 的 URL。无论如何，最好再检查一下。）",
+    "PHP APCu configuration" : "PHP APCu 配置",
+    "Your APCu cache has been running full, consider increasing the apc.shm_size php setting." : "您的 APCu 缓存已满，请考虑增加 apc.shm_size php 设置。",
+    "Your APCu cache is almost full at %s%%, consider increasing the apc.shm_size php setting." : " 您的 APCu 缓存在 %s%% 时几乎已满，请考虑增加 apc.shm_size php 设置。",
     "PHP default charset" : "PHP默认字符集",
     "PHP configuration option \"default_charset\" should be UTF-8" : "PHP 设置选项 default_chatset 应该为 UTF-8",
     "The function is available." : "该功能可用。",
@@ -214,6 +237,7 @@ OC.L10N.register(
     "for WebAuthn passwordless login, and SFTP storage" : "用于 WebAuthn 无密码登录和 SFTP 存储",
     "for picture rotation in server and metadata extraction in the Photos app" : "用于服务器中的图片旋转和照片应用程序中的元数据提取",
     "This instance is missing some required PHP modules. It is required to install them: %s." : "该实例缺少一些必须的PHP模块。必须安装以下模块：%s",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them:\n%s" : "此实例缺少一些推荐的 PHP 模块。为了提高性能和更好的兼容性，强烈建议安装它们：\n%s",
     "The PHP OPcache module is not loaded. For better performance it is recommended to load it into your PHP installation." : "未加载 PHP OPcache 模块。为了更好的性能，建议将其加载到您的 PHP 安装中。",
     "OPcache is disabled. For better performance, it is recommended to apply \"opcache.enable=1\" to your PHP configuration." : "OPcache 已禁用。 为了获得更好的性能，建议在 PHP 配置中应用 \"opcache.enable=1\" 。",
     "The shared memory based OPcache is disabled. For better performance, it is recommended to apply \"opcache.file_cache_only=0\" to your PHP configuration and use the file cache as second level cache only." : "基于共享内存的 OPcache 被禁用。 为了获得更好的性能，建议在 PHP 配置中应用 \"opcache.file_cache_only=0\"，并将文件缓存仅用作二级缓存。",
@@ -223,9 +247,11 @@ OC.L10N.register(
     "The OPcache interned strings buffer is nearly full. To assure that repeating strings can be effectively cached, it is recommended to apply \"opcache.interned_strings_buffer\" to your PHP configuration with a value higher than \"%s\"." : "OPcache 驻留字符串缓冲区几乎已满。 为了确保可以有效地缓存重复字符串，建议将 \"opcache.interned_strings_buffer\" 应用到您的 PHP 配置，其值高于 \"%s\".",
     "OPcache is configured to remove code comments. With OPcache enabled, \"opcache.save_comments=1\" must be set for Nextcloud to function." : "OPcache 配置为删除代码注释。 启用 OPcache 后，必须设置 \"opcache.save_comments=1\"，Nextcloud 才能正常运行。",
     "Nextcloud is not allowed to use the OPcache API. With OPcache enabled, it is highly recommended to include all Nextcloud directories with \"opcache.restrict_api\" or unset this setting to disable OPcache API restrictions, to prevent errors during Nextcloud core or app upgrades." : "Nextcloud 不允许使用 OPcache API。 启用 OPcache 后，强烈建议将所有 Nextcloud 目录包含在 \"opcache.restrict_api\" 中，或取消设置此设置以禁用 OPcache API 限制，以防止 Nextcloud 核心或应用程序升级期间出现错误。",
+    "Checking from CLI, OPcache checks have been skipped." : "从 CLI 检查，OPcache 检查已被跳过。",
     "The PHP OPcache module is not properly configured. %s." : "PHP OPcache 模块配置不正确。%s.",
     "Correctly configured" : "正确配置",
     "PHP version" : "PHP版本",
+    "You are currently running PHP %s. PHP 8.1 is now deprecated in Nextcloud 30. Nextcloud 31 may require at least PHP 8.2. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "您当前正在运行 PHP %s 。PHP 8.1 在 Nextcloud 30 中已弃用。Nextcloud 31 可能至少需要 PHP 8.2。请尽快升级到 PHP 组提供的官方支持的 PHP 版本之一。",
     "You are currently running PHP %s." : "您当前正在使用 PHP %s。",
     "PHP \"output_buffering\" option" : "PHP output_buffering 选项",
     "PHP configuration option \"output_buffering\" must be disabled" : "PHP 设置选项 output_buffering 必须被禁用",
@@ -239,9 +265,11 @@ OC.L10N.register(
     "Configuration file access rights" : "配置文件访问权限",
     "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "只读配置已启用。这可以在浏览器界面保护配置。另外，每次更新时需手动赋予该文件写权限。",
     "Nextcloud configuration file is writable" : "Nextcloud 配置文件可写",
+    "You have more than %s rows in the scheduling objects table. Please run the expensive repair jobs via occ maintenance:repair --include-expensive." : "您的调度对象表中有超过 %s 行。请通过 `occ maintenance:repair --include-expensive` 运行昂贵的维修作业。",
     "HTTP headers" : "HTTP标头",
     "- The `%1$s` HTTP header is not set to `%2$s`. Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "- `%1$s` HTTP 标头未设置为 `%2$s`。 某些功能可能无法正常工作，建议相应地调整此设置。",
     "- The `%1$s` HTTP header is not set to `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- `%1$s` HTTP标头未设置为 `%2$s`。这可能是潜在的安全或隐私风险，建议调整此设置。",
+    "- The `%1$s` HTTP header does not contain `%2$s`. This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "- `%1$s` HTTP 标头不包含 `%2$s`。这是一个潜在的安全或隐私风险，建议相应地调整此设置。",
     "Some headers are not set correctly on your instance" : "您的实例上的某些标头设置不正确",
     "Could not check that your web server serves security headers correctly. Please check manually." : "无法检查您的 Web 服务器是否正确提供安全标头。 请手动检查。",
     "Could not check that your web server serves security headers correctly, unable to query `%s`" : "无法检查您的 Web 服务器是否正确提供安全标头，无法查询 `%s`",
@@ -266,24 +294,20 @@ OC.L10N.register(
     "Could not check that your web server serves `.well-known` correctly. Please check manually." : "无法检查您的网络服务器是否正确服务 `.well-known`。 请手动检查。",
     "Your web server is not properly set up to resolve `.well-known` URLs, failed on:\n`%s`" : "您的网络服务器未正确设置来解析 `.wellknown` URL，失败于:\n`%s`",
     "Your server is correctly configured to serve `.well-known` URLs." : "您的服务器已正确配置为提供 `.well-known` URL。",
-    "WOFF2 file loading" : "WOFF2 文件加载",
-    "Could not check for WOFF2 loading support. Please check manually if your webserver serves `.woff2` files." : "无法检查 WOFF2 加载支持。 请手动检查您的网络服务器是否提供 `.woff2` 文件。",
-    "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our documentation." : "您的 Web 服务器未正确设置以传送 .woff2 文件。 这通常是 Nginx 配置的问题。 对于 Nextcloud 15，它需要进行调整才能提供 .woff2 文件。 将您的 Nginx 配置与我们文档中推荐的配置进行比较。",
     "Profile information" : "个人信息",
     "Profile picture, full name, email, phone number, address, website, Twitter, organisation, role, headline, biography, and whether your profile is enabled" : "个人资料图片、全名、电子邮件、电话号码、地址、网站、Twitter、组织、角色、标题、个人简介以及您的个人资料是否启用",
     "Nextcloud settings" : "Nextcloud 设置",
+    "AI tasks can be implemented by different apps. Here you can set which app should be used for which task." : "AI 任务可以由不同的应用程序执行。在这里您可以设置哪个应用程序应该用于哪个任务。",
     "Task:" : "任务：",
+    "None of your currently installed apps provide Task processing functionality" : "您当前安装的应用程序均不提供任务处理功能",
     "Machine translation" : "机器翻译",
     "Machine translation can be implemented by different apps. Here you can define the precedence of the machine translation apps you have installed at the moment." : "机器翻译可由不同的应用程序实现。在这里，您可以定义当前安装的机器翻译应用程序的优先级。",
-    "Speech-To-Text" : "语音转文本",
-    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "语音转文本可由不同的应用程序实现。您可以在此设置使用哪个应用程序。",
-    "None of your currently installed apps provide Speech-To-Text functionality" : "您当前安装的应用程序均不提供语音转文本功能",
     "Image generation" : "图像生成",
     "Image generation can be implemented by different apps. Here you can set which app should be used." : "图像生成功能可能由多种应用提供。您可在此指定应当使用的应用。",
     "None of your currently installed apps provide image generation functionality" : "您目前安装的应用都不提供图像生成功能",
     "Text processing" : "文本处理",
     "Text processing tasks can be implemented by different apps. Here you can set which app should be used for which task." : "文本处理任务可由不同的应用程序执行。在这里，您可以设置哪个应用程序用于执行哪个任务。",
-    "None of your currently installed apps provide Text processing functionality" : "您当前安装的应用程序均不提供文本处理功能",
+    "None of your currently installed apps provide text processing functionality using the Text Processing API." : "您当前安装的应用程序均未提供使用文本处理 API 的文本处理功能。",
     "Here you can decide which group can access certain sections of the administration settings." : "您可以在此决定哪个组可以访问管理设置的特定部分。",
     "None" : "无",
     "Unable to modify setting" : "无法更改设置",
@@ -484,6 +508,8 @@ OC.L10N.register(
     "Error saving profile picture" : "保存个人资料图片出错",
     "Error removing profile picture" : "移除个人资料图片出错",
     "Your biography" : "个人简介",
+    "Enter your date of birth" : "輸入您的出生日期",
+    "Unable to update date of birth" : "无法更新出生日期",
     "You are a member of the following groups:" : "您是以下群组的成员：",
     "You are using <strong>{usage}</strong>" : "您已使用<strong>{usage}</strong>",
     "You are using <strong>{usage}</strong> of <strong>{totalSpace}</strong> (<strong>{usageRelative}%</strong>)" : "您已使用 <strong>{totalSpace}</strong> 中的 <strong>{usage}</strong> (<strong>{usageRelative}%</strong>)",
@@ -504,6 +530,9 @@ OC.L10N.register(
     "Unable to delete additional email address" : "无法删除附加电邮地址",
     "No email address set" : "尚未设置 Email 地址",
     "Your handle" : "您的别名",
+    "Day to use as the first day of week" : "用作一周第一天的日期",
+    "Derived from your locale ({weekDayName})" : "源自您的区域设置 ({weekDayName})",
+    "Unable to update first day of week" : "无法更新一周的第一天",
     "Your headline" : "您的标题",
     "Languages" : "语言",
     "Help translate" : "帮助翻译",
@@ -549,10 +578,19 @@ OC.L10N.register(
     "Password (required)" : "密码（必填）",
     "Email (required)" : "电子邮件（必填）",
     "Email" : "电子邮件",
+    "Member of the following groups (required)" : "以下群组的成员（必填）",
+    "Member of the following groups" : "以下群组的成员",
+    "Set account groups" : "设置帐户组",
+    "Admin of the following groups" : "以下群组的管理员",
+    "Set account as admin for …" : "将帐户设置为管理员...",
     "Quota" : "配额",
+    "Set account quota" : "设置账户配额",
     "Language" : "语言",
     "Set default language" : "设置默认语言",
+    "Add new account" : "添加新帐户",
     "Manager" : "管理者",
+    "Account name will be autogenerated" : "账户名将自动生成",
+    "Account name (required)" : "账户名称（必填）",
     "Total rows summary" : "总行摘要",
     "Scroll to load more rows" : "滚动以加载更多列。",
     "Avatar" : "头像",
@@ -621,6 +659,7 @@ OC.L10N.register(
     "Loading app list" : "正在加载应用程序列表",
     "App Store" : "应用商店",
     "Loading categories" : "正在加载分类",
+    "All accounts" : "所有账号",
     "Admins" : "管理员",
     "Create group" : "创建群组",
     "Group name" : "分组名称",
@@ -631,17 +670,19 @@ OC.L10N.register(
     "Location" : "位置",
     "Profile picture" : "个人头像",
     "About" : "关于",
+    "Date of birth" : "出生日期",
     "Full name" : "全名",
     "Additional email" : "附加邮箱",
+    "Fediverse (e.g. Mastodon)" : "联邦宇宙（例如 Mastodon）",
     "Headline" : "标题",
     "Organisation" : "组织",
     "Phone number" : "电话号码",
     "Role" : "角色",
     "X (formerly Twitter)" : "X（原Twitter）",
-    "Fediverse (e.g. Mastodon)" : "联邦宇宙（例如 Mastodon）",
     "Website" : "网站",
     "Profile visibility" : "个人资料可见性",
     "Locale" : "地区语系",
+    "First day of week" : "一周的第一天",
     "Not available as this property is required for core functionality including file sharing and calendar invitations" : "不可用，因为包括文件共享和日历邀请在内的核心功能需要此属性",
     "Not available as federation has been disabled for your account, contact your system administration if you have any questions" : "不可用，因为您的帐号已禁用联合，如果您有任何疑问，请联系您的系统管理员",
     "Not available as publishing account specific data to the lookup server is not allowed, contact your system administration if you have any questions" : "不可用，因为不允许将帐户特定数据发布到查找服务器，如果您有任何疑问，请联系您的系统管理员",
@@ -653,13 +694,16 @@ OC.L10N.register(
     "Featured apps" : "精选应用",
     "Supported apps" : "支持的应用",
     "Show to everyone" : "显示给所有人",
+    "Show to logged in accounts only" : "仅向登录账户显示",
     "Hide" : "隐藏",
     "Download and enable" : "下载并启用",
     "Allow untested app" : "允许未经测试的应用",
     "The app will be downloaded from the App Store" : "将从应用商店下载应用",
     "This app is not marked as compatible with your Nextcloud version. If you continue you will still be able to install the app. Note that the app might not work as expected." : "此应用被标记为与您的 Nextcloud 版本不兼容。如果您要继续，您仍可安装此应用。请注意此应用可能不会正常工作。",
     "Never" : "从不",
+    "Could not register device: Network error" : "无法注册设备：网络错误",
     "Could not register device: Probably already registered" : "无法注册设备：可能已经注册",
+    "Could not register device" : "无法注册设备",
     "An error occurred during the request. Unable to proceed." : "请求期间发生错误。无法继续。",
     "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "该应用已启用，但是需要更新。将在 5 秒后跳转到更新页面。",
     "Error: This app cannot be enabled because it makes the server unstable" : "错误:这个应用程序不能被启用，因为它使服务器不稳定 ",
@@ -669,11 +713,13 @@ OC.L10N.register(
     "Error while wiping the device with the token" : "使用令牌擦除设备时出错",
     "Error while updating device token name" : "更新设备令牌名称时出错",
     "Error while updating device token scope" : "更新设备令牌范围时出错",
+    "Could not set group sorting" : "无法设置群组排序",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "您的网络请求过多。如果出现错误，请稍后重试或与您的管理员联系。",
     "Error" : "错误",
     "Account documentation" : "账号文档",
     "Administration documentation" : "管理文档",
     "Forum" : "论坛",
+    "Nextcloud help & privacy resources" : "Nextcloud 帮助和隐私资源",
     "General documentation" : "一般文档",
     "Legal notice" : "法律声明",
     "Privacy policy" : "隐私政策",
@@ -690,6 +736,7 @@ OC.L10N.register(
     "Authentication" : "身份认证",
     "Authentication required" : "需要认证",
     "Credentials" : "证书",
+    "SMTP Login" : "SMTP 登录",
     "SMTP Password" : "SMTP 密码",
     "Save" : "保存",
     "Test and verify email settings" : "测试并验证电子邮箱设置",
@@ -703,7 +750,6 @@ OC.L10N.register(
     "Reasons to use Nextcloud in your organization" : "在您的组织中使用 Nextcloud 的原因",
     "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "由 {communityopen}Nextcloud 社区{linkclose} 开发，{githubopen}源代码{linkclose} 基于 {licenseopen}AGPL{linkclose}许可协议。",
     "Like our Facebook page" : "给我们的 Facebook 页面点赞！",
-    "Follow us on Twitter" : "在 Twitter 上关注我们！",
     "Follow us on Mastodon" : "在 Mastodon 上关注我们",
     "Check out our blog" : "浏览我们的博客！",
     "Subscribe to our newsletter" : "订阅我们的最新消息！",
@@ -721,16 +767,23 @@ OC.L10N.register(
     "A background job is pending that checks for user imported SSL certificates. Please check back later." : "一个检查用户导入的 SSL 证书的后台工作正在进行中。请稍后再来检查。",
     "There are some user imported SSL certificates present, that are not used anymore with Nextcloud 21. They can be imported on the command line via \"occ security:certificates:import\" command. Their paths inside the data directory are shown below." : "目前存在一些用户导入的 SSL 证书，这在 Nextcloud 21 中已经不使用了。它们可以通过“occ security:certificates:import”命令在命令行导入。它们在数据目录下的路径如下所示。",
     "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "数据库丢失了一些索引。由于给大的数据表添加索引会耗费一些时间，因此程序没有自动对其进行修复。您可以在 Nextcloud 运行时通过命令行手动执行“occ db:add-missing-indices”命令修复丢失的索引。索引修复后会大大提高相应表的查询速度。",
+    "File locking" : "文件锁定",
+    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems." : "事务性文件锁定已禁用，可能会引发争用问题。请在 config.php 中启用 filelocking.enabled 以避免这类问题的发生。",
     "Could not check for JavaScript support. Please check manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "无法检查 JavaScript 支持。 请手动检查您的网络服务器是否使用 JavaScript MIME 类型提供 \".mjs\" 文件。",
     "You are currently running PHP %s. PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to one of the officially supported PHP versions provided by the PHP Group as soon as possible." : "您当前正在使用 PHP %s。在 Nextcloud 27 中 PHP 8.0 已过时，而在 Nextcloud 28 中可能最低需要 PHP 8.1。请尽快升级 PHP 至官方支持的最新版本。",
     "MariaDB version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MariaDB 10.2 or higher." : "正在使用 MariaDB 版本“%s”。Nextcloud 21 及更新版本不再支持此版本，需要 MariaDB 10.2 或更高版本。",
     "MySQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require MySQL 8.0 or MariaDB 10.2 or higher." : "正在使用 MySQL 版本“%s”。Nextcloud 21 及更新版本不再支持此版本，需要 MySQL 8.0 或 MariaDB 10.2 或更高版本。",
     "PostgreSQL version \"%s\" is used. Nextcloud 21 and higher do not support this version and require PostgreSQL 9.6 or higher." : "正在使用 PostgreSQL 版本“%s”。Nextcloud 21 及更新版本不再支持此版本，需要 PostgreSQL 9.6 或更高版本。",
+    "Speech-To-Text" : "语音转文本",
+    "Speech-To-Text can be implemented by different apps. Here you can set which app should be used." : "语音转文本可由不同的应用程序实现。您可以在此设置使用哪个应用程序。",
+    "None of your currently installed apps provide Speech-To-Text functionality" : "您当前安装的应用程序均不提供语音转文本功能",
+    "None of your currently installed apps provide Text processing functionality" : "您当前安装的应用程序均不提供文本处理功能",
     "Exclude groups from sharing" : "在共享中排除组",
     "These groups will still be able to receive shares, but not to initiate them." : "这些组将仍可以获取共享，但无法向他人共享。",
     "Allow username autocompletion in share dialog and allow access to the system address book" : "允许在分享对话框中自动补全用户名并访问系统通讯录",
     "Two-factor authentication can be enforced for all users and specific groups. If they do not have a two-factor provider configured, they will be unable to log into the system." : "两步验证可以对于所有用户和特定分组启用。如果没有设置两步验证提供者，他们则不能登录到系统。",
     "When groups are selected/excluded, they use the following logic to determine if a user has 2FA enforced: If no groups are selected, 2FA is enabled for everyone except members of the excluded groups. If groups are selected, 2FA is enabled for all members of these. If a user is both in a selected and excluded group, the selected takes precedence and 2FA is enforced." : "当分组被选择/排除时，将使用以下逻辑来确定一个用户是否强制启用两步验证：如果没有选择分组，两步验证将对被排除分组成员外的所有用户启用。如果选择了分组，两步验证将对被选择分组的成员启用。如果一个用户同时属于被选择和被排除分组，被选择分组将拥有优先权，两步验证将对该用户强制启用。",
+    "{license}-licensed" : "{license}-许可协议",
     "Rating: {score}/10" : "评分：{score}/10",
     "Username" : "用户名",
     "Execute one task with each page loaded. Use case: Single user instance." : "每加载一个页面就执行一个任务。使用场景：单一用户实例。",
@@ -753,8 +806,6 @@ OC.L10N.register(
     "Set user manager" : "设置用户管理者",
     "Username will be autogenerated" : "用户名将自动生成",
     "Username (required)" : "用户名（必填）",
-    "_{userCount} user …_::_{userCount} users …_" : ["{userCount} 个用户 ..."],
-    "_{userCount} user_::_{userCount} users_" : ["{userCount} 个用户"],
     "User backend" : "用户来源",
     "User actions" : "用户操作",
     "Loading user …" : "正在加载用户 ...",
@@ -773,18 +824,20 @@ OC.L10N.register(
     "Send welcome email to new users" : "向新用户发送欢迎邮件",
     "Name your device" : "为您的设备命名",
     "Server error while trying to add WebAuthn device" : "尝试添加 WebAuthn 设备时出现服务器错误",
-    "{license}-licensed" : "{license}-许可协议",
     "by {author}\n{license}" : "按照 {author}\n{license}",
     "Active users" : "活跃用户",
     "Disabled users" : "已禁用的用户",
     "Creating group …" : "正在创建群组 ...",
+    "User group: {group}" : "用户群组：{group}",
     "Not available as federation has been disabled for your account, contact your system administrator if you have any questions" : "您的账号上的联合云功能已被停用，如有疑问，请咨询系统管理员。",
     "Not available as publishing user specific data to the lookup server is not allowed, contact your system administrator if you have any questions" : "不可用，因为不允许将特定于用户的数据发布到查找服务器，如果有任何问题，请与系统管理员联系",
     "Show to logged in users only" : "仅显示给登录用户",
     "Nextcloud help resources" : "Nextcloud 帮助资源",
     "SMTP Username" : "SMTP 用户名",
+    "Follow us on Twitter" : "在 Twitter 上关注我们！",
     "To allow this check to run you have to make sure that your webserver can connect to itself. Therefor it must be able to resolve and connect to at least one its `trusted_domains` or the `overwrite.cli.url`." : "要允许此检查运行，您必须确保您的网络服务器可以连接到自身。 因此，它必须能够解析并连接到至少一个 `trusted_domains` 或 `overwrite.cli.url`。",
     "Could not check for JavaScript support via any of your `trusted_domains` nor `overwrite.cli.url`. This may be the result of a server-side DNS mismatch or outbound firewall rule. Please check manually if your webserver serves `.mjs` files using the JavaScript MIME type." : "无法通过您的任何 “trusted_domains\" 或 \"overwrite.cli.url\" 检查 JavaScript 支持。 这可能是服务器端 DNS 不匹配或出站防火墙规则造成的。 请手动检查您的网络服务器是否使用 JavaScript MIME 类型提供 \".mjs\" 文件。",
-    "Active accounts" : "活跃账号"
+    "Active accounts" : "活跃账号",
+    "To allow this check to run you have to make sure that your Web server can connect to itself. Therefore it must be able to resolve and connect to at least one of its `trusted_domains` or the `overwrite.cli.url`. This failure may be the result of a server-side DNS mismatch or outbound firewall rule." : "要允许此检查运行，您必须确保您的 Web 服务器可以连接到自身。因此，它必须能够解析并连接到其 \"trusted_domains\" 或 \"overwrite.cli.url\" 中的至少一个。此失败可能是服务器端 DNS 不匹配或出站防火墙规则的结果。"
 },
 "nplurals=1; plural=0;");
