@@ -214,13 +214,13 @@ class UsersController extends Controller {
 				}, 0);
 			} else {
 				// User is subadmin !
-				// Map group list to names to retrieve the countDisabledUsersOfGroups
+				// Map group list to ids to retrieve the countDisabledUsersOfGroups
 				$userGroups = $this->groupManager->getUserGroups($user);
-				$groupsNames = [];
+				$groupsIds = [];
 
 				foreach ($groups as $key => $group) {
 					// $userCount += (int)$group['usercount'];
-					$groupsNames[] = $group['name'];
+					$groupsIds[] = $group['id'];
 					// we prevent subadmins from looking up themselves
 					// so we lower the count of the groups he belongs to
 					if (array_key_exists($group['id'], $userGroups)) {
@@ -229,7 +229,7 @@ class UsersController extends Controller {
 					}
 				}
 				$userCount += $this->userManager->countUsersOfGroups($groupsInfo->getGroups());
-				$disabledUsers = $this->userManager->countDisabledUsersOfGroups($groupsNames);
+				$disabledUsers = $this->userManager->countDisabledUsersOfGroups($groupsIds);
 			}
 
 			$userCount -= $disabledUsers;
