@@ -13,18 +13,16 @@ OC.L10N.register(
     "Usage survey" : "用量調查",
     "Help improve Nextcloud" : "幫助改善Nextcloud",
     "Do you want to help us to improve Nextcloud by providing some anonymized data about your setup and usage? You can disable it at any time in the admin settings again." : "您是否想通過提供一些有關您的設置和使用情況的匿名數據來幫助我們改善Nextcloud？ 您可以隨時在管理設置中再次禁用它。",
-    "Not now" : "現在不了",
     "Send usage" : "發送使用情況數據",
+    "Not now" : "現在不了",
     "Never" : "絕不",
     "Sends anonymized data to Nextcloud to help us to improve Nextcloud." : "將匿名數據發送到Nextcloud，以幫助我們改進Nextcloud。",
     "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n\t\talways have full control over the content sent to Nextcloud and can disable\n\t\tit again at any time." : "將匿名數據發送到 Nextcloud，以幫助我們改進 Nextcloud。你一律完全控制發送到 Nextcloud 的內容，並且可以隨時禁用。",
     "You can help improve Nextcloud by sending us some data about your current setup and usage." : "您可以通過向我們發送一些有關當前設置和使用情況的數據來幫助改進Nextcloud。",
-    "We take your privacy seriously. Sending data is disabled by default, and should you choose to turn it on, it will be anonymized first, and you are given the option of what things to share. Upon receiving a report, the previous one is removed. Upload a clean report to delete all data currently stored on the server" : "我們非常重視您的私隱。默認情況下，發送數據是停用的，如果您選擇打開它，它將首先被匿名，並且可以選擇共享哪些內容。收到報告後，前一個報告將被刪除。上載乾淨的報告以刪除當前存儲在伺服器上的所有數據",
     "Send new report now" : "立即發送新報告",
     "Send usage survey monthly" : "每月發送使用情況調查",
     "Data to send" : "要發送的數據",
     "Last report sent on: %s" : "上次發送報告的時間：%s",
-    "Last report" : "上次發送的報告",
-    "Sends anonymized data to Nextcloud to help us to improve Nextcloud. You\n        always have full control over the content sent to Nextcloud and can disable\n        it again at any time." : "將匿名數據發送到Nextcloud，以幫助我們改進Nextcloud。你始終完全控制發送到Nextcloud的內容，並且可以隨時禁用。"
+    "Last report" : "上次發送的報告"
 },
 "nplurals=1; plural=0;");
