@@ -1,10 +1,6 @@
 OC.L10N.register(
     "systemtags",
     {
-    "Tag name is empty" : "Markeringsnaam is niet ingevuld",
-    "Update" : "Update",
-    "Create" : "Opslaan",
-    "Select tag …" : "Selecteer tag …",
     "System tag %1$s added by the system" : "Systeemtag %1$s toegevoegd door het systeem",
     "Added system tag {systemtag}" : "Voegde systeemtag {systemtag} toe",
     "Added system tag %1$s" : "Systeemtag %1$s toegevoegd",
@@ -42,27 +38,26 @@ OC.L10N.register(
     "%s (restricted)" : "%s (beperkt)",
     "%s (invisible)" : "%s (onzichtbaar)",
     "<strong>System tags</strong> for a file have been modified" : "<strong>Systeemmarkeringen</strong> voor een bestand zijn gewijzigd",
+    "Files" : "Bestanden",
     "Tags" : "Markering",
     "Collaborative tags" : "Systeemtags",
-    "Collaborative tagging functionality which shares tags among users." : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers.",
-    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers. Perfect voor teams\n(als je een provider met een multi-tenancy installatie bent, adviseren we om deze app uit te schakelen omdat tags worden gedeeld.)",
-    "Failed to load tags" : "Kon tags niet laden",
-    "No tags found" : "Geen tags gevonden",
-    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samenwerkingstags zijn beschikbaar voor alle gebruikers. Beperkte tags zijn zichtbaar voor gebruikers, maar kunnen niet door hen worden toegewezen. Onzichtbare tags zijn er alleen voor intern gebruik, aangezien gebruikers ze niet kunnen zien of toewijzen.",
-    "Create a new tag" : "Creëren nieuw tag",
-    "Name" : "Tag",
+    "Create" : "Opslaan",
+    "Update" : "Update",
+    "Delete" : "Verwijder",
+    "Reset" : "Herstellen",
+    "Loading …" : "Laden …",
     "Public" : "Standaard",
     "Restricted" : "Beschermd",
     "Invisible" : "Verborgen",
-    "Delete" : "Verwijder",
-    "Reset" : "Herstellen",
+    "Failed to load tags" : "Kon tags niet laden",
+    "Collaborative tags are available for all users. Restricted tags are visible to users but cannot be assigned by them. Invisible tags are for internal use, since users cannot see or assign them." : "Samenwerkingstags zijn beschikbaar voor alle gebruikers. Beperkte tags zijn zichtbaar voor gebruikers, maar kunnen niet door hen worden toegewezen. Onzichtbare tags zijn er alleen voor intern gebruik, aangezien gebruikers ze niet kunnen zien of toewijzen.",
+    "No tags found" : "Geen tags gevonden",
+    "Collaborative tagging functionality which shares tags among users." : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers.",
+    "Collaborative tagging functionality which shares tags among users. Great for teams.\n\t(If you are a provider with a multi-tenancy installation, it is advised to deactivate this app as tags are shared.)" : "Samenwerkings tagfunctionaliteit, waardoor je tags kunt delen onder gebruikers. Perfect voor teams\n(als je een provider met een multi-tenancy installatie bent, adviseren we om deze app uit te schakelen omdat tags worden gedeeld.)",
     "No files in here" : "Hier geen bestanden",
     "No entries found in this folder" : "Niets gevonden in deze map",
+    "Name" : "Tag",
     "Size" : "Grootte",
-    "Modified" : "Aangepast",
-    "Tagged files" : "Gemarkeerde bestanden",
-    "Select tags to filter by" : "Selecteer markering om op te filteren",
-    "Please select tags to filter by" : "Selecteer markeringen om op te filteren",
-    "No files found for the selected tags" : "Geen bestanden gevonden voor de geselecteerde markeringen"
+    "Modified" : "Aangepast"
 },
 "nplurals=2; plural=(n != 1);");
