@@ -45,6 +45,7 @@ OC.L10N.register(
     "Guest" : "訪客",
     "Save guest name" : "儲存訪客名稱",
     "Uploading multiple attachments failed." : "上傳多個附件失敗。",
+    "Uploading attachment failed: {error}" : "上傳附件失敗：{error}",
     "Uploading attachment failed." : "上傳附件失敗。",
     "Insert an attachment" : "插入附件",
     "Failed to insert from Files" : "從檔案插入失敗",
@@ -180,20 +181,24 @@ OC.L10N.register(
     "Heading 3" : "標題 3",
     "Heading 4" : "標題 4",
     "Heading 5" : "標題 5",
+    "Lists" : "清單",
     "To-Do list" : "待辦事項清單",
-    "Insert link" : "插入連結",
-    "Callouts" : "標記",
-    "Info" : "資訊",
-    "Success" : "成功",
-    "Warning" : "警告",
-    "Danger" : "危險",
+    "Increase indentation" : "增加縮排",
+    "Decrease indentation" : "減少縮排",
+    "Blocks" : "區塊",
+    "Info callout" : "資訊標記",
+    "Success callout" : "成功標記",
+    "Warning callout" : "警告標記",
+    "Danger callout" : "危險標記",
     "Table" : "表格",
+    "Details" : "詳細資訊",
+    "Insert link" : "插入連結",
     "Insert attachment" : "插入附件",
     "Command" : "指令",
     "Control" : "控制",
     "Option" : "選項",
     "Formatting" : "文字樣式",
-    "Add notes, lists or links …" : "加入筆記、清單或連結…",
+    "Start writing, or try '/' to add, '@' to mention…" : "開始撰寫，或試試看「/」新增、「@」提及……",
     "Add folder description" : "新增資料夾描述",
     "\"{name}\" already exist!" : "「{name}」已存在！",
     "Created \"{name}\"" : "已建立「{name}」",
@@ -203,6 +208,12 @@ OC.L10N.register(
     "Link to this section" : "連結至此節",
     "Show author colors" : "顯示作者顏色",
     "Author colors are only shown until everyone has closed the document." : "僅在所有人都關閉文件前才顯示文件顏色。",
+    "Callouts" : "標記",
+    "Info" : "資訊",
+    "Success" : "成功",
+    "Warning" : "警告",
+    "Danger" : "危險",
+    "Add notes, lists or links …" : "加入筆記、清單或連結…",
     "Add description" : "新增描述"
 },
 "nplurals=1; plural=0;");
