@@ -10,7 +10,7 @@ OC.L10N.register(
     "The given privacy policy address is not a valid URL" : "عنوان سياسة الخصوصية هذا ليس عنوان URL صحيح",
     "The given slogan is too long" : "هذه الشارة slogan أطول مما يجب",
     "The given color is invalid" : "هذا اللون غير صحيح",
-    "Disable-user-theming should be true or false" : "\"إيقاف ثيمة المستخدم\" Disable-user-theming يجب أن تكون إمّا صح أو خطأ",
+    "Disable-user-theming should be true or false" : "\"إيقاف سمات المستخدم\" Disable-user-theming يجب أن تكون إمّا صح أو خطأ",
     "Saved" : "تم الحفظ",
     "Invalid app given" : "التطبيق المُعطى غير صحيح",
     "Invalid type for setting \"defaultApp\" given" : "النوع المُعطى للإعدادات \"defaultApp\" غير صحيح",
@@ -24,20 +24,20 @@ OC.L10N.register(
     "Could not write file to disk" : "لم يستطع كتابة ملف للقرص",
     "A PHP extension stopped the file upload" : "اضافة البي اچ بي PHP اوقفت رفع الملف",
     "No file uploaded" : "لم يتم رفع الملف",
-    "You are already using a custom theme. Theming app settings might be overwritten by that." : "أنت تستخدم الآن ثيمة مُخصّصة. إعدادات تطبيق الثيمات يُمكن أن يتم الكتابة عليها بسبب ذلك. ",
+    "You are already using a custom theme. Theming app settings might be overwritten by that." : "أنت تستخدم الآن سمة مُخصّصة. إعدادات تطبيق السمات يمكن أن تتجاوز مميزات السمة التي تستخدمها.",
     "Theming" : "تخصيص القالب",
     "Appearance and accessibility" : "المظهر و سهولة الوصول ",
     "PHP Imagick module" : "جزئية PHP Imagick ",
     "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "وحدة PHP ـ \"imahick\" غير مُفعّلة بالرغم من تفعيل تطبيق الثيمات theming. حتى يتم توليد الأيقونة الأساسية favicon بشكل صحيح يتوجب تنصيب و تفعيل هذه الوحدة.",
     "The PHP module \"imagick\" in this instance has no SVG support. For better compatibility it is recommended to install it." : "جزئية PHP Imagick في هذا الخادوم لا تدعم خاصية SVG. لتوافق أفضل، يُنصح بتثبيتها",
-    "Dark theme with high contrast mode" : "ثيمة داكنة dark مع وضعية تباين عالي",
+    "Dark theme with high contrast mode" : "سمة داكنة dark مع وضعية تباين عالي",
     "Enable dark high contrast mode" : "فَعِّل وضعية التباين العالي الدّاكن",
     "Similar to the high contrast mode, but with dark colours." : "مُماثلة لوضعية التباين العالي، لكن بألوان داكنة",
     "Dark theme" : "مظهر داكن",
     "Enable dark theme" : "تفعيل المظهر الداكن",
-    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "ثيمة داكنة تريح عينيك من خلال تقليل اللمعان والسطوع بشكل عام",
-    "System default theme" : "ثيمة النظام التلقائية",
-    "Enable the system default" : "تمكين ثيمة النظام التلقائية",
+    "A dark theme to ease your eyes by reducing the overall luminosity and brightness." : "سمة داكنة تريح عينيك من خلال تقليل اللمعان والسطوع بشكل عام",
+    "System default theme" : "سمة النظام التلقائية",
+    "Enable the system default" : "تمكين سمة النظام التلقائية",
     "Using the default system appearance." : "إستخدام المظهر التلقائي للنظام",
     "Dyslexia font" : "خط خاص بالمصابين بعسر القراءة",
     "Enable dyslexia font" : "تفعيل الخط الخاص بالمصابين بعسر القراءة",
@@ -45,12 +45,12 @@ OC.L10N.register(
     "High contrast mode" : "وضع تباين الألوان العالي",
     "Enable high contrast mode" : "تفعيل وضع تباين الألوان العالي",
     "A high contrast mode to ease your navigation. Visual quality will be reduced but clarity will be increased." : "وضع تباين الألوان العالي يساعدك على التنقل في الموقع بسهولة. الجودة المرئية سوف تقل بينما الوضوح سيزداد.",
-    "Light theme" : "ثيمة فاتحة light",
-    "Enable the default light theme" : "مكّن الثيمة التلقائية الفاتحة",
+    "Light theme" : "سمة فاتحة light",
+    "Enable the default light theme" : "تمكين السمة التلقائية الفاتحة",
     "The default light appearance." : "المظهر الفاتح التلقائي.",
     "Legal notice" : "ملاحظة قانونية",
     "Privacy policy" : "سياسة الخصوصية",
-    "Adjust the Nextcloud theme" : "تضبيط ثيمة نكست كلاود",
+    "Adjust the Nextcloud theme" : "تعديل سمة نكست كلاود",
     "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "السمات تجعل من الممكن بسهولة تخصيص الشكل والمظهر لنموذجك ودعم العملاء. سيكون هذا مرئيا لجميع المستخدمين.",
     "Instead of a background image you can also configure a plain background color. If you use a background image changing this color will influence the color of the app menu icons." : "بدلاً من صورة الخلفية، يمكنك أيضًا تكوين لون خلفية عادي. إذا كنت تستخدم صورة خلفية، فإن تغيير هذا اللون سيؤثر على لون أيقونات قائمة التطبيقات.",
     "Background color" : "لون الخلفية",
@@ -73,9 +73,11 @@ OC.L10N.register(
     "Favicon" : "الأيقونة المفضلة",
     "Upload new favicon" : "تحميل أيقونة مفضلة جديدة",
     "User settings" : "إعدادات المستخدم",
-    "Disable user theming" : "إيقاف تصرف المستخدم في الثيمات",
+    "Disable user theming" : "إيقاف تحكم المستخدم في تعديل السمات والمظهر",
     "Although you can select and customize your instance, users can change their background and colors. If you want to enforce your customization, you can toggle this on." : "على الرغم من أنه يمكنك تحديد وتخصيص الخادوم الخاص بك، فإنه يمكن للمستخدمين تغيير صور خلفيات شاشاتهم وألوانهم. إذا كنت تريد فرض التخصيص الخاص بك ، فيمكنك التبديل إلى هذا.",
     "Appearance and accessibility settings" : "إعدادات المظهر و سهولة الوصول",
+    "Misc accessibility options" : "خيارات متفرقة للوصول",
+    "Enable blur background filter (may increase GPU load)" : "تمكين فلتر تضبيب الخلفية (يمكن أن يتسبب في زيادة العبء على المعالج الرسومي  GPU)",
     "Customization has been disabled by your administrator" : "التخصيص موقوف من قِبَل المُشرف",
     "Set a primary color to highlight important elements. The color used for elements such as primary buttons might differ a bit as it gets adjusted to fulfill accessibility requirements." : "يُستعمل الِلون الأساسي لإبراز بعض العناصر مثل الأزرار الهامة. و قد يتم ضبطه قليلاً تلبيةً لمتطلبات سهولة الوصول.",
     "Background and color" : "الخلفية و الألوان",
@@ -94,8 +96,8 @@ OC.L10N.register(
     "Select a background from your files" : "إختر خلفية من ملفاتك",
     "Select background" : "إختَر الخلفية",
     "No background has been selected" : "لم يتم اختيار أي خلفية بعد",
-    "Theme selection is enforced" : "تمّ فرض اختيار الثيمة",
-    "Navigation bar settings" : "إعدادات شريط التنقُّل",
+    "Theme selection is enforced" : "تم فرض اختيار السمة",
+    "Navigation bar settings" : "إعدادات شريط التنقل",
     "You can configure the app order used for the navigation bar. The first entry will be the default app, opened after login or when clicking on the logo." : "يمكنك تهيئة ترتيب التطبيق المستخدم لشريط التنقل. سيكون الإدخال الأول هو التطبيق الافتراضي الذي يتم فتحه بعد تسجيل الدخول أو عند النقر على الشعار.",
     "The default app can not be changed because it was configured by the administrator." : "لا يمكن تغيير التطبيق الافتراضي لأنه تم تكوينه بواسطة المشرف.",
     "The app order was changed, to see it in action you have to reload the page." : "ترتيب التطبيق تمّ تغييره. لرؤية أثر التغيير، يتوجب إعادة تحميل الصفحة.",
