@@ -20,6 +20,8 @@ OC.L10N.register(
     "Set status" : "设定状态",
     "Online status" : "在线状态",
     "Status message" : "状态信息",
+    "Set absence period" : "设置缺勤时段",
+    "Set absence period and replacement" : "设置缺勤时段和替代人员",
     "Your status was set automatically" : "您的状态已自动设定",
     "Clear status message" : "清除状态信息",
     "Set status message" : "设定状态信息",
