@@ -26,8 +26,8 @@ declare(strict_types=1);
 namespace OCA\UserStatus\Connector;
 
 use DateTimeImmutable;
-use OCP\UserStatus\IUserStatus;
 use OCA\UserStatus\Db;
+use OCP\UserStatus\IUserStatus;
 
 class UserStatus implements IUserStatus {
 
@@ -46,12 +46,11 @@ class UserStatus implements IUserStatus {
 	/** @var DateTimeImmutable|null */
 	private $clearAt;
 
-	/**
-	 * UserStatus constructor.
-	 *
-	 * @param Db\UserStatus $status
-	 */
+	/** @var Db\UserStatus */
+	private $internalStatus;
+
 	public function __construct(Db\UserStatus $status) {
+		$this->internalStatus = $status;
 		$this->userId = $status->getUserId();
 		$this->status = $status->getStatus();
 		$this->message = $status->getCustomMessage();
@@ -99,4 +98,8 @@ class UserStatus implements IUserStatus {
 	public function getClearAt(): ?DateTimeImmutable {
 		return $this->clearAt;
 	}
+
+	public function getInternal(): Db\UserStatus {
+		return $this->internalStatus;
+	}
 }
