@@ -7,6 +7,7 @@ OC.L10N.register(
     "Error" : "Erro",
     "Weather status" : "Status do Tempo",
     "Weather status in your dashboard" : "Status do Tempo no seu Painel",
+    "Weather status integrated in the Dashboard app.\n    The geographic location can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Status do tempo integrado no aplicativo Dashboard. \n    A localização geográfica pode ser determinada automaticamente ou definida manualmente. Uma previsão de 6 horas é então exibida. \n    Esse status também pode ser integrado em outros locais, como o aplicativo Calendário.",
     "Detect location" : "Detectar localização",
     "Set custom address" : "Definir endereço personalizado",
     "Favorites" : "Favoritos",
@@ -14,6 +15,18 @@ OC.L10N.register(
     "{temperature} {unit} clear sky" : "{temperature} {unit} céu claro",
     "{temperature} {unit} cloudy later today" : "{temperature} {unit} nublado mais tarde hoje",
     "{temperature} {unit} cloudy" : "{temperature} {unit} nublado",
+    "{temperature} {unit} snow and thunder later today" : "{temperature} {unit}neve e trovoadas ainda hoje",
+    "{temperature} {unit} snow and thunder" : "{temperature} {unit} neve e trovoadas",
+    "{temperature} {unit} snow showers and thunder later today" : "{temperature} {unit}pancadas de neve e trovoadas ainda hoje ",
+    "{temperature} {unit} snow showers and thunder" : "{temperature} {unit} pancadas de neve e trovoadas",
+    "{temperature} {unit} snow showers, thunder and polar twilight later today" : "{temperature} {unit}pancadas de neve, trovoadas e crepúsculo polar ainda hoje ",
+    "{temperature} {unit} snow showers, thunder and polar twilight" : "{temperature} {unit} pancadas de neve, trovoadas e crepúsculo polar",
+    "{temperature} {unit} snow showers later today" : "{temperature} {unit} pancadas de neve ainda hoje",
+    "{temperature} {unit} snow showers" : "{temperature} {unit} pancadas de neve",
+    "{temperature} {unit} snow showers and polar twilight later today" : "{temperature} {unit} pancadas de neve e crepúsculo polar ainda hoje",
+    "{temperature} {unit} snow showers and polar twilight" : "{temperature} {unit} pancadas de neve e crepúsculo polar",
+    "{temperature} {unit} snow later today" : "{temperature} {unit} neve ainda hoje",
+    "{temperature} {unit} snow" : "{temperature} {unit} neve",
     "{temperature} {unit} fair weather later today" : "{temperature} {unit} tempo bom mais tarde hoje",
     "{temperature} {unit} fair weather" : "{temperature} {unit} tempo bom",
     "{temperature} {unit} partly cloudy later today" : "{temperature} {unit} parcialmente nublado hoje mais tarde",
@@ -34,6 +47,7 @@ OC.L10N.register(
     "{temperature} {unit} heavy rainfall showers" : "{temperature} {unit} chuvas fortes",
     "More weather for {adr}" : "Ver mais Tempo para {adr}",
     "Loading weather" : "Carregando Tempo",
+    "Set location for weather" : "Definir localização para o Tempo",
     "Remove from favorites" : "Remover dos favoritos",
     "Add as favorite" : "Adicionar aos favoritos",
     "You are not logged in." : "Você não está conectado.",
@@ -44,7 +58,7 @@ OC.L10N.register(
     "There was an error setting the location." : "Houve um erro ao definir a localização.",
     "There was an error saving the mode." : "Houve um erro ao salvar o modo.",
     "There was an error using personal address." : "Houve um erro ao usar o endereço pessoal.",
-    "Set location for weather" : "Definir localização para o Tempo",
+    "Unknown weather code" : "Código meteorológico desconhecido",
     "Weather status integrated in the Dashboard app.\n    User's position can be automatically determined or manually defined. A 6 hours forecast is then displayed.\n    This status can also be integrated in other places like the Calendar app." : "Status do Tempo integrado no aplicativo Painel.\n    Localização do usuário pode ser obtida automaticamente ou definida manualmente. Uma previsão de 6 horas é então exibida.\n    Esse status também pode ser integrado em outros locais, como no aplicativo Calendário."
 },
 "nplurals=3; plural=(n == 0 || n == 1) ? 0 : n != 0 && n % 1000000 == 0 ? 1 : 2;");
