@@ -87,10 +87,13 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "La actualización no fue exitosa. Por favor reporta este tema a la <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Comunidad Nextcloud</a>.",
     "Continue to {productName}" : "Continuar a {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundo.","La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundos.","La actualización se realizó correctamente. Redireccionándolo a {productName} en %n segundos."],
+    "Apps" : "Aplicaciones",
     "More apps" : "Más aplicaciones",
     "_{count} notification_::_{count} notifications_" : ["{count} notificación","{count} notificaciones","{count} notificaciones"],
     "No" : "No",
     "Yes" : "Sí",
+    "Create share" : "Crear compartición",
+    "Failed to add the public link to your Nextcloud" : "Se presentó una falla al agregar el enlace público a tu Nextcloud",
     "Places" : "Lugares",
     "Today" : "Hoy",
     "Last year" : "Último año",
@@ -127,11 +130,11 @@ OC.L10N.register(
     "Recommended apps" : "Aplicaciones recomendadas",
     "Loading apps …" : "Cargando aplicaciones...",
     "Could not fetch list of apps from the App Store." : "No se pudo obtener la lista de aplicaciones desde la Tienda de aplicaciones.",
-    "Installing apps …" : "Instalando aplicaciones...",
     "App download or installation failed" : "Error al descargar o instalar la aplicación",
     "Cannot install this app because it is not compatible" : "No se puede instalar esta aplicación porque no es compatible",
     "Cannot install this app" : "No se puede instalar esta aplicación",
     "Skip" : "Omitir",
+    "Installing apps …" : "Instalando aplicaciones...",
     "Install recommended apps" : "Instalar aplicaciones recomendadas",
     "Schedule work & meetings, synced with all your devices." : "Programar trabajo y reuniones, sincronizado con todos tus dispositivos.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Mantén a tus colegas y amigos en un solo lugar sin filtrar su información privada.",
@@ -139,6 +142,7 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chat, videollamadas, uso compartido de pantalla, reuniones en línea y videoconferencias, en tu navegador y con aplicaciones móviles.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Documentos colaborativos, hojas de cálculo y presentaciones, basados en Collabora Online.",
     "Distraction free note taking app." : "Aplicación de toma de notas sin distracciones.",
+    "Settings menu" : "Menú de Configuraciones",
     "Search contacts" : "Buscar contactos",
     "Reset search" : "Reestablecer búsqueda",
     "Search contacts …" : "Buscar contactos ...",
@@ -155,7 +159,6 @@ OC.L10N.register(
     "No results for {query}" : "Sin resultados para {query}",
     "Press Enter to start searching" : "Pulse Enter para comenzar a buscar",
     "An error occurred while searching for {type}" : "Se produjo un error al buscar {type}",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Por favor, ingrese {minSearchLength} carácter o más para buscar","Por favor, ingrese {minSearchLength} caracteres o más para buscar","Por favor, ingrese {minSearchLength} caracteres o más para buscar"],
     "Forgot password?" : "¿Olvidaste tu contraseña?",
     "Back to login form" : "Volver al formulario de inicio de sesión",
     "Back" : "Atrás",
@@ -165,12 +168,12 @@ OC.L10N.register(
     "You have not added any info yet" : "No has agregado ninguna información todavía",
     "{user} has not added any info yet" : "{user} no ha agregado ninguna información aún",
     "Error opening the user status modal, try hard refreshing the page" : "Error al abrir el modal de estado del usuario, intenta actualizar la página",
+    "More actions" : "Más acciones",
     "This browser is not supported" : "Este navegador no es compatible",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Tu navegador no es compatible. Por favor, actualízalo a una versión más nueva o una compatible.",
     "Continue with this unsupported browser" : "Continuar con este navegador no compatible",
     "Supported versions" : "Versiones compatibles",
     "{name} version {version} and above" : "{name} versión {version} y superior",
-    "Settings menu" : "Menú de Configuraciones",
     "Search {types} …" : "Buscar {types} ...",
     "Choose" : "Seleccionar",
     "Copy" : "Copiar",
@@ -220,7 +223,6 @@ OC.L10N.register(
     "No tags found" : "No se encontraron etiquetas",
     "Personal" : "Personal",
     "Accounts" : "Cuentas",
-    "Apps" : "Aplicaciones",
     "Admin" : "Administración",
     "Help" : "Ayuda",
     "Access forbidden" : "Acceso prohibido",
@@ -232,7 +234,6 @@ OC.L10N.register(
     "Too many requests" : "Demasiadas solicitudes",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Había demasiadas solicitudes desde tu red. Vuelve a intentarlo más tarde o contacta a tu administrador si se trata de un error.",
     "Error" : "Error",
-    "Previous" : "Previo",
     "Internal Server Error" : "Error interno del servidor",
     "The server was unable to complete your request." : "El servidor no pudo completar tu solicitud.",
     "If this happens again, please send the technical details below to the server administrator." : "Si esto vuelve a suceder, por favor envia los detalles tecnicos siguientes al adminsitrador del sistema.",
@@ -288,6 +289,7 @@ OC.L10N.register(
     "Account connected" : "Cuenta conectada",
     "Your client should now be connected!" : "¡Tu cliente ahora debería estar conectado!",
     "You can close this window." : "Puedes cerrar esta ventana.",
+    "Previous" : "Previo",
     "This share is password-protected" : "Este elemento compartido está protegido con una contraseña",
     "The password is wrong or expired. Please try again or request a new one." : "La contraseña es incorrecta o ha caducado. Por favor, inténtalo de nuevo o solicita una nueva.",
     "Please type in your email address to request a temporary password" : "Por favor, ingresa tu dirección de correo electrónico para solicitar una contraseña temporal",
@@ -331,52 +333,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Su servidor web no está configurado correctamente para resolver \"{url}\". Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Su servidor web no está configurado correctamente para resolver \"{url}\". Esto probablemente se debe a una configuración del servidor web que no se actualizó para entregar esta carpeta directamente. Por favor, compare su configuración con las reglas de reescritura incluidas en \".htaccess\" para Apache o las proporcionadas en la documentación para Nginx en su {linkstart}página de documentación ↗{linkend}. En Nginx, generalmente son las líneas que comienzan con \"location ~\" las que necesitan una actualización.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Su servidor web no está configurado correctamente para entregar archivos .woff2. Esto suele ser un problema de configuración de Nginx. Para Nextcloud 15, necesita un ajuste para entregar también archivos .woff2. Compare su configuración de Nginx con la configuración recomendada en nuestra {linkstart}documentación ↗{linkend}.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP no parece estar configurado correctamente para consultar las variables de ambiente. La prueba con getenv(\"PATH\") sólo regresa una respuesta vacía.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Por favor, consulte la {linkstart}documentación de instalación ↗{linkend} para obtener notas de configuración de PHP y la configuración de PHP de su servidor, especialmente cuando se utiliza php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "La configuración de solo lectura se ha habilitado. Esto impide establecer algunas configuraciones a través de la interfaz web. Además, el archivo debe hacerse editable manualmente en cada actualización.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "No ha configurado ni verificado la configuración del servidor de correo electrónico. Diríjase a la {mailSettingsStart}Configuración básica{mailSettingsEnd} para configurarla. A continuación, utilice el botón \"Enviar correo electrónico\" debajo del formulario para verificar su configuración.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Tu base de datos no puede correr con el nivel de aislamiento de transacción de \"READ COMMITTED\".  Puede causar problemas cuando mútiples acciones sean ejecutadas en paralelo.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Falta el módulo PHP \"fileinfo\". Se recomienda encarecidamente habilitar este módulo para obtener los mejores resultados en la detección de tipos MIME.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "El bloqueo de archivos transaccional está desactivado, lo que podría generar problemas con las condiciones de carrera. Habilite \"filelocking.enabled\" en config.php para evitar estos problemas. Consulte la {linkstart}documentación ↗{linkend} para obtener más información.",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "La base de datos se utiliza para el bloqueo de archivos transaccional. Para mejorar el rendimiento, configure memcache si está disponible. Consulte la {linkstart}documentación ↗{linkend} para obtener más información.",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Asegúrese de establecer la opción \"overwrite.cli.url\" en su archivo config.php con la URL que sus usuarios suelen utilizar para acceder a Nextcloud. Sugerencia: \"{suggestedOverwriteCliURL}\". De lo contrario, podría haber problemas con la generación de URL a través de cron. (Sin embargo, es posible que la URL sugerida no sea la que sus usuarios suelen utilizar para acceder a Nextcloud. Lo mejor es verificar esto en cualquier caso.)",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Su instalación no tiene configurada una región de teléfono predeterminada. Esto es necesario para validar números de teléfono en la configuración del perfil sin un código de país. Para permitir números sin código de país, agregue \"default_phone_region\" con el código {linkstart}ISO 3166-1 correspondiente ↗{linkend} de la región en su archivo de configuración.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "No fue posible ejecutar el trabajo de cron via CLI. Se presentaron los siguientes errores técnicos:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "La última ejecución de la tarea en segundo plano se realizó {relativeTime}. Algo parece estar mal. {linkstart}Verifique la configuración de la tarea en segundo plano ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Esta es la versión de la comunidad no compatible de Nextcloud. Dado el tamaño de esta instancia, no se puede garantizar el rendimiento, la confiabilidad y la escalabilidad. Las notificaciones push están limitadas para evitar sobrecargar nuestro servicio gratuito. Obtenga más información sobre los beneficios de Nextcloud Enterprise en {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Este servidor no tiene conexión a Internet: no se pudo acceder a varios puntos finales. Esto significa que algunas funciones, como el montaje de almacenamiento externo, las notificaciones sobre actualizaciones o la instalación de aplicaciones de terceros, no funcionarán. Es posible que tampoco funcione el acceso a archivos de forma remota y el envío de correos electrónicos de notificación. Establezca una conexión desde este servidor a Internet para disfrutar de todas las funciones.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "No se ha configurado una memoria caché. Para mejorar el rendimiento, configure una memoria caché si está disponible. Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "No se encontró una fuente adecuada de aleatoriedad en PHP, lo cual se desaconseja encarecidamente por razones de seguridad. Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Actualmente está utilizando PHP {version}. Actualice su versión de PHP para aprovechar las {linkstart}actualizaciones de rendimiento y seguridad proporcionadas por el Grupo PHP ↗{linkend} tan pronto como su distribución lo admita.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 está obsoleto en Nextcloud 27. Nextcloud 28 puede requerir al menos PHP 8.1. Actualice a {linkstart}una de las versiones de PHP admitidas oficialmente proporcionadas por el Grupo PHP ↗{linkend} lo antes posible.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "La configuración del encabezado de proxy inverso es incorrecta, o está accediendo a Nextcloud desde un proxy de confianza. Si no es así, esto es un problema de seguridad y puede permitir que un atacante suplante su dirección IP tal como se muestra en Nextcloud. Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached está configurado como caché distribuida, pero se ha instalado el módulo PHP incorrecto \"memcache\". \\OC\\Memcache\\Memcached solo admite \"memcached\" y no \"memcache\". Consulte la {linkstart}wiki de memcached sobre ambos módulos ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Algunos archivos no han superado la comprobación de integridad. Puede encontrar más información sobre cómo resolver este problema en la {linkstart1}documentación ↗{linkend}. ({linkstart2}Lista de archivos no válidos...{linkend} / {linkstart3}Volver a analizar...{linkend})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "El módulo OPcache de PHP no está configurado correctamente. Puede encontrar más información en la {linkstart}documentación ↗{linkend}.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "La función de PHP \"set_time_limit\" no está disponible. Esto podría generar que la ejecución de scripts se detenga, rompiendo su instalación. Se recomienda ámpliamente habilitar esta función. ",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Tu PHP no cuenta con soporte FreeType, lo que resulta en fallas en la imagen de perfil y la interface de configuraciones. ",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Falta el índice \"{indexName}\" en la tabla \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "A la base de datos le faltan algunos índices. Debido a que agregar índices en tablas grandes puede llevar tiempo, no se agregaron automáticamente. Al ejecutar \"occ db:add-missing-indices\", se pueden agregar manualmente esos índices faltantes mientras la instancia sigue funcionando. Una vez que se agregan los índices, las consultas a esas tablas suelen ser mucho más rápidas.",
-    "Missing primary key on table \"{tableName}\"." : "Falta la clave principal en la tabla \"{tableName}\".",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "A la base de datos le faltan algunas claves principales. Debido a que agregar claves principales en tablas grandes puede llevar tiempo, no se agregaron automáticamente. Al ejecutar \"occ db:add-missing-primary-keys\", se pueden agregar manualmente esas claves principales faltantes mientras la instancia sigue funcionando.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Falta la columna opcional \"{columnName}\" en la tabla \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "A la base de datos le faltan algunas columnas opcionales. Debido a que agregar columnas en tablas grandes puede llevar tiempo, no se agregaron automáticamente cuando pueden ser opcionales. Al ejecutar \"occ db:add-missing-columns\", se pueden agregar manualmente esas columnas faltantes mientras la instancia sigue funcionando. Una vez que se agregan las columnas, algunas características pueden mejorar la capacidad de respuesta o la usabilidad.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "A esta instancia le faltan algunos módulos PHP recomendados. Para mejorar el rendimiento y la compatibilidad, se recomienda instalarlos.",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "No se ha habilitado el módulo PHP \"imagick\", aunque está habilitada la aplicación de temas. Para que la generación de favicon funcione correctamente, debe instalar y habilitar este módulo.",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "No se han habilitado los módulos PHP \"gmp\" y/o \"bcmath\". Si utiliza la autenticación sin contraseña de WebAuthn, se requieren estos módulos.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Parece que está ejecutando una versión de PHP de 32 bits. Nextcloud necesita 64 bits para funcionar correctamente. ¡Actualice su sistema operativo y PHP a 64 bits! Para obtener más detalles, lea {linkstart}la página de documentación sobre este tema ↗{linkend}.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "El módulo php-imagick en esta instancia no tiene soporte para SVG. Para una mejor compatibilidad, se recomienda instalarlo.",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Algunas columnas en la base de datos no tienen una conversión a big int. Debido a que cambiar los tipos de columna en tablas grandes puede llevar tiempo, no se cambiaron automáticamente. Al ejecutar \"occ db:convert-filecache-bigint\", se pueden aplicar manualmente esos cambios pendientes. Esta operación debe realizarse mientras la instancia esté fuera de línea. Para obtener más detalles, lea {linkstart}la página de documentación sobre este tema ↗{linkend}.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Actualmente estás usando SQLite como el backend de base de datos. Para instalaciones más grandes te recomendamos cambiar a un backend de base de datos diferente.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Esto es particularmente recomendado cuando se usa el cliente de escritorio para sincronización de archivos. ",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Para migrar a otra base de datos, utilice la herramienta de línea de comandos: \"occ db:convert-type\" o consulte la {linkstart}documentación ↗{linkend}.",
-    "The PHP memory limit is below the recommended value of 512MB." : "El límite de memoria PHP está por debajo del valor recomendado de 512 MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Algunos directorios de aplicaciones son propiedad de un usuario diferente al del servidor web. Esto puede ocurrir si las aplicaciones se han instalado manualmente. Compruebe los permisos de los siguientes directorios de aplicaciones:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Se utiliza MySQL como base de datos, pero no admite caracteres de 4 bytes. Para poder manejar caracteres de 4 bytes (como emojis) sin problemas en nombres de archivos o comentarios, por ejemplo, se recomienda habilitar el soporte de 4 bytes en MySQL. Para obtener más detalles, lea {linkstart}la página de documentación sobre este tema ↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Esta instancia utiliza un almacenamiento principal basado en S3. Los archivos cargados se almacenan temporalmente en el servidor, por lo que se recomienda disponer de 50 GB de espacio libre en el directorio temporal de PHP. Consulte los registros para obtener detalles completos sobre la ruta y el espacio disponible. Para mejorar esto, cambie el directorio temporal en el php.ini o aumente el espacio disponible en esa ruta.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "El directorio temporal de esta instancia apunta a un directorio que no existe o no se puede escribir en él.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Está accediendo a su instancia a través de una conexión segura, sin embargo, su instancia está generando URL no seguras. Esto probablemente significa que está detrás de un proxy inverso y las variables de configuración de sobrescritura no están configuradas correctamente. Lea {linkstart}la página de documentación sobre este tema ↗{linkend}.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Esta instancia se está ejecutando en modo de depuración. Solo habilite esto para el desarrollo local y no en entornos de producción.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Su directorio de datos y sus archivos probablemente sean accesibles desde Internet. El archivo .htaccess no está funcionando. Se recomienda encarecidamente que configure su servidor web de manera que el directorio de datos ya no sea accesible, o mueva el directorio de datos fuera de la raíz del documento del servidor web.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" está establecido a \"{expected}\". Esto representa un riesgo potencial de seguridad o privacidad, y que se recomienda ajustar esta configuración. ",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "El encabezado HTTP \"{header}\" no está establecido a \"{expected}\". Puede que lgunas características no funcionen correctamente, y se recomienda ajustar esta confirguración. ",
@@ -389,38 +346,13 @@ OC.L10N.register(
     "User disabled" : "Usuario deshabilitado",
     "Username or email" : "Usuario o correo electrónico",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Si esta cuenta existe, se ha enviado un mensaje de restablecimiento de contraseña a su dirección de correo electrónico. Si no lo recibe, verifique su dirección de correo electrónico y/o nombre de cuenta, revise las carpetas de spam/correo no deseado o solicite ayuda a su administración local.",
-    "Start search" : "Iniciar búsqueda",
-    "Open settings menu" : "Abrir menú de configuración",
-    "Settings" : "Configuraciones ",
-    "Avatar of {fullName}" : "Avatar de {fullName}",
-    "Show all contacts …" : "Mostrar todos los contactos ...",
-    "No files in here" : "No hay archivos aquí",
-    "New folder" : "Carpeta nueva",
-    "No more subfolders in here" : "No hay más subcarpetas aquí",
-    "Name" : "Nombre",
-    "Size" : "Tamaño",
-    "Modified" : "Modificado",
-    "\"{name}\" is an invalid file name." : "\"{name}\" es un nombre de archivo inválido.",
-    "File name cannot be empty." : "El nombre de archivo no puede estar vacío.",
-    "\"/\" is not allowed inside a file name." : "No se permite el uso del caracter \"/\" en el nombre del archivo.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" no es in tipo de archivo permitido",
-    "{newName} already exists" : "{newName} ya existe",
-    "Error loading file picker template: {error}" : "Se presentó un error al cargar la plantilla del seleccionador de archivos: {error}",
     "Error loading message template: {error}" : "Se presentó un error al cargar la plantilla del mensaje: {error}",
-    "Show list view" : "Mostrar vista de lista",
-    "Show grid view" : "Mostrar vista de cuadrícula",
-    "Pending" : "Pendiente",
-    "Home" : "Inicio",
-    "Copy to {folder}" : "Copiar a {folder}",
-    "Move to {folder}" : "Mover a {folder}",
-    "Authentication required" : "Se requiere autenticación",
-    "This action requires you to confirm your password" : "Esta acción requiere que confirmes tu contraseña",
-    "Confirm" : "Confirmar",
-    "Failed to authenticate, try again" : "Falla en la autenticación, por favor reintentalo",
     "Users" : "Usuarios",
     "Username" : "Usuario",
     "Database user" : "Usuario de la base de datos",
+    "This action requires you to confirm your password" : "Esta acción requiere que confirmes tu contraseña",
     "Confirm your password" : "Confirma tu contraseña",
+    "Confirm" : "Confirmar",
     "App token" : "Ficha de la aplicación",
     "Alternative log in using app token" : "Inicio de sesión alternativo usando una ficha de aplicación",
     "Please use the command line updater because you have a big instance with more than 50 users." : "Favor de usar el actualizador desde la línea de comandos ya que tu instancia cuenta con más de 50 usuarios."
