@@ -43,6 +43,7 @@ OC.L10N.register(
     "Task not found" : "Ez da eginkizuna aurkitu",
     "Internal error" : "Barne errorea",
     "Not found" : "Ez da aurkitu",
+    "Bad request" : "Eskaera txarra",
     "Requested task type does not exist" : "Eskatutako eginkizun mota ez da existitzen",
     "Necessary language model provider is not available" : "Beharrezko lengoaia-modelo hornitzailea ez dago eskuragarri",
     "No text to image provider is available" : "Ez dago testutik irudirako hornitzailerik erabilgarri",
@@ -97,10 +98,19 @@ OC.L10N.register(
     "Continue to {productName}" : "Jarraitu hona: {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Eguneraketa behar bezala egin da. {ProductName} ra birbideratuko zaitugu %nsegundotan.","Eguneraketa behar bezala egin da. {ProductName}(e)ra birbideratuko zaitugu %n segundotan."],
     "Applications menu" : "Aplikazio-menua",
+    "Apps" : "Aplikazioak",
     "More apps" : "Aplikazio gehiago",
     "_{count} notification_::_{count} notifications_" : ["Jakinarazpen {count}","{count} jakinarazpenak"],
     "No" : "Ez",
     "Yes" : "Bai",
+    "Federated user" : "Erabiltzaile federatua",
+    "user@your-nextcloud.org" : "erabiltzaile@zure-nextcloud.org",
+    "Create share" : "Sortu partekatzea",
+    "The remote URL must include the user." : "Urruneko URLak erabiltzailea eduki behar du.",
+    "Invalid remote URL." : "Urruneko URL baliogabea",
+    "Failed to add the public link to your Nextcloud" : "Huts egin du esteka publikoa zure Nextcloudera gehitzean",
+    "Direct link copied to clipboard" : "Esteka zuzena arbelera kopiatuta",
+    "Please copy the link manually:" : "Mesedez kopiatu esteka eskuz:",
     "Custom date range" : "Data-tarte pertsonalizatua",
     "Pick start date" : "Aukeratu hasiera-data",
     "Pick end date" : "Aukeratu amaiera-data",
@@ -161,11 +171,11 @@ OC.L10N.register(
     "Recommended apps" : "Gomendatutako aplikazioak",
     "Loading apps …" : "Aplikazioak kargatzen...",
     "Could not fetch list of apps from the App Store." : "Ezin izan da aplikazioen zerrenda eskuratu aplikazioen dendatik.",
-    "Installing apps …" : "Aplikazioak instalatzen...",
     "App download or installation failed" : "Huts egin du aplikazioaren deskarga edo instalazioak",
     "Cannot install this app because it is not compatible" : "Ezin da aplikazio hau instalatu ez delako bateragarria",
     "Cannot install this app" : "Ezin da aplikazio hau instalatu",
     "Skip" : "Saltatu",
+    "Installing apps …" : "Aplikazioak instalatzen...",
     "Install recommended apps" : "Instalatu gomendatutako aplikazioak",
     "Schedule work & meetings, synced with all your devices." : "Antolatu lana eta bilerak, zure gailu guztiekin sinkronizatuta.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Eduki zure lankide eta lagun guztiak leku bakarrean, beren informazioa pribatu mantenduz.",
@@ -173,6 +183,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Txata, bideo-deiak, pantaila partekatzea, lineako bilerak eta web konferentziak - zure nabigatzailean eta mugikorrerako aplikazioekin.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Dokumentu, kalkulu-orri eta aurkezpen kolaboratiboak, Collabora Online-en sortuak.",
     "Distraction free note taking app." : "Distrakziorik gabeko oharrak hartzeko aplikazioa.",
+    "Settings menu" : "Ezarpenen menua",
+    "Avatar of {displayName}" : "{displayName}-(r)en avatarra",
     "Search contacts" : "Bilatu kontaktuak",
     "Reset search" : "Berrezarri bilaketa",
     "Search contacts …" : "Bilatu kontaktuak...",
@@ -189,7 +201,6 @@ OC.L10N.register(
     "No results for {query}" : " {query}-(r)entzako emaitzarik ez",
     "Press Enter to start searching" : "Sakatu enter bilaketa hasteko",
     "An error occurred while searching for {type}" : "Errorea gertatu da {type} bilatzean",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Sartu karaktere {minSearchLength} edo gehiago bilatzeko","Sartu {minSearchLength} karaktere edo gehiago bilatzeko"],
     "Forgot password?" : "Pasahitza ahaztu duzu?",
     "Back to login form" : "Itzuli saio hasierara",
     "Back" : "Atzera",
@@ -200,13 +211,12 @@ OC.L10N.register(
     "You have not added any info yet" : "Oraindik ez duzu informaziorik gehitu",
     "{user} has not added any info yet" : "{user}-(e)k ez du oraindik informaziorik gehitu",
     "Error opening the user status modal, try hard refreshing the page" : "Errorea erabiltzailen egoera leihoa irekitzean, saiatu orria guztiz freskatzen",
+    "More actions" : "Ekintza gehiago",
     "This browser is not supported" : "Nabigatzaile hau ez da onartzen",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Zure nabigatzailea ez da onartzen. Mesedez, eguneratu bertsio berriago batera edo onartzen den batera.",
     "Continue with this unsupported browser" : "Jarraitu onartzen ez den arakatzaile honekin",
     "Supported versions" : "Onartutako bertsioak",
     "{name} version {version} and above" : "{name} {bertsioa} bertsioa eta hortik gorakoak",
-    "Settings menu" : "Ezarpenen menua",
-    "Avatar of {displayName}" : "{displayName}-(r)en avatarra",
     "Search {types} …" : "Bilatu  {types} …",
     "Choose {file}" : "Aukeratu {file}",
     "Choose" : "Aukeratu",
@@ -260,7 +270,6 @@ OC.L10N.register(
     "No tags found" : "Ez da etiketarik aurkitu",
     "Personal" : "Pertsonala",
     "Accounts" : "Kontuak",
-    "Apps" : "Aplikazioak",
     "Admin" : "Admin",
     "Help" : "Laguntza",
     "Access forbidden" : "Sarrera debekatuta",
@@ -272,7 +281,6 @@ OC.L10N.register(
     "Too many requests" : "Eskaera gehiegi",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Eskaera gehiegi zeuden zure saretik. Saiatu beranduago edo kontaktatu zure administrailearekin hau errorea bada.",
     "Error" : "Errorea",
-    "Previous" : "Aurrekoa",
     "Internal Server Error" : "Zerbitzariaren barne-errorea",
     "The server was unable to complete your request." : "Zerbitzariak ezin izan du zure eskaera bete.",
     "If this happens again, please send the technical details below to the server administrator." : "Hau berriro gertatzen bada, mesedez bidali ondoko datu teknikoak zure administratzaileari.",
@@ -332,6 +340,7 @@ OC.L10N.register(
     "Account connected" : "Kontua konektatuta",
     "Your client should now be connected!" : "Zure bezeroak konektatua behar luke orain!",
     "You can close this window." : "Leiho hau itxi dezakezu.",
+    "Previous" : "Aurrekoa",
     "This share is password-protected" : "Partekatze hau pasahitzez babestua dago.",
     "The password is wrong or expired. Please try again or request a new one." : "Pasahitza oker dago edo iraungita dago. Mesedez, saiatu berriro edo eskatu berri bat.",
     "Please type in your email address to request a temporary password" : "Idatzi zure helbide elektronikoa aldi baterako pasahitza eskatzeko",
@@ -376,53 +385,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Zure web zerbitzaria ez dago behar bezala konfiguratuta \"{url}\" ebazteko. Informazio gehiago {linkstart}dokumentazioan ↗{linkend} aurkitu daiteke.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Zure web zerbitzaria ez dago behar bezala konfiguratuta \"{url}\" ebazteko. Ziur aski web zerbitzariaren konfigurazioa ez dago karpeta hau zuzenean entregatzeko eguneratuta. Konparatu zure konfigurazioa eskaintzen den Apacherako \".htaccess\" fitxategiko berridazketa arauekin edo Nginx-en {linkstart}dokumentazio orria ↗{linkend} dokumentazioarekin. Nginx-en \"location ~\" katearekin hasten diren lerroak izan ohi dira eguneratu beharrekoak.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Zure web zerbitzaria ez dago behar bezala konfiguratuta .woff2 fitxategiak entregatzeko. Hau Nginx-en konfigurazioaren ohiko arazo bat da. Nextcloud 15ean doikuntza bat beharrezkoa da .woff2 fitxategiak bidaltzeko. Konparatu zure Nginx konfigurazioa gure {linkstart}dokumentazioan ↗{linkend}  gomendatutakoarekin.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Badirudi PHPa sistemaren ingurune aldagaiak kontsultatu ahal izateko behar bezala konfiguratu gabe dagoela. Egindako getenv(\"PATH\") probak erantzun hutsa itzultzen du.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Mesedez, begiratu {linkstart}instalazio dokumentazioa ↗ {linked} PHP konfigurazio oharrak eta zure zerbitzariaren PHP konfigurazioa, batez ere php-fpm erabiltzean. ",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Irakurtzeko soilik konfigurazioa gaitu da. Honek web interfazetik konfigurazio batzuk ezartzea eragozten du. Gainera, eguneraketa bakoitzean fitxategia idazteko moduan jarri behar da eskuz.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Oraindik ez duzu posta elektronikoko zerbitzariaren konfigurazioa ezarri edo egiaztatu. Mesedez, joan {mailSettingsStart}Oinarrizko ezarpenetara{mailSettingsEnd} hauek ezartzeko. Ondoren, erabili inprimakiaren azpiko \"Bidali mezu elektronikoa\" botoia zure ezarpenak egiaztatzeko.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Zure datu-basea ez da \"READ COMMITTED\" transakzio isolamendu mailarekin exekutatzen. Honek arazoak eragin ditzake hainbat ekintza paraleloan exekutatzen direnean.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "PHPren \"fileinfo\" modulua falta da. Biziki gomendatzen da modulu hau gaitzea, MIME moten detekzioan emaitza hobeak lortzeko.",
-    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Zure urrutiko helbidea  \"{remoteAddress}\" bezala identifikatua izan da, eta gelditzera behartuta dago une honetan eskaera batzuen errendimendua gutxituz. Urrutiko helbidea zure helbidea ez bada, proxy bat ez dela behar bezala konfiguratu adierazten du. Informazio gehiago aurkitu daiteke {linkstart} dokumentazioan ↗{linkend}.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transakzio-fitxategiak blokeatzea desgaituta dago, honek lasterketa baldintzekin arazoak sor ditzake. Gaitu \"filelocking.enabled\" config.php-n arazo horiek saihesteko. Informazio gehiago lortzeko, ikusi {linkstart}dokumentazioa ↗ {linkend}.",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "Datu-basea fitxategi transakzionalak blokeatzeko erabiltzen da. Errendimendua hobetzeko, mesedez konfiguratu memcache, eskuragarri badago. Ikusi {linkstart}dokumentazioa ↗{linkend} informazio gehiago lortzeko.",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Mesedez, ziurtatu zure config.php fitxategiko \"overwrite.cli.url\" aukera zure erabiltzaileek nagusiki Nextcloud honetara sartzeko erabiltzen duten URLan ezartzen duzula. Iradokizuna: \"{suggestedOverwriteCliURL}\". Bestela, URLa sortzeko arazoak egon daitezke cron bidez. (Litekeena da iradokitako URLa ez izatea zure erabiltzaileek nagusiki Nextcloud honetara atzitzeko erabiltzen duten URLa. Edonola ere, hau egiaztatzea da onena.)",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Zure instalazioak ez du telefono eskualde lehenetsirik ezarrita. Hori beharrezkoa da profil ezarpenetan herrialde koderik gabe jarritako telefono zenbakiak baliozkotzeko. Herrialde koderik gabeko zenbakiak onartzeko, gehitu \"default_phone_region\" dagokion eskualdeko {linkstart}ISO 3166-1 kodea ↗{linkend} zure konfigurazio fitxategian.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ezin izan da cron lana komando lerro bidez exekutatu. Ondorengo errore teknikoak gertatu dira:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Atzeko planoaren azken lana {relativeTime} exekutatu da. Badirudi zerbait gaizki dagoela. {linkstart}Egiaztatu atzeko planoko ezarpenak ↗ {linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Hau laguntzarik gabeko Nextcloud komunitate bertsioa da. Instantzia honen tamaina kontuan hartuz, ezin da errendimendua, fidagarritasuna eta eskalabilitatea ziurtatu. Push jakinarazpenak mugatu egin dira gure doako zerbitzua ez gainkargatzeko. Ikusi Nextcloud Enterpriseren abantailei buruzkoak {linkstart}https://nextcloud.com/enterprise{linkend} orrian.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Zerbitzari honek ez dauka Interneteko konexiorik: hainbat amaiera-puntu ezin izan dira atzitu. Horren ondorioz, hainbat ezaugarrik ez dute funtzionatuko, hala nola, kanpoko biltegiratzeak muntatzeak, eguneraketei buruzko jakinarazpenek edo hirugarrengoen aplikazioek. Urruneko fitxategiak atzitzeak eta posta elektroniko bidezko jakinarazpenek ere ez dute funtzionatuko. Ezarri Interneterako konexioa zerbitzari honetan ezaugarri horiek izateko.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Ez da memoria cachea konfiguratu. Errendimendua hobetzeko, konfiguratu memcache bat, erabilgarri badago. Informazio gehiago aurki dezakezu {linkstart}dokumentazioan ↗ {linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "PHP-k ez du aurkitu iturri egokirik ausazkotasunerako, segurtasun arrazoiengatik oso gomendagarria dena. Informazio gehiago aurki dezakezu {linkstart}dokumentazioan ↗ {linkend}.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Une honetan PHP {version} exekutatzen ari zara. Bertsio-berritu zure PHP bertsioa {linkstart}PHP Group-ek eskaintzen dituen errendimendu eta segurtasun eguneratzeak ↗{linkend} aprobetxatzeko zure banaketak onartu bezain laster.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 zaharkituta dago Nextcloud 27-n. Baliteke Nextcloud 28-k gutxienez PHP 8.1 behar izatea. Mesedez, eguneratu {linkstart}PHP Group-ek ofizialki onartzen dituen ↗{linkend} PHP bertsio batera ahalik eta lasterren.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Alderantzizko proxy goiburuko konfigurazioa okerra da, edo Nextcloudera proxy fidagarri batetik sartzen ari zara. Hala ez bada, segurtasun arazo bat da eta erasotzaile batek bere IPa Nextcloudentzat ikusgai gisa faltsutzea baimendu dezake. Informazio gehiago aurkitu daiteke {linkstart}dokumentazioan ↗ {linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached banatutako cache gisa konfiguratuta dago, baina \"memcache\" PHP modulu okerra dago instalatuta. \\ OC \\ Memcache \\ Memcached-ek \"memcached\" soilik onartzen du eta ez \"memcache\". Ikusi bi moduluei buruzko {linkstart}memcached wikia ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Zenbait fitxategik ez dute integritate egiaztapena gainditu. Arazo hau konpontzeko moduari buruzko informazio gehiago aurki daiteke {linkstart1}dokumentazioan ↗{linkend}. ({linkstart2}Baliogabeko fitxategien zerrenda...{linkend} / {linkstart3}Eskaneatu berriro...{linkend})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "PHP OPcache modulua ez dago behar bezala konfiguratuta. Ikus {linkstart}dokumentazioa ↗{linkend} informazio gehiago lortzeko.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "PHPko \"set_time_limit\" funtzioa ez dago erabilgarri. Horren eraginez script-ak exekuzioaren erdian gelditu daitezke, zure instalazioa puskatuz. Biziki gomendatzen da funtzio hau gaitzea.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Zure PHPak ez dauka FreeType euskarririk. Ondorioz, profileko irudiak eta ezarpenen interfazea hondatuta daude.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "\"{indexName}\" indizea falta da \"{tableName}\" taulan.",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Datu-baseak zenbait indize falta ditu. Taula handietan indizeak gehitzeak denbora dezente har dezakeenez ez dira automatikoki gehitu. \"occ db:add-missing-indices\" exekutatuz indize horiek eskuz gehitu daitezke instantzia martxan dagoen bitartean. Indizeak gehitu ondoren taula horietan egindako kontsultak askoz azkarragoak izan ohi dira.",
-    "Missing primary key on table \"{tableName}\"." : "Gako nagusia falta da \"{tableName}\" taulan.",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "Datu-baseak zenbait gako nagusi falta ditu. Taula handietan datu nagusiak gehitzeak denbora dezente har dezakeenez ez dira automatikoki gehitu. \"occ db:add-missing-primary-keys\" exekutatuz falta diren gako nagusi horiek eskuz gehitu daitezke instantzia martxan dagoen bitartean.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "\"{columnName}\" hautazko zutabea falta da \"{tableName}\" taulan.",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Datu-baseak zenbait hautazko zutabe falta ditu. Hautazkoak izanik ez dira automatikoki gehitu, taula handietan zutabeak gehitzeak denbora behar duelako. Zutabe horiek eskuz gehitu daitezke, instantzia martxan dagoen bitartean, \"occ db:add-missing-columns\" exekutatuz. Zutabeak gehitu ondoren, ezaugarri batzuek erantzuteko gaitasuna eta erabilgarritasuna hobetu dezakete.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Instantzia honek gomendatutako PHP modulu batzuk falta ditu. Biziki gomendatzen da horiek instalatzea, errendimendua eta bateragarritasuna hobetzeko.",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "\"Imagick\" PHP modulua  ez dago gaituta, nahiz eta gaiak pertsonalizatzeko aplikazioa badagoen. Faviconen sorrerak behar bezala funtziona dezan, modulu hau instalatu eta gaitu behar duzu.",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "\"gmp\" eta/edo \"bcmath\" PHP moduluak ez daude gaituta. WebAuthn pasahitz gabeko autentifikazioa erabiltzen baduzu, modulu hauek beharrezkoak dira.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "32 biteko PHP bertsioa exekutatzen ari zarela dirudi. Nextcloud-ek 64 bitekoa behar du ondo exekutatzeko. Eguneratu zure OS eta PHP 64 bitekora! Xehetasun gehiago lortzeko, irakurri {linkstart}honi buruzko dokumentazio orria ↗{linkend}.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Instantzia honetan php-imagick moduluak ez du SVG onartzen. Bateragarritasuna hobetzeko instalatzea gomendatzen da.",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Datu baseko zutabe batzuek big int bihurtzea falta dute. Taula handietan zutabe motak aldatzeak denbora dezente har dezakeenez ez dira automatikoki aldatu. 'Occ db: convert-filecache-bigint' exekutatuz zain dauden aldaketak eskuz aplika daitezke. Eragiketa hau instantzia lineaz kanpo dagoen bitartean egin behar da. Xehetasun gehiagorako, irakurri {linkstart}honi buruzko dokumentazio orria ↗{linkend}.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite datu-basea erabiltzen ari zara. Instalazio handiagoetarako beste datu-base sistema bat erabiltzea gomendatzen da.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Bereziki gomendagarria da mahaigaineko bezeroa fitxategien sinkronizaziorako erabiltzean.",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Beste datu-base batera migratzeko, erabili komando lerroko tresna: \"occ db:convert-type\", edo ikusi {linkstart}dokumentazioa ↗{linkend}.",
-    "The PHP memory limit is below the recommended value of 512MB." : "PHPren memoria muga aholkatutako 512MB balioaren azpitik dago.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Zenbait aplikazio direktorioren jabea ez dator bat web zerbitzariaren erabiltzailearekin. Aplikazio horiek eskuz instalatzean gerta daiteke hori. Egiaztatu baimenak ondorengo aplikazio direktorioetan:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL datu-base gisa erabiltzen da baina ez ditu 4 byteko karaktereak onartzen. 4 byteko karaktereak (emojiak kasu) arazorik gabe erabiltzeko, adibidez, fitxategien izenetan edo iruzkinetan, MySQL-n 4 byteko euskarria gaitzea gomendatzen da. Xehetasun gehiagorako, irakurri {linkstart}honi buruzko dokumentazio orria ↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Instantzia honek S3n oinarritutako objektuen biltegia erabiltzen du biltegiratze nagusi bezala. Igotako fitxategiak behin-behinean zerbitzarian gordetzen direnez, PHPren aldi baterako direktorioan 50 GB libre edukitzea gomendatzen da. Egiaztatu egunkariak bideari eta erabilgarri dagoen espazioari buruzko xehetasunak izateko. Hau hobetzeko aldatu aldi baterako direktorioa php.ini fitxategian edo egin leku gehiago bide horretan.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Instantzia honen aldi baterako direktorioak existitzen ez den edo idatzi ezin den direktorio batera erreferentziatzen du.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "Zure instantziara konexio seguru baten bidez sartzen ari zara, hala ere, instantziak seguruak ez diren URLak sortzen ditu. Seguruenik horrek esan nahi du alderantzizko proxy baten atzean zaudela eta gainidazte konfigurazio aldagaiak ez daudela ondo ezarrita. Irakurri {linkstart}honi buruzko dokumentazio orria ↗{linkend}.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Instantzia hau arazketa moduan exekutatzen ari da. Gaitu hau garapen lokalerako soilik eta ez produkzio inguruneetarako.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Zure datuen direktorioa eta fitxategiak Internetetik atzitu daitezke seguru aski. .htaccess fitxategiak ez du funtzionatzen. Biziki gomendatzen da web zerbitzariaren konfigurazioa aldatzea datuen direktorioa atzigarri egon ez dadin, edo datuen direktorioa ateratzea web zerbitzariaren dokumentuen errotik kanpora.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP goiburua ez dago \"{expected}\" baliora ezarria. Hau segurtasun edo pribatutasun arrisku bat izan daiteke. Ezarpenean dagokion balioa jartzea gomendatzen da.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "\"{header}\" HTTP goiburua ez dago \"{expected}\" baliora ezarria. Baliteke ezaugarri batzuk espero bezala ez funtzionatzea. Ezarpenean dagokion balioa jartzea gomendatzen da.",
@@ -433,45 +396,20 @@ OC.L10N.register(
     "Currently open" : "Irekita une honetan",
     "Wrong username or password." : "Erabiltzaile-izen edo pasahitz okerra.",
     "User disabled" : "Erabiltzailea desgaituta",
+    "Login with username or email" : "Hasi saioa erabiltzaile-izen edo e-postarekin",
+    "Login with username" : "Hasi saioa erabiltzaile-izenarekin",
     "Username or email" : "Erabiltzaile-izena edo posta elektronikoa",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Kontu hau badago, pasahitza berrezartzeko mezua bidali da bere helbide elektronikora. Jasotzen ez baduzu, egiaztatu zure helbide elektronikoa eta/edo kontuaren izena, egiaztatu spam/zabor-karpetak edo eskatu laguntza administrazio lokalari.",
-    "Start search" : "Hasi bilaketa",
-    "Open settings menu" : "Ireki ezarpenen menua",
-    "Settings" : "Ezarpenak",
-    "Avatar of {fullName}" : "{fullName}-(r)en avatarra",
-    "Show all contacts …" : "Erakutsi kontaktu guztiak...",
-    "No files in here" : "Ez dago fitxategirik hemen",
-    "New folder" : "Karpeta berria",
-    "No more subfolders in here" : "Ez dago azpikarpeta gehiagorik hemen",
-    "Name" : "Izena",
-    "Size" : "Tamaina",
-    "Modified" : "Aldatua",
-    "\"{name}\" is an invalid file name." : "\"{name}\" fitxategi-izen baliogabea da.",
-    "File name cannot be empty." : "Fitxategi-izena ezin da hutsa izan.",
-    "\"/\" is not allowed inside a file name." : "\"/\" ez da onartzen fitxategi-izenen barnean.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" fitxategi-mota ez da onartzen",
-    "{newName} already exists" : "{newName} badago aurretik",
-    "Error loading file picker template: {error}" : "Errorea fitxategi-hautatzailearen txantiloia kargatzerakoan: {error}",
+    "Apps and Settings" : "Aplikazioak eta ezarpenak",
     "Error loading message template: {error}" : "Errorea mezu txantiloia kargatzean: {error}",
-    "Show list view" : "Erakutsi zerrenda ikuspegia",
-    "Show grid view" : "Erakutsi sareta-ikuspegia",
-    "Pending" : "Zain",
-    "Home" : "Hasiera",
-    "Copy to {folder}" : "Kopiatu hona: {folder}",
-    "Move to {folder}" : "Eraman hona: {folder}",
-    "Authentication required" : "Autentifikazioa beharrezkoa da",
-    "This action requires you to confirm your password" : "Ekintza honek zure pasahitza berrestea eskatzen du",
-    "Confirm" : "Berretsi",
-    "Failed to authenticate, try again" : "Autentifikazioak huts egin du, saiatu berriz",
     "Users" : "Erabiltzaileak",
     "Username" : "Erabiltzaile-izena",
     "Database user" : "Datu-basearen erabiltzailea",
+    "This action requires you to confirm your password" : "Ekintza honek zure pasahitza berrestea eskatzen du",
     "Confirm your password" : "Berretsi pasahitza",
+    "Confirm" : "Berretsi",
     "App token" : "Aplikazio-tokena",
     "Alternative log in using app token" : "Saio hasiera alternatiboa aplikazio-tokena erabiliz",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Komando-lerroko eguneratzailea erabili mesedez, 50 erabiltzaile baino gehiagoko instantzia handia baita zurea.",
-    "Login with username or email" : "Hasi saioa erabiltzaile-izen edo e-postarekin",
-    "Login with username" : "Hasi saioa erabiltzaile-izenarekin",
-    "Apps and Settings" : "Aplikazioak eta ezarpenak"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Komando-lerroko eguneratzailea erabili mesedez, 50 erabiltzaile baino gehiagoko instantzia handia baita zurea."
 },
 "nplurals=2; plural=(n != 1);");
