@@ -93,10 +93,13 @@ OC.L10N.register(
     "Continue to {productName}" : "Continue to {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["The update was successful. Redirecting you to {productName} in %n second.","The update was successful. Redirecting you to {productName} in %n seconds."],
     "Applications menu" : "Applications menu",
+    "Apps" : "Apps",
     "More apps" : "More apps",
     "_{count} notification_::_{count} notifications_" : ["{count} notification","{count} notifications"],
     "No" : "No",
     "Yes" : "Yes",
+    "Create share" : "Create share",
+    "Failed to add the public link to your Nextcloud" : "Failed to add the public link to your Nextcloud",
     "Custom date range" : "Custom date range",
     "Pick start date" : "Pick start date",
     "Pick end date" : "Pick end date",
@@ -147,11 +150,11 @@ OC.L10N.register(
     "Recommended apps" : "Recommended apps",
     "Loading apps …" : "Loading apps …",
     "Could not fetch list of apps from the App Store." : "Could not fetch list of apps from the App Store.",
-    "Installing apps …" : "Installing apps …",
     "App download or installation failed" : "App download or installation failed",
     "Cannot install this app because it is not compatible" : "Cannot install this app because it is not compatible",
     "Cannot install this app" : "Cannot install this app",
     "Skip" : "Skip",
+    "Installing apps …" : "Installing apps …",
     "Install recommended apps" : "Install recommended apps",
     "Schedule work & meetings, synced with all your devices." : "Schedule work & meetings, synced with all your devices.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Keep your colleagues and friends in one place without leaking their private info.",
@@ -159,6 +162,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Collaborative documents, spreadsheets and presentations, built on Collabora Online.",
     "Distraction free note taking app." : "Distraction free note taking app.",
+    "Settings menu" : "Settings menu",
+    "Avatar of {displayName}" : "Avatar of {displayName}",
     "Search contacts" : "Search contacts",
     "Reset search" : "Reset search",
     "Search contacts …" : "Search contacts …",
@@ -175,7 +180,6 @@ OC.L10N.register(
     "No results for {query}" : "No results for {query}",
     "Press Enter to start searching" : "Press Enter to start searching",
     "An error occurred while searching for {type}" : "An error occurred while searching for {type}",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Please enter {minSearchLength} character or more to search","Please enter {minSearchLength} characters or more to search"],
     "Forgot password?" : "Forgot password?",
     "Back to login form" : "Back to login form",
     "Back" : "Back",
@@ -185,13 +189,12 @@ OC.L10N.register(
     "You have not added any info yet" : "You have not added any info yet",
     "{user} has not added any info yet" : "{user} has not added any info yet",
     "Error opening the user status modal, try hard refreshing the page" : "Error opening the user status modal, try hard refreshing the page",
+    "More actions" : "More actions",
     "This browser is not supported" : "This browser is not supported",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Your browser is not supported. Please upgrade to a newer version or a supported one.",
     "Continue with this unsupported browser" : "Continue with this unsupported browser",
     "Supported versions" : "Supported versions",
     "{name} version {version} and above" : "{name} version {version} and above",
-    "Settings menu" : "Settings menu",
-    "Avatar of {displayName}" : "Avatar of {displayName}",
     "Search {types} …" : "Search {types} …",
     "Choose {file}" : "Choose {file}",
     "Choose" : "Choose",
@@ -244,7 +247,6 @@ OC.L10N.register(
     "No tags found" : "No tags found",
     "Personal" : "Personal",
     "Accounts" : "Accounts",
-    "Apps" : "Apps",
     "Admin" : "Admin",
     "Help" : "Help",
     "Access forbidden" : "Access forbidden",
@@ -256,7 +258,6 @@ OC.L10N.register(
     "Too many requests" : "Too many requests",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "There were too many requests from your network. Retry later or contact your administrator if this is an error.",
     "Error" : "Error",
-    "Previous" : "Previous",
     "Internal Server Error" : "Internal Server Error",
     "The server was unable to complete your request." : "The server was unable to complete your request.",
     "If this happens again, please send the technical details below to the server administrator." : "If this happens again, please send the technical details below to the server administrator.",
@@ -314,6 +315,7 @@ OC.L10N.register(
     "Account connected" : "Account connected",
     "Your client should now be connected!" : "Your client should now be connected!",
     "You can close this window." : "You can close this window.",
+    "Previous" : "Previous",
     "This share is password-protected" : "This share is password-protected",
     "The password is wrong or expired. Please try again or request a new one." : "The password is wrong or expired. Please try again or request a new one.",
     "Please type in your email address to request a temporary password" : "Please type in your email address to request a temporary password",
@@ -357,52 +359,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update.",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information.",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information.",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "It was not possible to execute the cron job via CLI. The following technical errors have appeared:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Missing index \"{indexName}\" in table \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster.",
-    "Missing primary key on table \"{tableName}\"." : "Missing primary key on table \"{tableName}\".",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Missing optional column \"{columnName}\" in table \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them.",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module.",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it.",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "This is particularly recommended when using the desktop client for file synchronisation.",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}.",
-    "The PHP memory limit is below the recommended value of 512MB." : "The PHP memory limit is below the recommended value of 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "The temporary directory of this instance points to an either non-existing or non-writable directory.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "This instance is running in debug mode. Only enable this for local development and not in production environments.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly.",
@@ -415,41 +372,16 @@ OC.L10N.register(
     "User disabled" : "User disabled",
     "Username or email" : "Username or email",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help.",
-    "Start search" : "Start search",
-    "Open settings menu" : "Open settings menu",
-    "Settings" : "Settings",
-    "Avatar of {fullName}" : "Avatar of {fullName}",
-    "Show all contacts …" : "Show all contacts …",
-    "No files in here" : "No files in here",
-    "New folder" : "New folder",
-    "No more subfolders in here" : "No more subfolders in here",
-    "Name" : "Name",
-    "Size" : "Size",
-    "Modified" : "Modified",
-    "\"{name}\" is an invalid file name." : "\"{name}\" is an invalid file name.",
-    "File name cannot be empty." : "File name cannot be empty.",
-    "\"/\" is not allowed inside a file name." : "\"/\" is not allowed inside a file name.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" is not an allowed filetype",
-    "{newName} already exists" : "{newName} already exists",
-    "Error loading file picker template: {error}" : "Error loading file picker template: {error}",
+    "Apps and Settings" : "Apps and Settings",
     "Error loading message template: {error}" : "Error loading message template: {error}",
-    "Show list view" : "Show list view",
-    "Show grid view" : "Show grid view",
-    "Pending" : "Pending",
-    "Home" : "Home",
-    "Copy to {folder}" : "Copy to {folder}",
-    "Move to {folder}" : "Move to {folder}",
-    "Authentication required" : "Authentication required",
-    "This action requires you to confirm your password" : "This action requires you to confirm your password",
-    "Confirm" : "Confirm",
-    "Failed to authenticate, try again" : "Failed to authenticate, try again",
     "Users" : "Users",
     "Username" : "Username",
     "Database user" : "Database user",
+    "This action requires you to confirm your password" : "This action requires you to confirm your password",
     "Confirm your password" : "Confirm your password",
+    "Confirm" : "Confirm",
     "App token" : "App token",
     "Alternative log in using app token" : "Alternative log in using app token",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users.",
-    "Apps and Settings" : "Apps and Settings"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Please use the command line updater because you have a big instance with more than 50 users."
 },
 "nplurals=2; plural=(n!=1);");
