@@ -103,6 +103,8 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count}개의 알림"],
     "No" : "아니요",
     "Yes" : "예",
+    "Create share" : "공유 만들기",
+    "Failed to add the public link to your Nextcloud" : "Nextcloud에 공개 링크를 추가할 수 없음",
     "Custom date range" : "맞춤 날짜 범위",
     "Pick start date" : "시작일 선택",
     "Pick end date" : "종료일 선택",
@@ -193,7 +195,6 @@ OC.L10N.register(
     "No results for {query}" : "{query}에 대한 결과가 없음",
     "Press Enter to start searching" : "검색을 시작하려면 엔터를 누르세요.",
     "An error occurred while searching for {type}" : "{type} 탐색중 오류 발생",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["{minSearchLength}개 이상의 글자를 입력해 검색해 주세요."],
     "Forgot password?" : "암호를 잊으셨습니까?",
     "Back to login form" : "로그인으로 돌아가기",
     "Back" : "뒤로",
@@ -204,6 +205,7 @@ OC.L10N.register(
     "You have not added any info yet" : "아직 아무 정보도 추가하지 않았습니다.",
     "{user} has not added any info yet" : "{user}님이 아직 아무 정보도 추가하지 않음",
     "Error opening the user status modal, try hard refreshing the page" : "사용자 상태 모달을 불러오는 데 실패했습니다, 페이지를 완전히 새로고침 해 보십시오.",
+    "More actions" : "더 많은 동작",
     "This browser is not supported" : "이 브라우저는 지원되지 않습니다.",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "이 브라우저는 지원되지 않습니다. 새로운 버전 및 지원되는 브라우저로 업그레이드 하세요.",
     "Continue with this unsupported browser" : "지원되지 않는 브라우저로 계속 사용하기",
@@ -273,7 +275,6 @@ OC.L10N.register(
     "Too many requests" : "요청이 너무 많음",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "이 네트워크에 너무 요청이 많습니다. 나중에 다시 시도하십시오. 이것이 오류일 경우 관리자에게 문의하십시오.",
     "Error" : "오류",
-    "Previous" : "이전",
     "Internal Server Error" : "내부 서버 오류",
     "The server was unable to complete your request." : "서버에서 요청을 처리할 수 없습니다.",
     "If this happens again, please send the technical details below to the server administrator." : "만약 이 오류가 다시 발생하면 서버 관리자에게 다음 기술 정보를 알려 주십시오.",
@@ -333,6 +334,7 @@ OC.L10N.register(
     "Account connected" : "계정 연결됨",
     "Your client should now be connected!" : "이제 클라이언트가 연결되야 합니다.",
     "You can close this window." : "윈도우를 닫으셔도 됩니다.",
+    "Previous" : "이전",
     "This share is password-protected" : "이 공유는 암호로 보호되어 있습니다.",
     "The password is wrong or expired. Please try again or request a new one." : "암호가 틀렸거나 만료되었습니다. 다시 시도하거나 새로운 암호를 요청하십시오.",
     "Please type in your email address to request a temporary password" : "임시 암호를 받기 위해 이메일 주소를 입력하십시오.",
