@@ -84,10 +84,13 @@ OC.L10N.register(
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "Atnaujinimas buvo nesėkmingas. Prašome pranešti apie šią problemą <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud bendruomenei</a>.",
     "Continue to {productName}" : "Tęsti {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sek.","Atnaujinimas sėkmingas. Nukreipiama į  {productName} per %n seconds.","Atnaujinimas sėkmingas. Nukreipiama į {productName} per %n sekundes."],
+    "Apps" : "Programėlės",
     "More apps" : "Daugiau programėlių",
     "_{count} notification_::_{count} notifications_" : ["{count} pranešimas","{count} pranešimai","{count} pranešimų","{count} pranešimas"],
     "No" : "Ne",
     "Yes" : "Taip",
+    "Create share" : "Sukurti viešinį",
+    "Failed to add the public link to your Nextcloud" : "Nepavyko pridėti viešosios nuorodos į jūsų Nextcloud",
     "Date" : "Data",
     "Today" : "Šiandien",
     "People" : "Žmonės",
@@ -121,15 +124,16 @@ OC.L10N.register(
     "I know what I'm doing" : "Aš žinau ką darau",
     "Recommended apps" : "Rekomenduojamos programėlės",
     "Loading apps …" : "Įkeliamos programėlės…",
-    "Installing apps …" : "Įdiegiamos programėlės…",
     "App download or installation failed" : "Programėlės atsisiuntimas ar įdiegimas patyrė nesėkmę",
     "Cannot install this app because it is not compatible" : "Nepavyksta įdiegti šios programėlės, nes ji yra nesuderinama",
     "Cannot install this app" : "Nepavyksta įdiegti šios programėlės",
     "Skip" : "Praleisti",
+    "Installing apps …" : "Įdiegiamos programėlės…",
     "Install recommended apps" : "Įdiegti rekomenduojamas programėles",
     "Schedule work & meetings, synced with all your devices." : "Planuokite su visais jūsų įrenginiais sinchronizuotus darbus ir susitikimus.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Saugokite savo kolegas bei draugus vienoje vietoje, neatskleisdami jų asmeninės informacjios.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Paprasta el. pašto programėlė, tvarkingai integruota su failais, adresatais ir kalendoriumi.",
+    "Settings menu" : "Nustatymų meniu",
     "Search contacts" : "Ieškoti adresatų",
     "Reset search" : "Atstatyti paiešką",
     "Search contacts …" : "Ieškoti adresatų…",
@@ -144,15 +148,14 @@ OC.L10N.register(
     "Search" : "Ieškoti",
     "No results for {query}" : "{query} negrąžino jokių rezultatų",
     "An error occurred while searching for {type}" : "Ieškant {type}, įvyko klaida",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių","Norėdami atlikti paiešką, įveskite {minSearchLength} ar daugiau simbolių"],
     "Forgot password?" : "Pamiršote slaptažodį?",
     "Back" : "Atgal",
     "Edit Profile" : "Taisyti profilį",
     "The headline and about sections will show up here" : "Čia bus rodoma santrauka apie jus bei kita su jumis susijusi informacija",
     "You have not added any info yet" : "Jūs kol kas nesate pridėję jokios informacijos",
     "{user} has not added any info yet" : "Naudotojas {user} kol kas nėra pridėjęs jokios informacijos",
+    "More actions" : "Daugiau veiksmų",
     "Supported versions" : "Palaikomos versijos",
-    "Settings menu" : "Nustatymų meniu",
     "Search {types} …" : "Ieškoti {types}…",
     "Choose" : "Pasirinkti",
     "Copy to {target}" : "Kopijuoti į {target}",
@@ -202,7 +205,6 @@ OC.L10N.register(
     "Collaborative tags" : "Bendradarbiavimo žymės",
     "No tags found" : "Nerasta jokių žymių",
     "Personal" : "Asmeniniai",
-    "Apps" : "Programėlės",
     "Admin" : "Administravimas",
     "Help" : "Pagalba",
     "Access forbidden" : "Prieiga uždrausta",
@@ -213,7 +215,6 @@ OC.L10N.register(
     "Too many requests" : "Per daug užklausų",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Iš jūsų tinklo buvo per daug užklausų. Bandykite dar kartą vėliau arba, jeigu tai klaida, susisiekite su savo administratoriumi.",
     "Error" : "Klaida",
-    "Previous" : "Ankstesnis",
     "Internal Server Error" : "Vidinė serverio klaida",
     "The server was unable to complete your request." : "Serveriui nepavyko įvykdyti jūsų užklausos.",
     "If this happens again, please send the technical details below to the server administrator." : "Jei tai pasikartos, prašome nusiųsti serverio administratoriui žemiau esančią techninę informaciją.",
@@ -267,6 +268,7 @@ OC.L10N.register(
     "Account connected" : "Paskyra prijungta",
     "Your client should now be connected!" : "Dabar, jūsų kliento programa turėtų būti prijungta!",
     "You can close this window." : "Galite užverti šį langą.",
+    "Previous" : "Ankstesnis",
     "This share is password-protected" : "Šis viešinys yra apsaugotas slaptažodžiu",
     "Email address" : "El. pašto adresas",
     "Password sent!" : "Slaptažodis išsiųstas!",
@@ -300,48 +302,19 @@ OC.L10N.register(
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Susisiekite su savo sistemos administratoriumi, jei šis pranešimas nedingsta arba, jei jis pasirodė netikėtai.",
     "The user limit of this instance is reached." : "Yra pasiekta šio egzemplioriaus naudotojų riba.",
     "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Jūsų svetainės serveris nėra tinkamai sukonfiguruotas, Failų sinchronizavimas negalimas, nes neveikia WebDAV interfeisas.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Buvo neįmanoma įvykdyti cron užduotį per komandų eilutę. Atsirado šios techninės klaidos:",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Jūsų PHP neturi FreeType palaikymo, kas savo ruožtu sąlygoja profilio paveikslėlių ir nustatymų sąsajos neteisingą atvaizdavimą.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Lentelėje „{tableName}“ trūksta nebūtino stulpelio „{columnName}“.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "Šiame egzemplioriuje trūksta kai kurių rekomenduojamų PHP modulių. Pagerintam našumui ir geresniam suderinamumui yra primygtinai rekomenduojama juos įdiegti.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Tai ypač rekomenduojama failų sinchronizavimui naudojant darbalaukio kliento programą.",
-    "The PHP memory limit is below the recommended value of 512MB." : "PHP atminties riba yra žemiau rekomenduojamos 512MB reikšmės.",
     "Wrong username or password." : "Neteisingas naudotojo vardas ar slaptažodis.",
     "User disabled" : "Naudotojas išjungtas",
     "Username or email" : "Naudotojas arba el. paštas",
-    "Open settings menu" : "Atverti nustatymų meniu",
-    "Settings" : "Nustatymai",
-    "Show all contacts …" : "Rodyti visus adresatus…",
-    "No files in here" : "Čia failų nėra",
-    "New folder" : "Naujas aplankas",
-    "No more subfolders in here" : "Čia daugiau nebėra poaplankių",
-    "Name" : "Pavadinimas",
-    "Size" : "Dydis",
-    "Modified" : "Pakeista",
-    "\"{name}\" is an invalid file name." : "„{name}“ yra neteisingas failo pavadinimas.",
-    "File name cannot be empty." : "Failo pavadinimas negali būti tuščias.",
-    "\"/\" is not allowed inside a file name." : "Failo pavadinime simbolis „/“ draudžiamas.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" yra neleistinas failo tipas",
-    "{newName} already exists" : "{newName} jau yra",
-    "Error loading file picker template: {error}" : "Klaida įkeliant failo parinkimo ruošinį: {error}",
+    "Apps and Settings" : "Programėlės ir nustatymai",
     "Error loading message template: {error}" : "Klaida įkeliant žinutės ruošinį: {error}",
-    "Show list view" : "Rodyti sąrašo rodinį",
-    "Show grid view" : "Rodyti tinklelio rodinį",
-    "Pending" : "Vykdoma",
-    "Home" : "Namai",
-    "Copy to {folder}" : "Kopijuoti į {folder}",
-    "Move to {folder}" : "Perkelti į {folder}",
-    "Authentication required" : "Reikalingas tapatybės nustatymas",
-    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
-    "Confirm" : "Patvirtinti",
-    "Failed to authenticate, try again" : "Nepavyko nustatyti tapatybės, bandykite dar kartą",
     "Users" : "Naudotojai",
     "Username" : "Naudotojo vardas",
     "Database user" : "Duomenų bazės naudotojas",
+    "This action requires you to confirm your password" : "Šis veiksmas reikalauja, kad įvestumėte savo slaptažodį",
     "Confirm your password" : "Patvirtinkite savo slaptažodį",
+    "Confirm" : "Patvirtinti",
     "App token" : "Išorinės sistemos įskiepio kodas",
     "Alternative log in using app token" : "Alternatyvus prisijungimas naudojant programėlės atpažinimo raktą",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Naudokite komandų eilutės atnaujinimo programą, nes turite didelį egzempliorių su daugiau nei 50 naudotojų.",
-    "Apps and Settings" : "Programėlės ir nustatymai"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Naudokite komandų eilutės atnaujinimo programą, nes turite didelį egzempliorių su daugiau nei 50 naudotojų."
 },
 "nplurals=4; plural=(n % 10 == 1 && (n % 100 > 19 || n % 100 < 11) ? 0 : (n % 10 >= 2 && n % 10 <=9) && (n % 100 > 19 || n % 100 < 11) ? 1 : n % 1 != 0 ? 2: 3);");
