@@ -43,6 +43,7 @@ OC.L10N.register(
     "Task not found" : "Задача не найдена",
     "Internal error" : "Внутренняя ошибка",
     "Not found" : "Не найдено",
+    "Bad request" : "Плохой запрос",
     "Requested task type does not exist" : "Запрошенный тип задачи не существует",
     "Necessary language model provider is not available" : "Необходимый поставщик языковой модели недоступен",
     "No text to image provider is available" : "Поставщик преобразования текста в изображение недоступен",
@@ -102,6 +103,14 @@ OC.L10N.register(
     "_{count} notification_::_{count} notifications_" : ["{count} уведомление","{count} уведомлений","{count} уведомлений","{count} уведомлений"],
     "No" : "Нет",
     "Yes" : "Да",
+    "Federated user" : "Федеративный пользователь",
+    "user@your-nextcloud.org" : "пользователь@ваш-nextcloud.org",
+    "Create share" : "Создать общий ресурс",
+    "The remote URL must include the user." : "Удаленный URL-адрес должен содержать имя пользователя.",
+    "Invalid remote URL." : "Неверный удаленный URL-адрес.",
+    "Failed to add the public link to your Nextcloud" : "Не удалось создать общедоступную ссылку",
+    "Direct link copied to clipboard" : "Прямая ссылка, скопированная в буфер обмена",
+    "Please copy the link manually:" : "Выполните копирование ссылки вручную:",
     "Custom date range" : "Настраиваемый диапазон дат",
     "Pick start date" : "Выберите дату начала",
     "Pick end date" : "Выберите дату окончания",
@@ -117,7 +126,7 @@ OC.L10N.register(
     "Last 7 days" : "Последние 7 дней",
     "Last 30 days" : "Последние 30 дней",
     "This year" : "Этот год",
-    "Last year" : "Последний год",
+    "Last year" : "Прошлый год",
     "Search people" : "Поиск людей",
     "People" : "Люди",
     "Filter in current view" : "Фильтр в текущем виде",
@@ -125,7 +134,7 @@ OC.L10N.register(
     "Load more results" : "Загрузить дополнительные результаты",
     "Search in" : "Искать в",
     "Searching …" : "Поиск…",
-    "Start typing to search" : "Начините вводить символы для поиска",
+    "Start typing to search" : "Начните вводить символы для поиска",
     "No matching results" : "Нет совпадающих результатов",
     "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Между ${this.dateFilter.startFrom.toLocaleDateString()} и ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Войти",
@@ -192,7 +201,6 @@ OC.L10N.register(
     "No results for {query}" : "По запросу «{query}» ничего не найдено",
     "Press Enter to start searching" : "Нажмите Enter, чтобы начать поиск",
     "An error occurred while searching for {type}" : "Произошла ошибка при поиске {type}",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Чтобы начать поиск необходимо ввести как минимум  {minSearchLength} символ","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символа","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символов","Чтобы начать поиск необходимо ввести как минимум {minSearchLength} символа"],
     "Forgot password?" : "Забыли пароль?",
     "Back to login form" : "Вернуться к форме входа",
     "Back" : "Назад",
@@ -203,6 +211,7 @@ OC.L10N.register(
     "You have not added any info yet" : "Вы ещё не добавили никакой информации",
     "{user} has not added any info yet" : "Пользователь {user} ещё не добавил(а) никакой информации",
     "Error opening the user status modal, try hard refreshing the page" : "Произошла ошибка при открытии модального окна пользователя, попробуйте обновить страницу",
+    "More actions" : "Больше действий",
     "This browser is not supported" : "Используемый браузер не поддерживается",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Используемый браузер не поддерживается. Обновитесь до более новой версии или используйте другой браузер.",
     "Continue with this unsupported browser" : "Продолжить с использованием неподдерживаемого браузера",
@@ -272,11 +281,11 @@ OC.L10N.register(
     "Too many requests" : "Превышено количество запросов",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Превышено количество запросов из вашей сети. Попробуйте позднее или сообщите администратору об этой ошибке.",
     "Error" : "Ошибка",
-    "Previous" : "Предыдущий",
     "Internal Server Error" : "Внутренняя ошибка сервера",
     "The server was unable to complete your request." : "Запрос не может быть обработан сервером.",
     "If this happens again, please send the technical details below to the server administrator." : "Если это случится ещё раз, отправьте администратору сервера подробное сообщение о произошедшем, приведённое ниже.",
     "More details can be found in the server log." : "Подробную информацию можно найти в журнале сервера.",
+    "For more details see the documentation ↗." : "Для получения более подробной информации ознакомьтесь с документацией ↗.",
     "Technical details" : "Технические подробности",
     "Remote Address: %s" : "Удаленный адрес: %s",
     "Request ID: %s" : "ID Запроса: %s",
@@ -331,6 +340,7 @@ OC.L10N.register(
     "Account connected" : "Аккаунт подключен",
     "Your client should now be connected!" : "Приложение-клиент подключено.",
     "You can close this window." : "Можете закрыть это окно.",
+    "Previous" : "Предыдущий",
     "This share is password-protected" : "Доступ к этому ресурсу защищён паролем",
     "The password is wrong or expired. Please try again or request a new one." : "Введённый пароль неверен или срок его действия истёк. Попробуйте снова ввести его или запросите новый пароль.",
     "Please type in your email address to request a temporary password" : "Введите свой адрес эл. почты для запроса временного пароля",
