@@ -39,9 +39,11 @@ OC.L10N.register(
     "Click the following button to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúce tlačidlo. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
     "Click the following link to reset your password. If you have not requested the password reset, then ignore this email." : "Pre obnovenie hesla kliknite na nasledujúci odkaz. Pokiaľ ste nevyžiadali obnovenie hesla, tento email ignorujte.",
     "Reset your password" : "Vytvoriť nové heslo",
+    "The given provider is not available" : "Zadaný poskytovateľ nie je dostupný",
     "Task not found" : "Úloha nebola nájdená",
     "Internal error" : "Interná chyba",
     "Not found" : "Nenájdené",
+    "Bad request" : "Neplatná požiadavka",
     "Requested task type does not exist" : "Vyžiadaný typ úlohy neexistuje",
     "Necessary language model provider is not available" : "Potrebný poskytovateľ jazykového modelu nie je dostupný",
     "No text to image provider is available" : "Nie je dostupný žiadny poskytovateľ služby \"text na obrázok\"",
@@ -96,15 +98,41 @@ OC.L10N.register(
     "Continue to {productName}" : "Pokračovať na {productName}",
     "_The update was successful. Redirecting you to {productName} in %n second._::_The update was successful. Redirecting you to {productName} in %n seconds._" : ["Aktualizácia prebehla úspešne. O %n sekundu budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekundy budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}.","Aktualizácia prebehla úspešne. O %n sekúnd budete presmerovaní na {productName}."],
     "Applications menu" : "Ponuka aplikácií",
+    "Apps" : "Aplikácie",
     "More apps" : "Viac aplikácií",
-    "Currently open" : "V súčasnosti otvorené",
     "_{count} notification_::_{count} notifications_" : ["{count} upozornenie","{count} upozornenia","{count} upozornení","{count} upozornenia"],
     "No" : "Nie",
     "Yes" : "Áno",
+    "Federated user" : "Združený užívateľ",
+    "user@your-nextcloud.org" : "user@your-nextcloud.org",
+    "Create share" : "Vytvoriť sprístupnenie",
+    "Failed to add the public link to your Nextcloud" : "Pridanie verejne dostupného odkazu do vášho Nextcloud zlyhalo",
     "Custom date range" : "Vlastné rozpätie dátumov",
     "Pick start date" : "Vyberte dátum začiatku",
     "Pick end date" : "Vyberte dátum ukončenia",
     "Search in date range" : "Hľadať v rozsahu dátumov",
+    "Search in current app" : "Hľadať v aktuálnej aplikácii",
+    "Clear search" : "Vymazať hľadanie",
+    "Search everywhere" : "Hľadať všade",
+    "Unified search" : "Jednotné vyhľadávanie",
+    "Search apps, files, tags, messages" : "Hľadať aplikácie, súbory, štítky a správy",
+    "Places" : "Miesta",
+    "Date" : "Dátum",
+    "Today" : "Dnes",
+    "Last 7 days" : "Posledných 7 dní",
+    "Last 30 days" : "Posledných 30 dní",
+    "This year" : "Tento rok",
+    "Last year" : "Minulý rok",
+    "Search people" : "Hľadať ľudí",
+    "People" : "Ľudia",
+    "Filter in current view" : "Filter v aktuálnom zobrazení",
+    "Results" : "Výsledky",
+    "Load more results" : "Načítať viac výsledkov",
+    "Search in" : "Hľadať v",
+    "Searching …" : "Hľadá sa…",
+    "Start typing to search" : "Začnite písať pre vyhľadanie",
+    "No matching results" : "Žiadne zhodujúce výsledky",
+    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Medzi ${this.dateFilter.startFrom.toLocaleDateString()} a ${this.dateFilter.endAt.toLocaleDateString()}",
     "Log in" : "Prihlásiť sa",
     "Logging in …" : "Prihlasujem ...",
     "Server side authentication failed!" : "Autentifikácia na serveri zlyhala!",
@@ -119,6 +147,7 @@ OC.L10N.register(
     "This account is disabled" : "Tento účet je deaktivovaný",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Zaznamenali sme viacnásobné chybné prihlásenie z vašej IP adresy. Vaše nasledujúce prihlásenie bude pozdržané o 30 sekúnd.",
     "Account name or email" : "Názov účtu alebo e-mail",
+    "Account name" : "Názov účtu",
     "Log in with a device" : "Prihlásiť sa pomocou zariadenia",
     "Login or email" : "Prihlasovacie meno alebo email",
     "Your account is not setup for passwordless login." : "Váš účet nie je nastavený pre bezheslové overovanie.",
@@ -138,11 +167,11 @@ OC.L10N.register(
     "Recommended apps" : "Odporúčané apky",
     "Loading apps …" : "Načítavanie apiek...",
     "Could not fetch list of apps from the App Store." : "Nepodarilo sa načítať zoznam apiek z Obchodu s aplikáciami.",
-    "Installing apps …" : "Inštalácia apiek...",
     "App download or installation failed" : "Nepodarilo sa prevziať alebo nainštalovať apku",
     "Cannot install this app because it is not compatible" : "Táto apka sa nedá nainštalovať, pretože nie je kompatibilná",
     "Cannot install this app" : "Táto aplikácia sa nedá nainštalovať",
     "Skip" : "Preskočiť",
+    "Installing apps …" : "Inštalácia apiek...",
     "Install recommended apps" : "Nainštalovať odporúčané apky",
     "Schedule work & meetings, synced with all your devices." : "Naplánujte si prácu a stretnutia, synchronizované so všetkými vašimi zariadeniami.",
     "Keep your colleagues and friends in one place without leaking their private info." : "Udržujte si údaje o svojich kolegoch a priateľoch na jednom mieste bez hrozby úniku ich súkromných informácií tretím stranám.",
@@ -150,6 +179,8 @@ OC.L10N.register(
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Četovanie, videohovory, zdieľanie obrazovky, online stretnutia a webové konferencie - vo vašom prehliadači a pomocou mobilných aplikácií.",
     "Collaborative documents, spreadsheets and presentations, built on Collabora Online." : "Kolaboratívne dokumenty, tabuľky a prezentácie postavené na Collabora Online.",
     "Distraction free note taking app." : "Aplikácia pre písanie poznámok bez rozptyľovania.",
+    "Settings menu" : "Menu nastavení",
+    "Avatar of {displayName}" : "Avatar užívateľa {displayName}",
     "Search contacts" : "Prehľadať kontakty",
     "Reset search" : "Vynuluj vyhľadávanie",
     "Search contacts …" : "Prehľadať kontakty...",
@@ -161,14 +192,11 @@ OC.L10N.register(
     "Looking for {term} …" : "Hľadá sa výraz {term}...",
     "Search starts once you start typing and results may be reached with the arrow keys" : "Hľadanie sa začína, keď začnete písať a výsledky môžete dosiahnuť pomocou šípiek.",
     "Search for {name} only" : "Hľadať iba {name}",
-    "Start typing to search" : "Začnite písať pre vyhľadanie",
     "Loading more results …" : "Načítava sa viac výsledkov …",
-    "Load more results" : "Načítať viac výsledkov",
     "Search" : "Hľadať",
     "No results for {query}" : "Žiadne výsledky pre {query}",
     "Press Enter to start searching" : "Stlačte Enter pre spustenie hľadania",
     "An error occurred while searching for {type}" : "Počas hľadania {type} sa vyskytla chyba",
-    "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Pre vyhľadávanie zadajte aspoň {minSearchLength} znak","Pre vyhľadávanie zadajte aspoň {minSearchLength} znaky","Pre vyhľadávanie zadajte aspoň {minSearchLength} znakov","Pre vyhľadávanie zadajte aspoň {minSearchLength} znakov"],
     "Forgot password?" : "Zabudli ste heslo?",
     "Back to login form" : "Späť na prihlásenie",
     "Back" : "Späť",
@@ -179,30 +207,13 @@ OC.L10N.register(
     "You have not added any info yet" : "Zatiaľ ste nepridali žiadne informácie",
     "{user} has not added any info yet" : "{user} zatiaľ nepridal žiadne informácie",
     "Error opening the user status modal, try hard refreshing the page" : "Chyba pri otváraní modálneho okna stavu používateľa, skúste stránku obnoviť",
-    "Unified search" : "Jednotné vyhľadávanie",
-    "Search apps, files, tags, messages" : "Hľadať aplikácie, súbory, štítky a správy",
-    "Search {types} …" : "Vyhľadať {types}",
-    "Places" : "Miesta",
-    "Date" : "Dátum",
-    "Today" : "Dnes",
-    "Last 7 days" : "Posledných 7 dní",
-    "Last 30 days" : "Posledných 30 dní",
-    "This year" : "Tento rok",
-    "Last year" : "Minulý rok",
-    "Search people" : "Hľadať ľudí",
-    "People" : "Ľudia",
-    "Filter in current view" : "Filter v aktuálnom zobrazení",
-    "Search in" : "Hľadať v",
-    "Searching …" : "Hľadá sa…",
-    "No matching results" : "Žiadne zhodujúce výsledky",
-    "Between ${this.dateFilter.startFrom.toLocaleDateString()} and ${this.dateFilter.endAt.toLocaleDateString()}" : "Medzi ${this.dateFilter.startFrom.toLocaleDateString()} a ${this.dateFilter.endAt.toLocaleDateString()}",
+    "More actions" : "Viac akcií",
     "This browser is not supported" : "Tento prehliadač nie je podporovaný",
     "Your browser is not supported. Please upgrade to a newer version or a supported one." : "Váš prehliadač nie je podporovaný. Inovujte na novšiu alebo podporovanú verziu.",
     "Continue with this unsupported browser" : "Pokračovať s nepodporovaným prehliadačom",
     "Supported versions" : "Podporované verzie",
     "{name} version {version} and above" : "{name} verzie {version} alebo vyššej",
-    "Settings menu" : "Menu nastavení",
-    "Avatar of {displayName}" : "Avatar užívateľa {displayName}",
+    "Search {types} …" : "Vyhľadať {types}",
     "Choose {file}" : "Vyberte {file}",
     "Choose" : "Vybrať",
     "Copy to {target}" : "Kopírovať do {target}",
@@ -255,7 +266,6 @@ OC.L10N.register(
     "No tags found" : "Štítky sa nenašli",
     "Personal" : "Osobné",
     "Accounts" : "Účty",
-    "Apps" : "Aplikácie",
     "Admin" : "Administrácia",
     "Help" : "Pomoc",
     "Access forbidden" : "Prístup odmietnutý",
@@ -267,11 +277,11 @@ OC.L10N.register(
     "Too many requests" : "Priveľa požiadavok",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "Príliš mnoho požiadaviek z vašej siete. Skúste to znovu neskôr alebo kontaktujte svojho administrátora ak je toto chyba.",
     "Error" : "Chyba",
-    "Previous" : "Predchádzajúce",
     "Internal Server Error" : "Vnútorná chyba servera",
     "The server was unable to complete your request." : "Server nebol schopný dokončiť vašu žiadosť.",
     "If this happens again, please send the technical details below to the server administrator." : "Ak sa to stane opäť, nižšie zašlite technické podrobnosti správcovi servera.",
     "More details can be found in the server log." : "Viac nájdete v logu servera.",
+    "For more details see the documentation ↗." : "Viac podrobností nájdete vdokumentácii ↗.",
     "Technical details" : "Technické podrobnosti",
     "Remote Address: %s" : "Vzdialená adresa: %s",
     "Request ID: %s" : "ID požiadavky: %s",
@@ -326,6 +336,7 @@ OC.L10N.register(
     "Account connected" : "Účet pripojený",
     "Your client should now be connected!" : "Váš klient by mal byť pripojený!",
     "You can close this window." : "Toto okno už môžete zatvoriť.",
+    "Previous" : "Predchádzajúce",
     "This share is password-protected" : "Toto sprístupnenie je chránené heslom",
     "The password is wrong or expired. Please try again or request a new one." : "Heslo je nesprávne alebo jeho platnosť vypršala. Skúste to znova alebo požiadajte o nové heslo.",
     "Please type in your email address to request a temporary password" : "Prosím zadajte vašu e-mailovú adresu pre získanie dočasného hesla",
@@ -370,53 +381,7 @@ OC.L10N.register(
     "Your web server is not properly set up to resolve \"{url}\". Further information can be found in the {linkstart}documentation ↗{linkend}." : "Váš webový server nie je správne nastavený na spracovanie \"{url}\". Viac informácií môžete nájsť v {linkstart}dokumentácii ↗{linkend}.",
     "Your web server is not properly set up to resolve \"{url}\". This is most likely related to a web server configuration that was not updated to deliver this folder directly. Please compare your configuration against the shipped rewrite rules in \".htaccess\" for Apache or the provided one in the documentation for Nginx at it's {linkstart}documentation page ↗{linkend}. On Nginx those are typically the lines starting with \"location ~\" that need an update." : "Váš web server nie je správne nastavený, aby preložil \"{url}\". To pravdepodobne súvisí s nastavením webového servera, ktoré nebolo aktualizované pre priame doručovanie tohto priečinka. Porovnajte prosím svoje nastavenia voči dodávaným rewrite pravidlám v \".htaccess\" pre Apache alebo tým, ktoré uvádzame v {linkstart}dokumentácii ↗{linkend} pre Nginx. V Nginx je typicky potrebné aktualizovať riadky začínajúce na \"location ~\".",
     "Your web server is not properly set up to deliver .woff2 files. This is typically an issue with the Nginx configuration. For Nextcloud 15 it needs an adjustement to also deliver .woff2 files. Compare your Nginx configuration to the recommended configuration in our {linkstart}documentation ↗{linkend}." : "Váš server nie je správne nastavený tak, aby doručoval súbory .woff2. Toto je typicky problém s nastavením Nginx. Pre Nextcloud 15 je potrebné ho upraviť, aby tieto súbory doručoval. Porovnajte nastavenie svojho Nginx s tým, ktorý je odporúčaný v našej {linkstart}dokumentácii ↗{linkend}.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "Zdá sa že PHP nie je nastavené korektne na získanie premenných prostredia.  Test s príkazom getenv(\"PATH\") vráti prázdnu odpoveď.",
-    "Please check the {linkstart}installation documentation ↗{linkend} for PHP configuration notes and the PHP configuration of your server, especially when using php-fpm." : "Prosím skontrolujte {linkstart}inštalačnú dokumentáciu ↗{linkend} ohľadne PHP konfigurácie a PHP konfiguráciu Vášho servra, hlavne ak používate php-fpm.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Konfigurácia je nastavená len na čítanie. Toto znemožňuje urobiť niektoré nastavenia prostredníctvom webového rozhrania. Okrem toho, súbor musí mať zapisovanie ručne povolené pre každú aktualizáciu.",
-    "You have not set or verified your email server configuration, yet. Please head over to the {mailSettingsStart}Basic settings{mailSettingsEnd} in order to set them. Afterwards, use the \"Send email\" button below the form to verify your settings." : "Zatiaľ ste nenastavili ani neoverili konfiguráciu e-mailového servera. Ak ju chcete nastaviť, prejdite na   {mailSettingsStart}základné nastavenia{mailSettingsEnd}. Potom pomocou tlačidla „Odoslať e-mail“ pod formulárom overte svoje nastavenia.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Vaša databáza nebeží s úrovňou izolácie transakcií \"READ COMMITTED\".  Toto môže spôsobovať problémy v prípade ak viacero akcií beží paralelne.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "Chýba PHP modul 'fileinfo'. Dôrazne ho odporúčame povoliť pre dosiahnutie najlepších výsledkov zisťovania MIME-typu.",
-    "Your remote address was identified as \"{remoteAddress}\" and is brute-force throttled at the moment slowing down the performance of various requests. If the remote address is not your address this can be an indication that a proxy is not configured correctly. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Vaša vzdialená adresa bola identifikovaná ako \"{remoteAddress}\" a rýchlosť vybavovania požiadaviek z nej je v tejto chvíli obmedzovaná kvôli ochrane proti útokom heslom (bruteforce). Ak vzdialená adresa nie je vaša, môže to znamenať, že nie je správna nastavená proxy. Podrobnosti sú k dispozícii v dokumentácii ↗.",
-    "Transactional file locking is disabled, this might lead to issues with race conditions. Enable \"filelocking.enabled\" in config.php to avoid these problems. See the {linkstart}documentation ↗{linkend} for more information." : "Tranzakčné uzamykanie súborov je vypnuté, toto môže viesť k problémom.  Nastavte \"filelocking.enabled\" v config.php pre vyriešenie problému.  Viac informácií viď {linkstart}dokumentácia ↗{linkend} .",
-    "The database is used for transactional file locking. To enhance performance, please configure memcache, if available. See the {linkstart}documentation ↗{linkend} for more information." : "Databáza sa používa pre transakčné zamykanie súborov. Ak chcete zvýšiť výkon, nastavte memcache, ak je k dispozícií. Ďalšie informácie nájdete v {linkstart}dokumentácií ↗{linkend}.",
-    "Please make sure to set the \"overwrite.cli.url\" option in your config.php file to the URL that your users mainly use to access this Nextcloud. Suggestion: \"{suggestedOverwriteCliURL}\". Otherwise there might be problems with the URL generation via cron. (It is possible though that the suggested URL is not the URL that your users mainly use to access this Nextcloud. Best is to double check this in any case.)" : "Uistite sa, že ste v súbore config.php nastavili možnosť „overwrite.cli.url“ na adresu URL, ktorú vaši používatelia používajú na prístup k tomuto Nextcloudu. Návrh: \"{suggestedOverwriteCliURL}\". V opačnom prípade môžu nastať problémy s generovaním URL cez cron. (Je však možné, že navrhovaná adresa URL nie je adresa URL, ktorú vaši používatelia používajú na prístup k tomuto Nextcloudu. Najlepšie je v každom prípade to ešte raz skontrolovať.)",
-    "Your installation has no default phone region set. This is required to validate phone numbers in the profile settings without a country code. To allow numbers without a country code, please add \"default_phone_region\" with the respective {linkstart}ISO 3166-1 code ↗{linkend} of the region to your config file." : "Vaša inštalácia nemá nastavenú žiadnu predvolenú oblasť predvoľby telefónu. Toto je potrebné na overenie telefónnych čísel v nastaveniach profilu bez kódu krajiny. Ak chcete povoliť čísla bez kódu krajiny, pridajte do svojho konfiguračného súboru „default_phone_region“ s príslušným {linkstart} kódom ISO 3166-1 ↗ {linkend} regiónu.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Nebolo možné spustiť cron úlohu na pozadí pomocou CLI.  Toto sú chyby:",
-    "Last background job execution ran {relativeTime}. Something seems wrong. {linkstart}Check the background job settings ↗{linkend}." : "Posledné spustenie úlohy na pozadí prebehlo {relativeTime}. Zdá sa, že niečo nie je v poriadku. {linkstart} Skontrolujte nastavenia úlohy na pozadí ↗{linkend}.",
-    "This is the unsupported community build of Nextcloud. Given the size of this instance, performance, reliability and scalability cannot be guaranteed. Push notifications are limited to avoid overloading our free service. Learn more about the benefits of Nextcloud Enterprise at {linkstart}https://nextcloud.com/enterprise{linkend}." : "Toto je nepodporovaná komunitná verzia Nextcloud. Vzhľadom na veľkosť tejto inštancie nemožno zaručiť výkon, spoľahlivosť a škálovateľnosť. Push notifikácie boli deaktivované, aby sa predišlo preťaženiu našej bezplatnej služby. Získajte viac informácií o výhodách Nextcloud Enterprise na {linkstart}https://nextcloud.com/enterprise{linkend}.",
-    "This server has no working internet connection: Multiple endpoints could not be reached. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. Establish a connection from this server to the internet to enjoy all features." : "Tento server nemá funkčné internetové pripojenie: Nie je možné dosiahnuť viacero koncových bodov. To znamená, že niektoré funkcie, ako je pripojenie externého úložiska, upozornenia na aktualizácie alebo inštalácia aplikácií tretích strán, nebudú fungovať. Tiež nemusí fungovať vzdialený prístup k súborom a odosielanie e -mailov s upozorneniami. Ak chcete využívať všetky funkcie, vytvorte z tohto servera pripojenie na internet.",
-    "No memory cache has been configured. To enhance performance, please configure a memcache, if available. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Nie je nakonfigurovaná vyrovnávacia pamäť. Ak chcete zvýšiť výkon, nakonfigurujte prosím memcache ak je to možné. Viac informácií nájdete v {linkstart}dokumentácii ↗{linkend}.",
-    "No suitable source for randomness found by PHP which is highly discouraged for security reasons. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Použiteľný zdroj náhodnosti pre PHP nebol nájdený, čo nie je odporúčané z bezpečnostných dôvodov.  Viac informácií nájdete v {linkstart}dokumentácii ↗{linkend}.",
-    "You are currently running PHP {version}. Upgrade your PHP version to take advantage of {linkstart}performance and security updates provided by the PHP Group ↗{linkend} as soon as your distribution supports it." : "Aktuálne používate PHP {version}. Dôrazne odporúčame prechod na vyššiu verziu ihneď, ako to vaša distribúcia dovolí, aby ste využili {linkstart}všetky výkonnostné a bezpečnostné možnosti novej verzie od PHP Group ↗{linkend}.",
-    "PHP 8.0 is now deprecated in Nextcloud 27. Nextcloud 28 may require at least PHP 8.1. Please upgrade to {linkstart}one of the officially supported PHP versions provided by the PHP Group ↗{linkend} as soon as possible." : "PHP 8.0 je teraz zastarané v Nextcloud 27. Nextcloud 28 môže vyžadovať aspoň PHP 8.1. Prosím, aktualizujte na {linkstart}jednu z oficiálne podporovaných verzií PHP poskytovaných PHP Group ↗{linkend} čo najskôr.",
-    "The reverse proxy header configuration is incorrect, or you are accessing Nextcloud from a trusted proxy. If not, this is a security issue and can allow an attacker to spoof their IP address as visible to the Nextcloud. Further information can be found in the {linkstart}documentation ↗{linkend}." : "Konfigurácia hlavičiek reverse proxy nie je správna alebo pristupujete k NextCloudu z dôveryhodného proxy servera. Ak k NextCloudu nepristupujete z dôveryhodného proxy servera, vzniká bezpečnostné riziko - IP adresa potenciálneho útočníka, ktorú vidí NextCloud, môže byť falošná. Viac informácií nájdete v našej {linkstart}dokumentácii ↗{linkend}.",
-    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the {linkstart}memcached wiki about both modules ↗{linkend}." : "Memcached je nakonfigurovaný ako distribuovaná vyrovnávacia pamäť, ale v PHP je nainštalovaný nesprávny modul - \"memcache\". \\OC\\Memcache\\Memcached podporuje len modul \"memcached\", \"memcache\" nie je podporovaný. Viac informácií nájdete na {linkstart}memcached wiki stránke o oboch moduloch ↗{linkend}.",
-    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in the {linkstart1}documentation ↗{linkend}. ({linkstart2}List of invalid files…{linkend} / {linkstart3}Rescan…{linkend})" : "Niektoré súbory neprešli kontrolou integrity. Ďalšie informácie o tom, ako vyriešiť tento problém, nájdete v dokumentácii {linkstart1} ↗{linkend}. ({linkstart2}Zoznam neplatných súborov ... {linkend} / {linkstart3} Znova prehľadať ...{linkend})",
-    "The PHP OPcache module is not properly configured. See the {linkstart}documentation ↗{linkend} for more information." : "Modul PHP OPcache nie je správne nakonfigurovaný. Ďalšie informácie nájdete v {linkstart}dokumentácii ↗{linkend}.",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "Funkcia PHP \"set_time_limit\" nie je k dispozícii. To by mohlo viesť k zastaveniu skriptov v polovici vykonávania, čím by došlo k prerušeniu inštalácie. Dôrazne odporúčame povoliť túto funkciu.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Vaše PHP nemá podporu FreeType, čo bude mať za následok poškodenie profilových obrázkov a rozhrania nastavení.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Chýbajúci index \"{indexName}\" v tabuľke \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "V databáze chýbajú nejaké indexy. Keďže pridávanie indexov voči veľkým tabuľkám môže trvať dlho, tak neboli pridané automaticky. Spustením príkazu \"occ db:add-missing-indices\" môžete tieto chýbajúce indexy pridať ručne počas behu. Akonáhle budú indexy aktívne, tak požiadavky voči databáze budú podstatne rýchlejšie.",
-    "Missing primary key on table \"{tableName}\"." : "Chýbajúci primárny kľúč v tabuľke \"{tableName}\".",
-    "The database is missing some primary keys. Due to the fact that adding primary keys on big tables could take some time they were not added automatically. By running \"occ db:add-missing-primary-keys\" those missing primary keys could be added manually while the instance keeps running." : "V databáze chýbajú niektoré primárne kľúče. Vzhľadom na to, že pridávanie primárnych kľúčov do veľkých tabuliek by mohlo chvíľu trvať, neboli pridané automaticky. Spustením príkazu „occ db:add-missing-primary-keys“ je možné tieto chýbajúce primárne kľúče pridať ručne, zatiaľ čo inštancia beží.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Chýba nepovinný stĺpec „{columnName}“ v tabuľke „{tableName}“.",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "V databáze chýbajú niektoré voliteľné stĺpce. Vzhľadom na skutočnosť, že pridanie stĺpcov na veľké tabuľky by mohlo nejaký čas trvať, neboli pridané automaticky, keď môžu byť voliteľné. Spustením príkazu „occ db:add-missing-columns“ sa tieto chýbajúce stĺpce môžu pridať ručne, zatiaľ čo inštancia zostáva v prevádzke. Po pridaní stĺpcov môžu niektoré funkcie zlepšiť odozvu alebo použiteľnosť.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "V tejto inštancii chýbajú niektoré odporúčané moduly PHP.\nAk chcete zlepšiť výkon a kompatibilitu, dôrazne odporúčame, aby ste ich nainštalovali.",
-    "The PHP module \"imagick\" is not enabled although the theming app is. For favicon generation to work correctly, you need to install and enable this module." : "PHP modul „imagick“ nie je povolený, hoci tematická aplikácia áno. Aby generovanie favicon správne fungovalo, musíte nainštalovať a povoliť tento modul.",
-    "The PHP modules \"gmp\" and/or \"bcmath\" are not enabled. If you use WebAuthn passwordless authentication, these modules are required." : "PHP moduly \"gmp\" a/alebo \"bcmath\" nie sú povolené. Ak používate autentifikáciu WebAuthn bez hesla, tieto moduly sú povinné.",
-    "It seems like you are running a 32-bit PHP version. Nextcloud needs 64-bit to run well. Please upgrade your OS and PHP to 64-bit! For further details read {linkstart}the documentation page ↗{linkend} about this." : "Zdá sa, že používate 32-bitovú verziu PHP. Nextcloud potrebuje 64-bitovú verziu, aby fungoval dobre. Inovujte svoj OS a PHP na 64-bitové! Ďalšie podrobnosti nájdete na {linkstart}stránke dokumentácie↗{linkend}.",
-    "Module php-imagick in this instance has no SVG support. For better compatibility it is recommended to install it." : "Modul php-imagick nemá podporu SVG. Pre lepšiu kompatibilitu sa odporúča nainštalovať ho.",
-    "Some columns in the database are missing a conversion to big int. Due to the fact that changing column types on big tables could take some time they were not changed automatically. By running \"occ db:convert-filecache-bigint\" those pending changes could be applied manually. This operation needs to be made while the instance is offline. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Niektorým stĺpcom v databáze chýba konverzia na big int. Vzhľadom na to, že zmena typov stĺpcov na veľkých tabuľkách by mohla chvíľu trvať, neboli zmenené automaticky. Spustením príkazu „occ db: convert-filecache-bigint“ budú zmeny aplikované manuálne. Túto operáciu je potrebné vykonať v čase, keď je inštancia offline. Ďalšie informácie nájdete na {linkstart} dokumentačnej stránke ↗{linkend}.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "Ako databáza je použitá SQLite. Pre väčšie inštalácie odporúčame prejsť na inú databázu.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Toto odporúčame najmä pri používaní klientských aplikácií na synchronizáciu s desktopom.",
-    "To migrate to another database use the command line tool: \"occ db:convert-type\", or see the {linkstart}documentation ↗{linkend}." : "Na migráciu do inej databázy použite nástroj príkazového riadku: 'occ db:convert-type' alebo si pozrite {linkstart}dokumentáciu  ↗{linkend}.",
-    "The PHP memory limit is below the recommended value of 512MB." : "Limit pre pamäť PHP je nižší ako odporúčaná hodnota 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Niektoré aplikačné priečinky majú iného vlastníka ako web server.  Toto môže nastať ak aplikácie boli inštalované manuálne.  Skontrolujte práva nasledovných priečinkov nasledovných aplikácií:",
-    "MySQL is used as database but does not support 4-byte characters. To be able to handle 4-byte characters (like emojis) without issues in filenames or comments for example it is recommended to enable the 4-byte support in MySQL. For further details read {linkstart}the documentation page about this ↗{linkend}." : "Ako databáza sa používa MySQL, ale nepodporuje 4-bajtové znaky. Aby bolo možné také znaky (ako napr. emoji) bez problémov spracovať, odporúčame povoliť v MySQL podporu pre 4-bajtové znaky. Viac o tejto problematike nájdete v {linkstart}dokumentácii ↗{linkend}.",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "Táto inštancia používa ako hlavné úložisko objektové úložisko, ktoré je založené na protokole S3. Nahrávané súbory sú však dočasne ukladané priamo na server a preto odporúčame mať v PHP adresári pre dočasné súbory aspoň 50 GB voľného priestoru. Podrobnosti o umiestnení a priestore, ktorý je k dispozícii nájdete v logoch. Zmenu adresára pre dočasné súbory môžete uskutočniť v php.ini alebo zvýšte kapacitu súčasného umiestnenia.",
-    "The temporary directory of this instance points to an either non-existing or non-writable directory." : "Dočasný adresár tejto inštancie ukazuje na neexistujúci alebo nezapísateľný adresár.",
     "You are accessing your instance over a secure connection, however your instance is generating insecure URLs. This most likely means that you are behind a reverse proxy and the overwrite config variables are not set correctly. Please read {linkstart}the documentation page about this ↗{linkend}." : "K svojej inštancii pristupujete cez zabezpečené pripojenie, avšak vaša inštancia generuje nezabezpečené adresy URL. To s najväčšou pravdepodobnosťou znamená, že ste za reverzným proxy serverom a konfiguračné premenné prepisu nie sú nastavené správne. Prečítajte si o tom {linkstart} stránku s dokumentáciou ↗{linkend}.",
-    "This instance is running in debug mode. Only enable this for local development and not in production environments." : "Táto inštancia beží v režime ladenia. Toto povolte iba pre lokálny vývoj a nie v produkčnom prostredí.",
     "Your data directory and files are probably accessible from the internet. The .htaccess file is not working. It is strongly recommended that you configure your web server so that the data directory is no longer accessible, or move the data directory outside the web server document root." : "Váš dátový adresár a súbory sú pravdepodobne prístupné z internetu. Súbor .htaccess nefunguje. Dôrazne odporúčame nakonfigurovať webový server tak, aby k dátovému adresáru už nebol prístupný, alebo presunúť dátový adresár mimo koreňa dokumentov webového servera.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" nie je nakonfigurovaná tak, aby sa rovnala \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
     "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Hlavička HTTP \"{header}\" nie je nakonfigurovaná tak, aby sa rovnala \"{expected}\". Toto je potenciálne riziko pre bezpečnosť alebo ochranu osobných údajov a preto odporúčame toto nastavenie upraviť.",
@@ -424,47 +389,23 @@ OC.L10N.register(
     "The \"{header}\" HTTP header is not set to \"{val1}\", \"{val2}\", \"{val3}\", \"{val4}\" or \"{val5}\". This can leak referer information. See the {linkstart}W3C Recommendation ↗{linkend}." : "Hlavička HTTP „{header}“ nie je nastavená na „{val1}“, „{val2}“, „{val3}“, „{val4}“ alebo „{val5}“. To môže spôsobiť únik referer informácie. Prečítajte si {linkstart} odporúčanie W3C ↗{linkend}.",
     "The \"Strict-Transport-Security\" HTTP header is not set to at least \"{seconds}\" seconds. For enhanced security, it is recommended to enable HSTS as described in the {linkstart}security tips ↗{linkend}." : "Hlavička HTTP „Strict-Transport-Security“ nie je nastavená na minimálne „{seconds}“ sekúnd. Kvôli zvýšenému zabezpečeniu sa odporúča povoliť HSTS, ako je popísané v {linkstart} bezpečnostných tipoch ↗{linkend}.",
     "Accessing site insecurely via HTTP. You are strongly advised to set up your server to require HTTPS instead, as described in the {linkstart}security tips ↗{linkend}. Without it some important web functionality like \"copy to clipboard\" or \"service workers\" will not work!" : "Prístup na stránku nezabezpečený cez HTTP. Dôrazne sa odporúča nastaviť váš server tak, aby namiesto toho vyžadoval HTTPS, ako je opísané v {linkstart}bezpečnostných tipoch ↗{linkend}. Bez toho niektoré dôležité webové funkcie, ako napríklad \"kopírovať do schránky\" alebo \"service workers\", nebudú fungovať!",
+    "Currently open" : "V súčasnosti otvorené",
     "Wrong username or password." : "Nesprávne používateľské meno alebo heslo.",
     "User disabled" : "Používateľ zakázaný",
+    "Login with username or email" : "Prihlásiť sa pomocou užívateľského mena alebo e-mailu",
+    "Login with username" : "Prihlásiť sa s užívateľským menom",
     "Username or email" : "Používateľské meno alebo e-mail",
     "If this account exists, a password reset message has been sent to its email address. If you do not receive it, verify your email address and/or account name, check your spam/junk folders or ask your local administration for help." : "Ak existuje tento účet, na jeho e-mailovú adresu bola odoslaná správa na obnovenie hesla. Ak ju nedostanete, overte si svoju e-mailovú adresu a/alebo názov účtu, skontrolujte svoje spam/junk priečinky alebo požiadajte o pomoc miestneho administrátora.",
-    "Start search" : "Začať vyhľadávať",
-    "Open settings menu" : "Otvoriť menu s nastavením",
-    "Settings" : "Nastavenia",
-    "Avatar of {fullName}" : "Avatar užívateľa {fullName}",
-    "Show all contacts …" : "Zobraziť všetky kontakty...",
-    "No files in here" : "Nie sú tu žiadne súbory",
-    "New folder" : "Nový priečinok",
-    "No more subfolders in here" : "Už tu nie sú žiadne ďalšie podpriečinky",
-    "Name" : "Názov",
-    "Size" : "Veľkosť",
-    "Modified" : "Upravené",
-    "\"{name}\" is an invalid file name." : "\"{name}\" je neplatné meno súboru.",
-    "File name cannot be empty." : "Meno súboru nemôže byť prázdne",
-    "\"/\" is not allowed inside a file name." : "Znak \"/\" nie je povolený v názve súboru.",
-    "\"{name}\" is not an allowed filetype" : "\"{name}\" nie je povolený typ súboru",
-    "{newName} already exists" : "{newName} už existuje",
-    "Error loading file picker template: {error}" : "Chyba pri nahrávaní šablóny výberu súborov: {error}",
+    "Apps and Settings" : "Aplikácie a Nastavenia",
     "Error loading message template: {error}" : "Chyba pri nahrávaní šablóny správy: {error}",
-    "Show list view" : "Zobraziť ako zoznam",
-    "Show grid view" : "Zobraziť v mriežke",
-    "Pending" : "Čaká",
-    "Home" : "Domov",
-    "Copy to {folder}" : "Skopírovať do {folder}",
-    "Move to {folder}" : "Presunúť do {folder}",
-    "Authentication required" : "Vyžaduje sa overenie",
-    "This action requires you to confirm your password" : "Táto akcia vyžaduje potvrdenie vášho hesla",
-    "Confirm" : "Potvrdiť",
-    "Failed to authenticate, try again" : "Nastal problém pri overení, skúste znova",
     "Users" : "Používatelia",
     "Username" : "Meno používateľa",
     "Database user" : "Používateľ databázy",
+    "This action requires you to confirm your password" : "Táto akcia vyžaduje potvrdenie vášho hesla",
     "Confirm your password" : "Potvrďte svoje heslo",
+    "Confirm" : "Potvrdiť",
     "App token" : "Token aplikácie",
     "Alternative log in using app token" : "Alternatívne prihlásenie pomocou tokenu aplikácie",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Použite aktualizátor z príkazového riadka, pretože máte veľkú inštanciu s viac ako 50 používateľmi.",
-    "Login with username or email" : "Prihlásiť sa pomocou užívateľského mena alebo e-mailu",
-    "Login with username" : "Prihlásiť sa s užívateľským menom",
-    "Apps and Settings" : "Aplikácie a Nastavenia"
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Použite aktualizátor z príkazového riadka, pretože máte veľkú inštanciu s viac ako 50 používateľmi."
 },
 "nplurals=4; plural=(n % 1 == 0 && n == 1 ? 0 : n % 1 == 0 && n >= 2 && n <= 4 ? 1 : n % 1 != 0 ? 2: 3);");
