@@ -31,9 +31,7 @@ OC.L10N.register(
     "Dot files are not allowed" : "Berkas titik tidak diperbolehkan",
     "File already exists" : "Berkas sudah ada",
     "Templates" : "Templat",
-    "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
-    "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
-    "File name is too long" : "Nama berkas terlalu panjang",
+    "Filename contains at least one invalid character" : "Nama berkas mengandung setidaknya satu karakter yang tidak sah",
     "Empty filename is not allowed" : "Nama berkas kosong tidak diperbolehkan",
     "App \"%s\" cannot be installed because appinfo file cannot be read." : "Aplikasi \"%s\" tidak dapat dipasang karena berkas appinfo tidak dapat dibaca.",
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Aplikasi \"%s\" tidak dapat dipasang karena tidak kompatibel dengan versi server ini",
@@ -60,6 +58,7 @@ OC.L10N.register(
     "Sharing backend %s not found" : "Backend berbagi %s tidak ditemukan",
     "Sharing backend for %s not found" : "Backend berbagi untuk %s tidak ditemukan",
     "Open »%s«" : "Buka »%s«",
+    "Unknown share type" : "Tipe berbagi tidak diketahui",
     "You are not allowed to share %s" : "Anda tidak diizinkan untuk membagikan %s",
     "Cannot increase permissions of %s" : "Tidak dapat menambah izin %s",
     "Expiration date is in the past" : "Tanggal kedaluwarsa sudah lewat",
@@ -112,7 +111,6 @@ OC.L10N.register(
     "A valid password must be provided" : "Tuliskan kata sandi yang valid",
     "Login canceled by app" : "Log masuk dibatalkan oleh aplikasi",
     "a safe home for all your data" : "rumah yang aman untuk semua data Anda",
-    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
     "Application is not enabled" : "aplikasi tidak diaktifkan",
     "Authentication error" : "Galat saat otentikasi",
     "Token expired. Please reload page." : "Token sudah kedaluwarsa. Silakan muat ulang halaman.",
@@ -133,6 +131,9 @@ OC.L10N.register(
     "Storage connection timeout. %s" : "Koneksi penyimpanan waktu-habis. %s",
     "Summary" : "Kesimpulan",
     "Translate" : "Terjemahkan",
+    "File name is a reserved word" : "Nama berkas merupakan kata yang disediakan",
+    "File name contains at least one invalid character" : "Nama berkas berisi setidaknya satu karakter yang tidak sah.",
+    "File name is too long" : "Nama berkas terlalu panjang",
     "Help" : "Bantuan",
     "Users" : "Pengguna",
     "Unknown user" : "Pengguna tidak dikenal",
@@ -144,6 +145,7 @@ OC.L10N.register(
     "A valid username must be provided" : "Tuliskan nama pengguna yang valid",
     "Username contains whitespace at the beginning or at the end" : "Nama pengguna mengandung spasi di depan atau di belakang.",
     "User disabled" : "Pengguna dinonaktifkan",
+    "File is currently busy, please try again later" : "Berkas sedang sibuk, mohon coba lagi nanti",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Mohon ubah perizinan menjadi 0770 sehingga direktori tersebut tidak dapat dilihat oleh pengguna lain."
 },
 "nplurals=1; plural=0;");
