@@ -109,6 +109,12 @@ class AppConfig implements IAppConfig {
 		'notify_push' => [
 			'/^cookie$/',
 		],
+		'onlyoffice' => [
+			'/^jwt_secret$/',
+		],
+		'passwords' => [
+			'/^SSEv1ServerKey$/',
+		],
 		'serverinfo' => [
 			'/^token$/',
 		],
@@ -140,6 +146,9 @@ class AppConfig implements IAppConfig {
 		'user_ldap' => [
 			'/^(s..)?ldap_agent_password$/',
 		],
+		'twofactor_gateway' => [
+			'/^.*token$/',
+		],
 		'user_saml' => [
 			'/^idp-x509cert$/',
 		],
