@@ -32,6 +32,36 @@ namespace OCP\Mail;
  * @since 13.0.0
  */
 interface IMessage {
+	/**
+	 * Set the subject of this message
+	 *
+	 * @param string $subject
+	 *
+	 * @return self
+	 * @since 28.0.0
+	 */
+	public function setSubject(string $subject): IMessage;
+
+	/**
+	 * Set the plain-text body of this message
+	 *
+	 * @param string $body
+	 *
+	 * @return self
+	 * @since 28.0.0
+	 */
+	public function setPlainBody(string $body): IMessage;
+
+	/**
+	 * Set the HTML body of this message. Consider also sending a plain-text body instead of only an HTML one.
+	 *
+	 * @param string $body
+	 *
+	 * @return self
+	 * @since 28.0.0
+	 */
+	public function setHtmlBody(string $body): IMessage;
+
 	/**
 	 * @param IAttachment $attachment
 	 * @return IMessage
